@@ -21,6 +21,8 @@
 
 package com.github.javaparser.generator.core.visitor;
 
+import static com.github.javaparser.utils.CodeGenerationUtils.f;
+
 import com.github.javaparser.ast.CompilationUnit;
 import com.github.javaparser.ast.body.MethodDeclaration;
 import com.github.javaparser.ast.stmt.BlockStmt;
@@ -28,13 +30,10 @@ import com.github.javaparser.generator.VisitorGenerator;
 import com.github.javaparser.metamodel.BaseNodeMetaModel;
 import com.github.javaparser.metamodel.PropertyMetaModel;
 import com.github.javaparser.utils.SourceRoot;
-
 import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.List;
 
-import static com.github.javaparser.utils.CodeGenerationUtils.f;
-
 /**
  * Generates JavaParser's GenericListVisitorAdapter.
  */
@@ -44,7 +43,8 @@ public class GenericListVisitorAdapterGenerator extends VisitorGenerator {
     }
 
     @Override
-    protected void generateVisitMethodBody(BaseNodeMetaModel node, MethodDeclaration visitMethod, CompilationUnit compilationUnit) {
+    protected void generateVisitMethodBody(
+            BaseNodeMetaModel node, MethodDeclaration visitMethod, CompilationUnit compilationUnit) {
         visitMethod.getParameters().forEach(p -> p.setFinal(true));
 
         BlockStmt body = visitMethod.getBody().get();
@@ -58,20 +58,18 @@ public class GenericListVisitorAdapterGenerator extends VisitorGenerator {
             final String getter = field.getGetterMethodName() + "()";
             if (field.getNodeReference().isPresent()) {
                 if (field.isOptional()) {
-                    body.addStatement(f("if (n.%s.isPresent()) {" +
-                            "   tmp = n.%s.get().accept(this, arg);" +
-                            "   %s" +
-                            "}", getter, getter, resultCheck));
+                    body.addStatement(f(
+                            "if (n.%s.isPresent()) {" + "   tmp = n.%s.get().accept(this, arg);" + "   %s" + "}",
+                            getter, getter, resultCheck));
                 } else {
                     body.addStatement(f("{ tmp = n.%s.accept(this, arg); %s }", getter, resultCheck));
                 }
             }
         }
         body.addStatement("return result;");
-        Arrays.stream(new Class<?>[] {List.class, ArrayList.class}).filter(c ->
-                compilationUnit.getImports().stream().noneMatch(
-                        i -> c.getName().equals(i.getName().asString())
-                )
-        ).forEach(compilationUnit::addImport);
+        Arrays.stream(new Class<?>[] {List.class, ArrayList.class})
+                .filter(c -> compilationUnit.getImports().stream()
+                        .noneMatch(i -> c.getName().equals(i.getName().asString())))
+                .forEach(compilationUnit::addImport);
     }
 }
