@@ -21,6 +21,8 @@
 
 package com.github.javaparser.generator.core.visitor;
 
+import static com.github.javaparser.utils.CodeGenerationUtils.f;
+
 import com.github.javaparser.ast.CompilationUnit;
 import com.github.javaparser.ast.body.MethodDeclaration;
 import com.github.javaparser.ast.expr.BinaryExpr;
@@ -30,21 +32,19 @@ import com.github.javaparser.metamodel.BaseNodeMetaModel;
 import com.github.javaparser.metamodel.PropertyMetaModel;
 import com.github.javaparser.utils.SeparatedItemStringBuilder;
 import com.github.javaparser.utils.SourceRoot;
-
 import java.util.Arrays;
 import java.util.Comparator;
 import java.util.List;
 import java.util.stream.Collectors;
 
-import static com.github.javaparser.utils.CodeGenerationUtils.f;
-
 public class ModifierVisitorGenerator extends VisitorGenerator {
     public ModifierVisitorGenerator(SourceRoot sourceRoot) {
         super(sourceRoot, "com.github.javaparser.ast.visitor", "ModifierVisitor", "Visitable", "A", true);
     }
 
     @Override
-    protected void generateVisitMethodBody(BaseNodeMetaModel node, MethodDeclaration visitMethod, CompilationUnit compilationUnit) {
+    protected void generateVisitMethodBody(
+            BaseNodeMetaModel node, MethodDeclaration visitMethod, CompilationUnit compilationUnit) {
         visitMethod.getParameters().forEach(p -> p.setFinal(true));
 
         BlockStmt body = visitMethod.getBody().get();
@@ -52,15 +52,14 @@ public class ModifierVisitorGenerator extends VisitorGenerator {
 
         // FIXME: Bit of a hacky way to get this fixed order, and then have everything else (note this list is reversed)
         List<String> order = Arrays.asList(
-//                "comment", "name", "members", "parameters", "name",
-                "modifiers", "annotations"
-        );
-        List<PropertyMetaModel> sortedPropertyMetaModels = node.getAllPropertyMetaModels()
-                .stream()
-                .sorted(Comparator
-                        .comparingInt((PropertyMetaModel o) -> order.indexOf(o.getName())).reversed()
-//                        .thenComparing(PropertyMetaModel::getName)
-                )
+                //                "comment", "name", "members", "parameters", "name",
+                "modifiers", "annotations");
+        List<PropertyMetaModel> sortedPropertyMetaModels = node.getAllPropertyMetaModels().stream()
+                .sorted(
+                        Comparator.comparingInt((PropertyMetaModel o) -> order.indexOf(o.getName()))
+                                .reversed()
+                        //                        .thenComparing(PropertyMetaModel::getName)
+                        )
                 .collect(Collectors.toList());
 
         //
@@ -71,7 +70,8 @@ public class ModifierVisitorGenerator extends VisitorGenerator {
             body.addStatement("if (left == null) return right;");
             body.addStatement("if (right == null) return left;");
         } else {
-            final SeparatedItemStringBuilder collapseCheck = new SeparatedItemStringBuilder("if(", "||", ") return null;");
+            final SeparatedItemStringBuilder collapseCheck =
+                    new SeparatedItemStringBuilder("if(", "||", ") return null;");
             sortedPropertyMetaModels.forEach(property -> {
                 if (property.isRequired() && property.isNode()) {
                     if (property.isNodeList()) {
@@ -102,18 +102,19 @@ public class ModifierVisitorGenerator extends VisitorGenerator {
     private void extracted(BlockStmt body, PropertyMetaModel property) {
         if (property.isNode()) {
             if (property.isNodeList()) {
-                body.addStatement(f("NodeList<%s> %s = modifyList(n.%s(), arg);",
-                        property.getTypeNameGenerified(),
-                        property.getName(),
-                        property.getGetterMethodName()));
+                body.addStatement(f(
+                        "NodeList<%s> %s = modifyList(n.%s(), arg);",
+                        property.getTypeNameGenerified(), property.getName(), property.getGetterMethodName()));
             } else if (property.isOptional()) {
-                body.addStatement(f("%s %s = n.%s().map(s -> (%s) s.accept(this, arg)).orElse(null);",
+                body.addStatement(f(
+                        "%s %s = n.%s().map(s -> (%s) s.accept(this, arg)).orElse(null);",
                         property.getTypeNameGenerified(),
                         property.getName(),
                         property.getGetterMethodName(),
                         property.getTypeNameGenerified()));
             } else {
-                body.addStatement(f("%s %s = (%s) n.%s().accept(this, arg);",
+                body.addStatement(f(
+                        "%s %s = (%s) n.%s().accept(this, arg);",
                         property.getTypeNameGenerified(),
                         property.getName(),
                         property.getTypeNameGenerified(),
