@@ -21,20 +21,19 @@
 
 package com.github.javaparser.generator.metamodel;
 
-import com.github.javaparser.ast.AllFieldsConstructor;
-import com.github.javaparser.ast.Node;
-import com.github.javaparser.ast.NodeList;
-import com.github.javaparser.ast.stmt.Statement;
-
-import java.lang.annotation.Annotation;
-import java.lang.reflect.Constructor;
-import java.lang.reflect.Field;
-
 import static com.github.javaparser.StaticJavaParser.parseStatement;
 import static com.github.javaparser.generator.metamodel.MetaModelGenerator.nodeMetaModelFieldName;
 import static com.github.javaparser.generator.metamodel.MetaModelGenerator.propertyMetaModelFieldName;
 import static com.github.javaparser.utils.CodeGenerationUtils.f;
 
+import com.github.javaparser.ast.AllFieldsConstructor;
+import com.github.javaparser.ast.Node;
+import com.github.javaparser.ast.NodeList;
+import com.github.javaparser.ast.stmt.Statement;
+import java.lang.annotation.Annotation;
+import java.lang.reflect.Constructor;
+import java.lang.reflect.Field;
+
 class InitializeConstructorParametersStatementsGenerator {
     void generate(Class<? extends Node> nodeClass, NodeList<Statement> initializeConstructorParametersStatements) {
         if (nodeClass == Node.class) {
@@ -44,7 +43,8 @@ class InitializeConstructorParametersStatementsGenerator {
         for (java.lang.reflect.Parameter parameter : constructor.getParameters()) {
             Field field = findFieldInClass(nodeClass, parameter.getName());
 
-            String addFieldStatement = f("%s.getConstructorParameters().add(%s.%s);",
+            String addFieldStatement = f(
+                    "%s.getConstructorParameters().add(%s.%s);",
                     nodeMetaModelFieldName(nodeClass),
                     nodeMetaModelFieldName(field.getDeclaringClass()),
                     propertyMetaModelFieldName(field));
@@ -63,7 +63,8 @@ class InitializeConstructorParametersStatementsGenerator {
             }
             searchClass = searchClass.getSuperclass();
         } while (searchClass != null);
-        throw new AssertionError(f("Couldn't find constructor parameter %s as a field, class %s", name, nodeClass.getSimpleName()));
+        throw new AssertionError(
+                f("Couldn't find constructor parameter %s as a field, class %s", name, nodeClass.getSimpleName()));
     }
 
     private Constructor<?> findAllFieldsConstructor(Class<? extends Node> nodeClass) {
@@ -74,6 +75,7 @@ class InitializeConstructorParametersStatementsGenerator {
                 }
             }
         }
-        throw new AssertionError(f("Node class %s has no constructor annotated with @AllFieldsConstructor", nodeClass.getSimpleName()));
+        throw new AssertionError(
+                f("Node class %s has no constructor annotated with @AllFieldsConstructor", nodeClass.getSimpleName()));
     }
 }
