@@ -21,6 +21,12 @@
 
 package com.github.javaparser.generator.metamodel;
 
+import static com.github.javaparser.StaticJavaParser.*;
+import static com.github.javaparser.ast.Modifier.Keyword.*;
+import static com.github.javaparser.utils.CodeGenerationUtils.f;
+import static com.github.javaparser.utils.CodeGenerationUtils.optionalOf;
+import static com.github.javaparser.utils.Utils.decapitalize;
+
 import com.github.javaparser.ast.CompilationUnit;
 import com.github.javaparser.ast.Node;
 import com.github.javaparser.ast.NodeList;
@@ -30,39 +36,43 @@ import com.github.javaparser.generator.AbstractGenerator;
 import com.github.javaparser.metamodel.DerivedProperty;
 import com.github.javaparser.metamodel.InternalProperty;
 import com.github.javaparser.utils.SourceRoot;
-
 import java.lang.reflect.Field;
 import java.lang.reflect.Method;
 import java.util.*;
 
-import static com.github.javaparser.StaticJavaParser.*;
-import static com.github.javaparser.ast.Modifier.Keyword.*;
-import static com.github.javaparser.utils.CodeGenerationUtils.f;
-import static com.github.javaparser.utils.CodeGenerationUtils.optionalOf;
-import static com.github.javaparser.utils.Utils.decapitalize;
-
 public class NodeMetaModelGenerator extends AbstractGenerator {
 
-    private final InitializePropertyMetaModelsStatementsGenerator initializePropertyMetaModelsStatementsGenerator = new InitializePropertyMetaModelsStatementsGenerator();
-    private final InitializeConstructorParametersStatementsGenerator initializeConstructorParametersStatementsGenerator = new InitializeConstructorParametersStatementsGenerator();
+    private final InitializePropertyMetaModelsStatementsGenerator initializePropertyMetaModelsStatementsGenerator =
+            new InitializePropertyMetaModelsStatementsGenerator();
+    private final InitializeConstructorParametersStatementsGenerator
+            initializeConstructorParametersStatementsGenerator =
+                    new InitializeConstructorParametersStatementsGenerator();
 
-    public static final String GENERATED_CLASS_COMMENT = "" +
-            "This file, class, and its contents are completely generated based on:" +
-            "\n<ul>" +
-            "\n    <li>The contents and annotations within the package `com.github.javaparser.ast`, and</li>" +
-            "\n    <li>`ALL_NODE_CLASSES` within the class `com.github.javaparser.generator.metamodel.MetaModelGenerator`.</li>" +
-            "\n</ul>" +
-            "\n" +
-            "\nFor this reason, any changes made directly to this file will be overwritten the next time generators are run." +
-            "";
+    public static final String GENERATED_CLASS_COMMENT =
+            "" + "This file, class, and its contents are completely generated based on:"
+                    + "\n<ul>"
+                    + "\n    <li>The contents and annotations within the package `com.github.javaparser.ast`, and</li>"
+                    + "\n    <li>`ALL_NODE_CLASSES` within the class `com.github.javaparser.generator.metamodel.MetaModelGenerator`.</li>"
+                    + "\n</ul>"
+                    + "\n"
+                    + "\nFor this reason, any changes made directly to this file will be overwritten the next time generators are run."
+                    + "";
 
-    private static final String GENERATED_JAVADOC_COMMENT = "Warning: The content of this class is partially or completely generated - manual edits risk being overwritten.";
+    private static final String GENERATED_JAVADOC_COMMENT =
+            "Warning: The content of this class is partially or completely generated - manual edits risk being overwritten.";
 
     protected NodeMetaModelGenerator(SourceRoot sourceRoot) {
         super(sourceRoot);
     }
 
-    public void generate(Class<? extends Node> nodeClass, ClassOrInterfaceDeclaration metaModelCoid, NodeList<Statement> initializeNodeMetaModelsStatements, NodeList<Statement> initializePropertyMetaModelsStatements, NodeList<Statement> initializeConstructorParametersStatements, SourceRoot sourceRoot) throws NoSuchMethodException {
+    public void generate(
+            Class<? extends Node> nodeClass,
+            ClassOrInterfaceDeclaration metaModelCoid,
+            NodeList<Statement> initializeNodeMetaModelsStatements,
+            NodeList<Statement> initializePropertyMetaModelsStatements,
+            NodeList<Statement> initializeConstructorParametersStatements,
+            SourceRoot sourceRoot)
+            throws NoSuchMethodException {
         metaModelCoid.setJavadocComment(GENERATED_JAVADOC_COMMENT);
 
         final AstTypeAnalysis typeAnalysis = new AstTypeAnalysis(nodeClass);
@@ -72,22 +82,20 @@ public class NodeMetaModelGenerator extends AbstractGenerator {
         metaModelCoid.getFieldByName(nodeMetaModelFieldName).ifPresent(Node::remove);
 
         initializeNodeMetaModelsStatements.add(parseStatement(f("nodeMetaModels.add(%s);", nodeMetaModelFieldName)));
-        this.initializeConstructorParametersStatementsGenerator.generate(nodeClass, initializeConstructorParametersStatements);
+        this.initializeConstructorParametersStatementsGenerator.generate(
+                nodeClass, initializeConstructorParametersStatements);
 
         final Class<?> superclass = nodeClass.getSuperclass();
         final String superNodeMetaModel = MetaModelGenerator.nodeMetaModelName(superclass);
         final boolean isRootNode = !MetaModelGenerator.isNode(superclass);
 
-        final FieldDeclaration nodeField = metaModelCoid.addField(className, nodeMetaModelFieldName, PUBLIC, STATIC, FINAL);
+        final FieldDeclaration nodeField =
+                metaModelCoid.addField(className, nodeMetaModelFieldName, PUBLIC, STATIC, FINAL);
         annotateGenerated(nodeField);
-        nodeField.getVariable(0).setInitializer(
-                parseExpression(
-                        f("new %s(%s)",
-                                className,
-                                optionalOf(decapitalize(superNodeMetaModel), !isRootNode))
-                )
-        );
-
+        nodeField
+                .getVariable(0)
+                .setInitializer(parseExpression(
+                        f("new %s(%s)", className, optionalOf(decapitalize(superNodeMetaModel), !isRootNode))));
 
         // The node-specific metamodel file
         final CompilationUnit classMetaModelJavaFile = new CompilationUnit(MetaModelGenerator.METAMODEL_PACKAGE);
@@ -111,32 +119,27 @@ public class NodeMetaModelGenerator extends AbstractGenerator {
                 .addConstructor()
                 .addParameter(
                         f("Optional<%s>", MetaModelGenerator.BASE_NODE_META_MODEL),
-                        f("super%s", MetaModelGenerator.BASE_NODE_META_MODEL)
-                );
+                        f("super%s", MetaModelGenerator.BASE_NODE_META_MODEL));
         classMMConstructor
                 .getBody()
-                .addStatement(
-                        parseExplicitConstructorInvocationStmt(f("super(super%s, %s.class, \"%s\", \"%s\", %s, %s);",
-                                MetaModelGenerator.BASE_NODE_META_MODEL,
-                                nodeClass.getSimpleName(),
-                                nodeClass.getSimpleName(),
-                                nodeClass.getPackage().getName(),
-                                typeAnalysis.isAbstract,
-                                typeAnalysis.isSelfType
-                        ))
-                );
+                .addStatement(parseExplicitConstructorInvocationStmt(f(
+                        "super(super%s, %s.class, \"%s\", \"%s\", %s, %s);",
+                        MetaModelGenerator.BASE_NODE_META_MODEL,
+                        nodeClass.getSimpleName(),
+                        nodeClass.getSimpleName(),
+                        nodeClass.getPackage().getName(),
+                        typeAnalysis.isAbstract,
+                        typeAnalysis.isSelfType)));
         annotateGenerated(classMMConstructor);
 
         // ?Abstract protected constructor?
         if (typeAnalysis.isAbstract) {
             classMetaModelJavaFile.addImport(Node.class);
             BodyDeclaration<?> bodyDeclaration = parseBodyDeclaration(f(
-                    "protected %s(Optional<%s> superNodeMetaModel, Class<? extends Node> type, String name, String packageName, boolean isAbstract, boolean hasWildcard) {" +
-                            "super(superNodeMetaModel, type, name, packageName, isAbstract, hasWildcard);" +
-                            " }",
-                    className,
-                    MetaModelGenerator.BASE_NODE_META_MODEL
-            ));
+                    "protected %s(Optional<%s> superNodeMetaModel, Class<? extends Node> type, String name, String packageName, boolean isAbstract, boolean hasWildcard) {"
+                            + "super(superNodeMetaModel, type, name, packageName, isAbstract, hasWildcard);"
+                            + " }",
+                    className, MetaModelGenerator.BASE_NODE_META_MODEL));
             annotateGenerated(bodyDeclaration);
             nodeMetaModelClass.addMember(bodyDeclaration);
         }
@@ -149,7 +152,8 @@ public class NodeMetaModelGenerator extends AbstractGenerator {
                 continue;
             }
 
-            this.initializePropertyMetaModelsStatementsGenerator.generate(field, nodeMetaModelClass, nodeMetaModelFieldName, initializePropertyMetaModelsStatements);
+            this.initializePropertyMetaModelsStatementsGenerator.generate(
+                    field, nodeMetaModelClass, nodeMetaModelFieldName, initializePropertyMetaModelsStatements);
         }
 
         // Methods, sorted by name.
@@ -157,18 +161,19 @@ public class NodeMetaModelGenerator extends AbstractGenerator {
         methods.sort(Comparator.comparing(Method::getName));
         for (Method method : methods) {
             if (method.isAnnotationPresent(DerivedProperty.class)) {
-                this.initializePropertyMetaModelsStatementsGenerator.generateDerivedProperty(method, nodeMetaModelClass, nodeMetaModelFieldName, initializePropertyMetaModelsStatements);
+                this.initializePropertyMetaModelsStatementsGenerator.generateDerivedProperty(
+                        method, nodeMetaModelClass, nodeMetaModelFieldName, initializePropertyMetaModelsStatements);
             }
         }
 
-
         this.moveStaticInitializeToTheEndOfTheClassBecauseWeNeedTheFieldsToInitializeFirst(metaModelCoid);
 
         // Add the file to the source root, enabling it to be saved later.
         sourceRoot.add(MetaModelGenerator.METAMODEL_PACKAGE, className + ".java", classMetaModelJavaFile);
     }
 
-    private void moveStaticInitializeToTheEndOfTheClassBecauseWeNeedTheFieldsToInitializeFirst(ClassOrInterfaceDeclaration metaModelCoid) {
+    private void moveStaticInitializeToTheEndOfTheClassBecauseWeNeedTheFieldsToInitializeFirst(
+            ClassOrInterfaceDeclaration metaModelCoid) {
         for (BodyDeclaration<?> m : metaModelCoid.getMembers()) {
             if (m instanceof InitializerDeclaration) {
                 m.remove();
@@ -179,7 +184,7 @@ public class NodeMetaModelGenerator extends AbstractGenerator {
     }
 
     private boolean fieldShouldBeIgnored(Field reflectionField) {
-        return java.lang.reflect.Modifier.isStatic(reflectionField.getModifiers()) ||
-                reflectionField.isAnnotationPresent(InternalProperty.class);
+        return java.lang.reflect.Modifier.isStatic(reflectionField.getModifiers())
+                || reflectionField.isAnnotationPresent(InternalProperty.class);
     }
 }
