@@ -23,14 +23,13 @@ package com.github.javaparser;
 
 import com.github.javaparser.steps.PositionRangeSteps;
 import com.github.javaparser.steps.SharedSteps;
+import java.util.HashMap;
+import java.util.Map;
 import org.jbehave.core.junit.JUnit4StoryRunner;
 import org.jbehave.core.steps.InjectableStepsFactory;
 import org.jbehave.core.steps.InstanceStepsFactory;
 import org.junit.runner.RunWith;
 
-import java.util.HashMap;
-import java.util.Map;
-
 @RunWith(JUnit4StoryRunner.class)
 public class PositionRangeTest extends BasicJBehaveTest {
 
@@ -38,14 +37,10 @@ public class PositionRangeTest extends BasicJBehaveTest {
     public InjectableStepsFactory stepsFactory() {
         Map<String, Object> state = new HashMap<>();
 
-        return new InstanceStepsFactory(configuration(),
-                new SharedSteps(state),
-                new PositionRangeSteps());
+        return new InstanceStepsFactory(configuration(), new SharedSteps(state), new PositionRangeSteps());
     }
 
     public PositionRangeTest() {
         super("**/position_range*.story");
     }
 }
-
-
