@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2007-2010 Júlio Vilmar Gesser.
- * Copyright (C) 2011, 2013-2019 The JavaParser Team.
+ * Copyright (C) 2011, 2013-2024 The JavaParser Team.
  *
  * This file is part of JavaParser.
  *
@@ -22,12 +22,12 @@
 package com.github.javaparser;
 
 import com.github.javaparser.steps.PrettyPrintingSteps;
-import com.github.valfirst.jbehave.junit.monitoring.JUnitReportingRunner;
+import org.jbehave.core.junit.JUnit4StoryRunner;
 import org.jbehave.core.steps.InjectableStepsFactory;
 import org.jbehave.core.steps.InstanceStepsFactory;
 import org.junit.runner.RunWith;
 
-@RunWith(JUnitReportingRunner.class)
+@RunWith(JUnit4StoryRunner.class)
 public class PrettyPrintingTest extends BasicJBehaveTest {
 
     @Override
@@ -39,4 +39,3 @@ public class PrettyPrintingTest extends BasicJBehaveTest {
         super("**/pretty_printing*.story");
     }
 }
-
