@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2007-2010 Júlio Vilmar Gesser.
- * Copyright (C) 2011, 2013-2019 The JavaParser Team.
+ * Copyright (C) 2011, 2013-2024 The JavaParser Team.
  *
  * This file is part of JavaParser.
  *
@@ -26,12 +26,12 @@ import java.io.InputStream;
 public class TestUtils {
 
     public static InputStream getSampleStream(String sampleName) {
-        InputStream is = TestUtils.class.getClassLoader().getResourceAsStream("com/github/javaparser/samples/"
-                + sampleName + ".java");
+        InputStream is = TestUtils.class
+                .getClassLoader()
+                .getResourceAsStream("com/github/javaparser/samples/" + sampleName + ".java");
         if (is == null) {
             throw new RuntimeException("Example not found, check your test. Sample name: " + sampleName);
         }
         return is;
     }
-
 }
