@@ -20,13 +20,13 @@
 
 package com.github.javaparser;
 
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertTrue;
+
 import com.github.javaparser.ast.expr.LambdaExpr;
 import com.github.javaparser.ast.stmt.Statement;
 import org.junit.jupiter.api.Test;
 
-import static org.junit.jupiter.api.Assertions.assertEquals;
-import static org.junit.jupiter.api.Assertions.assertTrue;
-
 /**
  * Tests related to https://github.com/javaparser/javaparser/issues/2482.
  */
@@ -34,8 +34,7 @@ public class Issue2482Test {
     @Test
     public void commentBeforeLambda() {
         LambdaExpr le = StaticJavaParser.parseExpression(
-                "// a comment before parent" + System.lineSeparator() +
-                "()->{return 1;}");
+                "// a comment before parent" + System.lineSeparator() + "()->{return 1;}");
 
         assertTrue(le.getComment().isPresent());
         assertTrue(le.getOrphanComments().isEmpty());
@@ -45,8 +44,7 @@ public class Issue2482Test {
     @Test
     public void commentBeforeBlock() {
         Statement st = StaticJavaParser.parseBlock(
-                "// a comment before parent" + System.lineSeparator() +
-                "{ if (file != null) {} }");
+                "// a comment before parent" + System.lineSeparator() + "{ if (file != null) {} }");
         assertTrue(st.getComment().isPresent());
         assertTrue(st.getOrphanComments().isEmpty());
         assertEquals(0, st.getAllContainedComments().size());
@@ -55,8 +53,7 @@ public class Issue2482Test {
     @Test
     public void commentBeforeIfStatement() {
         Statement st = StaticJavaParser.parseStatement(
-                "// a comment before parent" + System.lineSeparator() +
-                        "if (file != null) {}");
+                "// a comment before parent" + System.lineSeparator() + "if (file != null) {}");
         assertTrue(st.getComment().isPresent());
         assertTrue(st.getOrphanComments().isEmpty());
         assertEquals(0, st.getAllContainedComments().size());
@@ -64,9 +61,7 @@ public class Issue2482Test {
 
     @Test
     public void commentBeforeAssignment() {
-        Statement st = StaticJavaParser.parseStatement(
-                "// a comment" + System.lineSeparator() +
-                "int x = 3;");
+        Statement st = StaticJavaParser.parseStatement("// a comment" + System.lineSeparator() + "int x = 3;");
 
         assertTrue(st.getComment().isPresent());
         assertTrue(st.getOrphanComments().isEmpty());
