@@ -21,25 +21,20 @@
 
 package com.github.javaparser.ast;
 
-import com.github.javaparser.ast.expr.SimpleName;
-import org.junit.jupiter.api.Test;
-
-import java.util.Arrays;
-import java.util.List;
-
 import static org.assertj.core.api.AssertionsForInterfaceTypes.assertThat;
 import static org.junit.jupiter.api.Assertions.assertEquals;
 import static org.junit.jupiter.api.Assertions.assertThrows;
 
+import com.github.javaparser.ast.expr.SimpleName;
+import java.util.Arrays;
+import java.util.List;
+import org.junit.jupiter.api.Test;
+
 class DataKeyTest {
-    private static final DataKey<String> ABC = new DataKey<String>() {
-    };
-    private static final DataKey<String> DEF = new DataKey<String>() {
-    };
-    private static final DataKey<List<String>> LISTY = new DataKey<List<String>>() {
-    };
-    private static final DataKey<List<String>> DING = new DataKey<List<String>>() {
-    };
+    private static final DataKey<String> ABC = new DataKey<String>() {};
+    private static final DataKey<String> DEF = new DataKey<String>() {};
+    private static final DataKey<List<String>> LISTY = new DataKey<List<String>>() {};
+    private static final DataKey<List<String>> DING = new DataKey<List<String>>() {};
 
     @Test
     void addAFewKeysAndSeeIfTheyAreStoredCorrectly() {
@@ -60,7 +55,7 @@ class DataKeyTest {
     void removeWorks() {
         Node node = new SimpleName();
         node.setData(ABC, "Hurray!");
-        
+
         node.removeData(ABC);
 
         assertThat(node.containsData(ABC)).isFalse();
