@@ -21,13 +21,15 @@
 
 package com.github.javaparser.ast.expr;
 
-import org.junit.jupiter.api.Test;
-
 import static org.junit.jupiter.api.Assertions.assertEquals;
 
+import org.junit.jupiter.api.Test;
+
 class AssignExprTest {
     @Test
     void convertOperator() {
-        assertEquals(BinaryExpr.Operator.PLUS, AssignExpr.Operator.PLUS.toBinaryOperator().get());
+        assertEquals(
+                BinaryExpr.Operator.PLUS,
+                AssignExpr.Operator.PLUS.toBinaryOperator().get());
     }
 }
