@@ -21,13 +21,13 @@
 
 package com.github.javaparser.ast.stmt;
 
+import static com.github.javaparser.StaticJavaParser.parseStatement;
+import static org.junit.jupiter.api.Assertions.*;
+
 import com.github.javaparser.ast.type.ClassOrInterfaceType;
 import com.github.javaparser.ast.type.PrimitiveType;
 import org.junit.jupiter.api.Test;
 
-import static com.github.javaparser.StaticJavaParser.parseStatement;
-import static org.junit.jupiter.api.Assertions.*;
-
 class ForEachStmtTest {
     @Test
     void nonFinalPrimitive() {
@@ -41,7 +41,9 @@ class ForEachStmtTest {
     void finalNonPrimitive() {
         ForEachStmt statement = parseStatement("for (final Object o : objs) {}").asForEachStmt();
         assertTrue(statement.hasFinalVariable());
-        assertEquals(new ClassOrInterfaceType(null, "Object"), statement.getVariableDeclarator().getType());
+        assertEquals(
+                new ClassOrInterfaceType(null, "Object"),
+                statement.getVariableDeclarator().getType());
         assertEquals("o", statement.getVariableDeclarator().getName().getIdentifier());
     }
 }
