@@ -21,6 +21,11 @@
 
 package com.github.javaparser.ast.visitor;
 
+import static com.github.javaparser.StaticJavaParser.parseBodyDeclaration;
+import static com.github.javaparser.StaticJavaParser.parseExpression;
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertNull;
+
 import com.github.javaparser.ast.NodeList;
 import com.github.javaparser.ast.body.BodyDeclaration;
 import com.github.javaparser.ast.body.VariableDeclarator;
@@ -29,14 +34,9 @@ import com.github.javaparser.ast.expr.IntegerLiteralExpr;
 import com.github.javaparser.ast.expr.StringLiteralExpr;
 import com.github.javaparser.printer.lexicalpreservation.AbstractLexicalPreservingTest;
 import com.github.javaparser.printer.lexicalpreservation.LexicalPreservingPrinter;
+import com.github.javaparser.utils.LineSeparator;
 import org.junit.jupiter.api.Test;
 
-import static com.github.javaparser.StaticJavaParser.parseBodyDeclaration;
-import static com.github.javaparser.StaticJavaParser.parseExpression;
-import static com.github.javaparser.utils.Utils.SYSTEM_EOL;
-import static org.junit.jupiter.api.Assertions.assertEquals;
-import static org.junit.jupiter.api.Assertions.assertNull;
-
 class ModifierVisitorTest extends AbstractLexicalPreservingTest {
     @Test
     void makeSureParentListsCanBeModified() {
@@ -46,24 +46,26 @@ class ModifierVisitorTest extends AbstractLexicalPreservingTest {
         list.add(new StringLiteralExpr("b"));
         list.add(new StringLiteralExpr("c"));
 
-        list.accept(new ModifierVisitor<Void>() {
-            @Override
-            public Visitable visit(final StringLiteralExpr n, final Void arg) {
-                String v = n.getValue();
+        list.accept(
+                new ModifierVisitor<Void>() {
+                    @Override
+                    public Visitable visit(final StringLiteralExpr n, final Void arg) {
+                        String v = n.getValue();
 
-                list.addFirst(new StringLiteralExpr("extra " + v));
-                list.remove(new StringLiteralExpr("t"));
+                        list.addFirst(new StringLiteralExpr("extra " + v));
+                        list.remove(new StringLiteralExpr("t"));
 
-                if (v.equals("a")) {
-                    return new StringLiteralExpr("x");
-                }
-                if (v.equals("b")) {
-                    return null;
-                }
+                        if (v.equals("a")) {
+                            return new StringLiteralExpr("x");
+                        }
+                        if (v.equals("b")) {
+                            return null;
+                        }
 
-                return n;
-            }
-        }, null);
+                        return n;
+                    }
+                },
+                null);
 
         assertEquals("extra c", list.get(0).getValue());
         assertEquals("extra b", list.get(1).getValue());
@@ -77,28 +79,32 @@ class ModifierVisitorTest extends AbstractLexicalPreservingTest {
     @Test
     void binaryExprReturnsLeftExpressionWhenRightSideIsRemoved() {
         Expression expression = parseExpression("1+2");
-        Visitable result = expression.accept(new ModifierVisitor<Void>() {
-            public Visitable visit(IntegerLiteralExpr integerLiteralExpr, Void arg) {
-                if (integerLiteralExpr.getValue().equals("1")) {
-                    return null;
-                }
-                return integerLiteralExpr;
-            }
-        }, null);
+        Visitable result = expression.accept(
+                new ModifierVisitor<Void>() {
+                    public Visitable visit(IntegerLiteralExpr integerLiteralExpr, Void arg) {
+                        if (integerLiteralExpr.getValue().equals("1")) {
+                            return null;
+                        }
+                        return integerLiteralExpr;
+                    }
+                },
+                null);
         assertEquals("2", result.toString());
     }
 
     @Test
     void binaryExprReturnsRightExpressionWhenLeftSideIsRemoved() {
         final Expression expression = parseExpression("1+2");
-        final Visitable result = expression.accept(new ModifierVisitor<Void>() {
-            public Visitable visit(IntegerLiteralExpr integerLiteralExpr, Void arg) {
-                if (integerLiteralExpr.getValue().equals("2")) {
-                    return null;
-                }
-                return integerLiteralExpr;
-            }
-        }, null);
+        final Visitable result = expression.accept(
+                new ModifierVisitor<Void>() {
+                    public Visitable visit(IntegerLiteralExpr integerLiteralExpr, Void arg) {
+                        if (integerLiteralExpr.getValue().equals("2")) {
+                            return null;
+                        }
+                        return integerLiteralExpr;
+                    }
+                },
+                null);
         assertEquals("1", result.toString());
     }
 
@@ -106,11 +112,13 @@ class ModifierVisitorTest extends AbstractLexicalPreservingTest {
     void fieldDeclarationCantSurviveWithoutVariables() {
         final BodyDeclaration<?> bodyDeclaration = parseBodyDeclaration("int x=1;");
 
-        final Visitable result = bodyDeclaration.accept(new ModifierVisitor<Void>() {
-            public Visitable visit(VariableDeclarator x, Void arg) {
-                return null;
-            }
-        }, null);
+        final Visitable result = bodyDeclaration.accept(
+                new ModifierVisitor<Void>() {
+                    public Visitable visit(VariableDeclarator x, Void arg) {
+                        return null;
+                    }
+                },
+                null);
 
         assertNull(result);
     }
@@ -119,26 +127,27 @@ class ModifierVisitorTest extends AbstractLexicalPreservingTest {
     void variableDeclarationCantSurviveWithoutVariables() {
         final BodyDeclaration<?> bodyDeclaration = parseBodyDeclaration("void x() {int x=1;}");
 
-        final Visitable result = bodyDeclaration.accept(new ModifierVisitor<Void>() {
-            public Visitable visit(VariableDeclarator x, Void arg) {
-                return null;
-            }
-        }, null);
+        final Visitable result = bodyDeclaration.accept(
+                new ModifierVisitor<Void>() {
+                    public Visitable visit(VariableDeclarator x, Void arg) {
+                        return null;
+                    }
+                },
+                null);
 
-        assertEquals("void x() {" + SYSTEM_EOL + "}", result.toString());
+        assertEquals("void x() {" + LineSeparator.SYSTEM + "}", result.toString());
     }
 
     @Test
     void issue2124() {
         ModifierVisitor<Void> modifier = new ModifierVisitor<>();
-        considerCode("\n" +
-                "public class ModifierVisitorTest {\n" +
-                "    private void causesException() {\n" +
-                "        String[] listWithExtraCommaAndEqualElements = {\"a\", \"a\",};\n" +
-                "    }\n" +
-                "}");
+        considerCode("\n" + "public class ModifierVisitorTest {\n"
+                + "    private void causesException() {\n"
+                + "        String[] listWithExtraCommaAndEqualElements = {\"a\", \"a\",};\n"
+                + "    }\n"
+                + "}");
         cu.accept(modifier, null);
-        //there should be no exception
+        // there should be no exception
         LexicalPreservingPrinter.print(cu);
     }
 }
