@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2007-2010 Júlio Vilmar Gesser.
- * Copyright (C) 2011, 2013-2019 The JavaParser Team.
+ * Copyright (C) 2011, 2013-2024 The JavaParser Team.
  *
  * This file is part of JavaParser.
  *
@@ -22,11 +22,12 @@
 package com.github.javaparser.printer;
 
 import com.github.javaparser.ast.body.ClassOrInterfaceDeclaration;
+import com.github.javaparser.printer.configuration.PrinterConfiguration;
 
-public class TestVisitor extends PrettyPrintVisitor {
+public class TestVisitor extends DefaultPrettyPrinterVisitor {
 
-    public TestVisitor(PrettyPrinterConfiguration prettyPrinterConfiguration) {
-        super(prettyPrinterConfiguration);
+    public TestVisitor(PrinterConfiguration configuration, SourcePrinter printer) {
+        super(configuration, printer);
     }
 
     @Override
