@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2007-2010 Júlio Vilmar Gesser.
- * Copyright (C) 2011, 2013-2019 The JavaParser Team.
+ * Copyright (C) 2011, 2013-2024 The JavaParser Team.
  *
  * This file is part of JavaParser.
  *
@@ -21,6 +21,13 @@
 
 package com.github.javaparser.printer.lexicalpreservation;
 
+import static com.github.javaparser.TokenTypes.eolTokenKind;
+import static com.github.javaparser.TokenTypes.spaceTokenKind;
+import static com.github.javaparser.ast.Modifier.Keyword.PUBLIC;
+import static com.github.javaparser.ast.Modifier.createModifierList;
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertTrue;
+
 import com.github.javaparser.GeneratedJavaParserConstants;
 import com.github.javaparser.ast.Modifier;
 import com.github.javaparser.ast.Node;
@@ -40,17 +47,9 @@ import com.github.javaparser.printer.ConcreteSyntaxModel;
 import com.github.javaparser.printer.concretesyntaxmodel.CsmElement;
 import com.github.javaparser.printer.concretesyntaxmodel.CsmToken;
 import com.github.javaparser.printer.lexicalpreservation.LexicalDifferenceCalculator.CsmChild;
-import org.junit.jupiter.api.Test;
-
 import java.io.IOException;
 import java.util.List;
-
-import static com.github.javaparser.TokenTypes.eolTokenKind;
-import static com.github.javaparser.TokenTypes.spaceTokenKind;
-import static com.github.javaparser.ast.Modifier.Keyword.PUBLIC;
-import static com.github.javaparser.ast.Modifier.createModifierList;
-import static org.junit.jupiter.api.Assertions.assertEquals;
-import static org.junit.jupiter.api.Assertions.assertTrue;
+import org.junit.jupiter.api.Test;
 
 class LexicalDifferenceCalculatorTest extends AbstractLexicalPreservingTest {
 
@@ -58,7 +57,8 @@ class LexicalDifferenceCalculatorTest extends AbstractLexicalPreservingTest {
     void compilationUnitExampleOriginal() {
         considerCode("class A {}");
         CsmElement element = ConcreteSyntaxModel.forClass(cu.getClass());
-        LexicalDifferenceCalculator.CalculatedSyntaxModel csmOriginal = new LexicalDifferenceCalculator().calculatedSyntaxModelForNode(element, cu);
+        LexicalDifferenceCalculator.CalculatedSyntaxModel csmOriginal =
+                new LexicalDifferenceCalculator().calculatedSyntaxModelForNode(element, cu);
         assertEquals(2, csmOriginal.elements.size());
         assertEquals(new CsmChild(cu.getType(0)), csmOriginal.elements.get(0));
         assertEquals(new CsmToken(eolTokenKind()), csmOriginal.elements.get(1));
@@ -69,7 +69,9 @@ class LexicalDifferenceCalculatorTest extends AbstractLexicalPreservingTest {
         considerCode("class A {}");
         CsmElement element = ConcreteSyntaxModel.forClass(cu.getClass());
         PackageDeclaration packageDeclaration = new PackageDeclaration(new Name(new Name("foo"), "bar"));
-        LexicalDifferenceCalculator.CalculatedSyntaxModel csmChanged = new LexicalDifferenceCalculator().calculatedSyntaxModelAfterPropertyChange(element, cu, ObservableProperty.PACKAGE_DECLARATION, null, packageDeclaration);
+        LexicalDifferenceCalculator.CalculatedSyntaxModel csmChanged = new LexicalDifferenceCalculator()
+                .calculatedSyntaxModelAfterPropertyChange(
+                        element, cu, ObservableProperty.PACKAGE_DECLARATION, null, packageDeclaration);
         assertEquals(3, csmChanged.elements.size());
         assertEquals(new CsmChild(packageDeclaration), csmChanged.elements.get(0));
         assertEquals(new CsmChild(cu.getType(0)), csmChanged.elements.get(1));
@@ -79,9 +81,10 @@ class LexicalDifferenceCalculatorTest extends AbstractLexicalPreservingTest {
     @Test
     void annotationDeclarationModifiersExampleOriginal() throws IOException {
         considerExample("AnnotationDeclaration_Example1_original");
-        AnnotationDeclaration annotationDeclaration = (AnnotationDeclaration)cu.getType(0);
+        AnnotationDeclaration annotationDeclaration = (AnnotationDeclaration) cu.getType(0);
         CsmElement element = ConcreteSyntaxModel.forClass(annotationDeclaration.getClass());
-        LexicalDifferenceCalculator.CalculatedSyntaxModel csm = new LexicalDifferenceCalculator().calculatedSyntaxModelForNode(element, annotationDeclaration);
+        LexicalDifferenceCalculator.CalculatedSyntaxModel csm =
+                new LexicalDifferenceCalculator().calculatedSyntaxModelForNode(element, annotationDeclaration);
         csm.removeIndentationElements();
         int i = 0;
         assertEquals(new CsmToken(GeneratedJavaParserConstants.AT), csm.elements.get(i++));
@@ -110,9 +113,15 @@ class LexicalDifferenceCalculatorTest extends AbstractLexicalPreservingTest {
     @Test
     void annotationDeclarationModifiersExampleModified() throws IOException {
         considerExample("AnnotationDeclaration_Example1_original");
-        AnnotationDeclaration annotationDeclaration = (AnnotationDeclaration)cu.getType(0);
+        AnnotationDeclaration annotationDeclaration = (AnnotationDeclaration) cu.getType(0);
         CsmElement element = ConcreteSyntaxModel.forClass(annotationDeclaration.getClass());
-        LexicalDifferenceCalculator.CalculatedSyntaxModel csm = new LexicalDifferenceCalculator().calculatedSyntaxModelAfterPropertyChange(element, annotationDeclaration, ObservableProperty.MODIFIERS, new NodeList<>(), createModifierList(PUBLIC));
+        LexicalDifferenceCalculator.CalculatedSyntaxModel csm = new LexicalDifferenceCalculator()
+                .calculatedSyntaxModelAfterPropertyChange(
+                        element,
+                        annotationDeclaration,
+                        ObservableProperty.MODIFIERS,
+                        new NodeList<>(),
+                        createModifierList(PUBLIC));
         csm.removeIndentationElements();
         int i = 0;
         assertEquals(new CsmChild(Modifier.publicModifier()), csm.elements.get(i++));
@@ -143,11 +152,16 @@ class LexicalDifferenceCalculatorTest extends AbstractLexicalPreservingTest {
     @Test
     void annotationDeclarationNameExampleModified() throws IOException {
         considerExample("AnnotationDeclaration_Example1_original");
-        AnnotationDeclaration annotationDeclaration = (AnnotationDeclaration)cu.getType(0);
+        AnnotationDeclaration annotationDeclaration = (AnnotationDeclaration) cu.getType(0);
         CsmElement element = ConcreteSyntaxModel.forClass(annotationDeclaration.getClass());
         SimpleName newName = new SimpleName("NewName");
-        LexicalDifferenceCalculator.CalculatedSyntaxModel csm = new LexicalDifferenceCalculator().calculatedSyntaxModelAfterPropertyChange(element, annotationDeclaration, ObservableProperty.NAME,
-                annotationDeclaration.getName(), newName);
+        LexicalDifferenceCalculator.CalculatedSyntaxModel csm = new LexicalDifferenceCalculator()
+                .calculatedSyntaxModelAfterPropertyChange(
+                        element,
+                        annotationDeclaration,
+                        ObservableProperty.NAME,
+                        annotationDeclaration.getName(),
+                        newName);
         csm.removeIndentationElements();
         int i = 0;
         assertEquals(new CsmToken(GeneratedJavaParserConstants.AT), csm.elements.get(i++));
@@ -176,9 +190,10 @@ class LexicalDifferenceCalculatorTest extends AbstractLexicalPreservingTest {
     @Test
     void annotationDeclarationJavadocExampleOriginal() throws IOException {
         considerExample("AnnotationDeclaration_Example3_original");
-        AnnotationDeclaration annotationDeclaration = (AnnotationDeclaration)cu.getType(0);
+        AnnotationDeclaration annotationDeclaration = (AnnotationDeclaration) cu.getType(0);
         CsmElement element = ConcreteSyntaxModel.forClass(annotationDeclaration.getClass());
-        LexicalDifferenceCalculator.CalculatedSyntaxModel csm = new LexicalDifferenceCalculator().calculatedSyntaxModelForNode(element, annotationDeclaration);
+        LexicalDifferenceCalculator.CalculatedSyntaxModel csm =
+                new LexicalDifferenceCalculator().calculatedSyntaxModelForNode(element, annotationDeclaration);
         csm.removeIndentationElements();
         int i = 0;
         assertEquals(new CsmChild(Modifier.publicModifier()), csm.elements.get(i++));
@@ -209,10 +224,12 @@ class LexicalDifferenceCalculatorTest extends AbstractLexicalPreservingTest {
     @Test
     void annotationDeclarationJavadocExampleAddingJavadoc() throws IOException {
         considerExample("AnnotationDeclaration_Example3_original");
-        AnnotationDeclaration annotationDeclaration = (AnnotationDeclaration)cu.getType(0);
+        AnnotationDeclaration annotationDeclaration = (AnnotationDeclaration) cu.getType(0);
         CsmElement element = ConcreteSyntaxModel.forClass(annotationDeclaration.getClass());
         JavadocComment comment = new JavadocComment("Cool this annotation!");
-        LexicalDifferenceCalculator.CalculatedSyntaxModel csm = new LexicalDifferenceCalculator().calculatedSyntaxModelAfterPropertyChange(element, annotationDeclaration, ObservableProperty.COMMENT, null, comment);
+        LexicalDifferenceCalculator.CalculatedSyntaxModel csm = new LexicalDifferenceCalculator()
+                .calculatedSyntaxModelAfterPropertyChange(
+                        element, annotationDeclaration, ObservableProperty.COMMENT, null, comment);
         csm.removeIndentationElements();
         int i = 0;
         assertEquals(new CsmChild(Modifier.publicModifier()), csm.elements.get(i++));
@@ -243,7 +260,8 @@ class LexicalDifferenceCalculatorTest extends AbstractLexicalPreservingTest {
     @Test
     void simpleEnumConstantDeclaration() {
         EnumConstantDeclaration ecd = considerEcd("A");
-        LexicalDifferenceCalculator.CalculatedSyntaxModel csm = new LexicalDifferenceCalculator().calculatedSyntaxModelForNode(ecd);
+        LexicalDifferenceCalculator.CalculatedSyntaxModel csm =
+                new LexicalDifferenceCalculator().calculatedSyntaxModelForNode(ecd);
 
         int i = 0;
         assertEquals(new CsmChild(ecd.getName()), csm.elements.get(i++));
@@ -255,14 +273,12 @@ class LexicalDifferenceCalculatorTest extends AbstractLexicalPreservingTest {
         LexicalDifferenceCalculator ldc = new LexicalDifferenceCalculator();
         considerExample("ASimpleClassWithMoreFormatting_step3");
 
-        MethodDeclaration setter = cu.getClassByName("MyRenamedClass").get()
-                .getMethodsByName("setAField").get(0);
-        Statement assignStatement = new ExpressionStmt(
-                new AssignExpr(
-                        new FieldAccessExpr(new ThisExpr(),"aField"),
-                        new NameExpr("aField"),
-                        AssignExpr.Operator.ASSIGN
-                ));
+        MethodDeclaration setter = cu.getClassByName("MyRenamedClass")
+                .get()
+                .getMethodsByName("setAField")
+                .get(0);
+        Statement assignStatement = new ExpressionStmt(new AssignExpr(
+                new FieldAccessExpr(new ThisExpr(), "aField"), new NameExpr("aField"), AssignExpr.Operator.ASSIGN));
         LexicalDifferenceCalculator.CalculatedSyntaxModel calculatedSyntaxModel =
                 ldc.calculatedSyntaxModelAfterListAddition(
                         ConcreteSyntaxModel.forClass(BlockStmt.class),
@@ -271,13 +287,15 @@ class LexicalDifferenceCalculatorTest extends AbstractLexicalPreservingTest {
                         0,
                         assignStatement);
         int index = 0;
-        assertEquals(CsmElement.token(GeneratedJavaParserConstants.LBRACE), calculatedSyntaxModel.elements.get(index++));
+        assertEquals(
+                CsmElement.token(GeneratedJavaParserConstants.LBRACE), calculatedSyntaxModel.elements.get(index++));
         assertEquals(CsmElement.newline(), calculatedSyntaxModel.elements.get(index++));
         assertEquals(CsmElement.indent(), calculatedSyntaxModel.elements.get(index++));
         assertTrue(isChild(calculatedSyntaxModel.elements.get(index++), ExpressionStmt.class));
         assertEquals(CsmElement.newline(), calculatedSyntaxModel.elements.get(index++));
         assertEquals(CsmElement.unindent(), calculatedSyntaxModel.elements.get(index++));
-        assertEquals(CsmElement.token(GeneratedJavaParserConstants.RBRACE), calculatedSyntaxModel.elements.get(index++));
+        assertEquals(
+                CsmElement.token(GeneratedJavaParserConstants.RBRACE), calculatedSyntaxModel.elements.get(index++));
         assertEquals(index, calculatedSyntaxModel.elements.size());
     }
 
@@ -286,27 +304,28 @@ class LexicalDifferenceCalculatorTest extends AbstractLexicalPreservingTest {
         LexicalDifferenceCalculator ldc = new LexicalDifferenceCalculator();
         considerExample("ASimpleClassWithMoreFormatting_step3");
 
-        MethodDeclaration setter = cu.getClassByName("MyRenamedClass").get()
-                .getMethodsByName("setAField").get(0);
-        Statement assignStatement = new ExpressionStmt(
-                new AssignExpr(
-                        new FieldAccessExpr(new ThisExpr(),"aField"),
-                        new NameExpr("aField"),
-                        AssignExpr.Operator.ASSIGN
-                ));
+        MethodDeclaration setter = cu.getClassByName("MyRenamedClass")
+                .get()
+                .getMethodsByName("setAField")
+                .get(0);
+        Statement assignStatement = new ExpressionStmt(new AssignExpr(
+                new FieldAccessExpr(new ThisExpr(), "aField"), new NameExpr("aField"), AssignExpr.Operator.ASSIGN));
         List<DifferenceElement> differenceElements = ldc.calculateListAdditionDifference(
-                ObservableProperty.STATEMENTS,
-                setter.getBody().get().getStatements(),
-                0,
-                assignStatement);
+                ObservableProperty.STATEMENTS, setter.getBody().get().getStatements(), 0, assignStatement);
         int index = 0;
-        assertEquals(DifferenceElement.kept(CsmElement.token(GeneratedJavaParserConstants.LBRACE)), differenceElements.get(index++));
+        assertEquals(
+                DifferenceElement.kept(CsmElement.token(GeneratedJavaParserConstants.LBRACE)),
+                differenceElements.get(index++));
         assertEquals(DifferenceElement.kept(CsmElement.newline()), differenceElements.get(index++));
         assertEquals(DifferenceElement.added(CsmElement.indent()), differenceElements.get(index++));
         assertTrue(isAddedChild(differenceElements.get(index++), ExpressionStmt.class));
-        assertEquals(DifferenceElement.added(CsmElement.newline()), differenceElements.get(index++));
+        CsmElement cmsElement = differenceElements.get(index++).getElement();
+        // all end of line tokens are not equal so it's safer to check if it's a token and then a end of line token
+        assertTrue(CsmToken.class.isAssignableFrom(cmsElement.getClass()) && ((CsmToken) cmsElement).isNewLine());
         assertEquals(DifferenceElement.added(CsmElement.unindent()), differenceElements.get(index++));
-        assertEquals(DifferenceElement.kept(CsmElement.token(GeneratedJavaParserConstants.RBRACE)), differenceElements.get(index++));
+        assertEquals(
+                DifferenceElement.kept(CsmElement.token(GeneratedJavaParserConstants.RBRACE)),
+                differenceElements.get(index++));
         assertEquals(index, differenceElements.size());
     }
 
@@ -315,11 +334,11 @@ class LexicalDifferenceCalculatorTest extends AbstractLexicalPreservingTest {
     }
 
     private boolean isChild(CsmElement element, Class<? extends Node> childClass) {
-        return element instanceof CsmChild && childClass.isInstance(((CsmChild)element).getChild());
+        return element instanceof CsmChild && childClass.isInstance(((CsmChild) element).getChild());
     }
 
     protected EnumConstantDeclaration considerEcd(String code) {
         considerCode("enum A { " + code + " }");
-        return ((EnumDeclaration)cu.getType(0)).getEntries().get(0);
+        return ((EnumDeclaration) cu.getType(0)).getEntries().get(0);
     }
 }
