@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2007-2010 Júlio Vilmar Gesser.
- * Copyright (C) 2011, 2013-2020 The JavaParser Team.
+ * Copyright (C) 2011, 2013-2024 The JavaParser Team.
  *
  * This file is part of JavaParser.
  *
@@ -20,12 +20,13 @@
  */
 package com.github.javaparser;
 
+import static com.github.javaparser.utils.CodeGenerationUtils.f;
+import static com.github.javaparser.utils.Utils.assertNotNull;
+
+import com.github.javaparser.ast.Generated;
+import com.github.javaparser.utils.LineSeparator;
 import java.util.List;
 import java.util.Optional;
-import static com.github.javaparser.utils.CodeGenerationUtils.f;
-import static com.github.javaparser.utils.Utils.SYSTEM_EOL;
-import static com.github.javaparser.utils.Utils.assertNotNull;
-import com.github.javaparser.ast.Generated;
 
 /**
  * A token from a parsed source file.
@@ -56,31 +57,34 @@ public class JavaToken {
 
     JavaToken(Token token, List<JavaToken> tokens) {
         // You could be puzzled by the following lines
-        // 
+        //
         // The reason why these lines are necessary is the fact that Java is ambiguous. There are cases where the
         // sequence of characters ">>>" and ">>" should be recognized as the single tokens ">>>" and ">>". In other
         // cases however we want to split those characters in single GT tokens (">").
-        // 
+        //
         // For example, in expressions ">>" and ">>>" are valid, while when defining types we could have this:
-        // 
+        //
         // List<List<Set<String>>>>
-        // 
+        //
         // You can see that the sequence ">>>>" should be interpreted as four consecutive ">" tokens closing a type
         // parameter list.
-        // 
+        //
         // The JavaCC handle this case by first recognizing always the longest token, and then depending on the context
         // putting back the unused chars in the stream. However in those cases the token provided is invalid: it has an
         // image corresponding to the text originally recognized, without considering that after some characters could
         // have been put back into the stream.
-        // 
+        //
         // So in the case of:
-        // 
+        //
         // List<List<Set<String>>>>
-        // ___   -> recognized as ">>>", then ">>" put back in the stream but Token(type=GT, image=">>>") passed to this class
-        // ___  -> recognized as ">>>", then ">>" put back in the stream but Token(type=GT, image=">>>") passed to this class
-        // __  -> recognized as ">>", then ">" put back in the stream but Token(type=GT, image=">>") passed to this class
+        // ___   -> recognized as ">>>", then ">>" put back in the stream but Token(type=GT, image=">>>") passed to this
+        // class
+        // ___  -> recognized as ">>>", then ">>" put back in the stream but Token(type=GT, image=">>>") passed to this
+        // class
+        // __  -> recognized as ">>", then ">" put back in the stream but Token(type=GT, image=">>") passed to this
+        // class
         // _  -> Token(type=GT, image=">") good!
-        // 
+        //
         // So given the image could be wrong but the type is correct, we look at the type of the token and we fix
         // the image. Everybody is happy and we can keep this horrible thing as our little secret.
         Range range = Range.range(token.beginLine, token.beginColumn, token.endLine, token.endColumn);
@@ -113,7 +117,7 @@ public class JavaToken {
             content = content.substring(1, content.length() - 1);
         }
         if (TokenTypes.isEndOfLineToken(kind)) {
-            content = SYSTEM_EOL;
+            content = LineSeparator.SYSTEM.asRawString();
         } else if (TokenTypes.isWhitespace(kind)) {
             content = " ";
         }
@@ -134,6 +138,13 @@ public class JavaToken {
         return Optional.ofNullable(range);
     }
 
+    /*
+     * Returns true if the token has a range
+     */
+    public boolean hasRange() {
+        return getRange().isPresent();
+    }
+
     public int getKind() {
         return kind;
     }
@@ -175,8 +186,14 @@ public class JavaToken {
 
     @Override
     public String toString() {
-        String text = getText().replace("\n", "\\n").replace("\r", "\\r").replace("\r\n", "\\r\\n").replace("\t", "\\t");
-        return f("\"%s\"   <%s>   %s", text, getKind(), getRange().map(Range::toString).orElse("(?)-(?)"));
+        String text = getText()
+                .replace("\n", "\\n")
+                .replace("\r", "\\r")
+                .replace("\r\n", "\\r\\n")
+                .replace("\t", "\\t");
+        return f(
+                "\"%s\"   <%s>   %s",
+                text, getKind(), getRange().map(Range::toString).orElse("(?)-(?)"));
     }
 
     /**
@@ -194,7 +211,6 @@ public class JavaToken {
     }
 
     public enum Category {
-
         WHITESPACE_NO_EOL,
         EOL,
         COMMENT,
@@ -247,7 +263,6 @@ public class JavaToken {
 
     @Generated("com.github.javaparser.generator.core.other.TokenKindGenerator")
     public enum Kind {
-
         EOF(0),
         SPACE(1),
         WINDOWS_EOL(2),
@@ -291,110 +306,115 @@ public class JavaToken {
         LONG(40),
         NATIVE(41),
         NEW(42),
-        NULL(43),
-        PACKAGE(44),
-        PRIVATE(45),
-        PROTECTED(46),
-        PUBLIC(47),
-        RETURN(48),
-        SHORT(49),
-        STATIC(50),
-        STRICTFP(51),
-        SUPER(52),
-        SWITCH(53),
-        SYNCHRONIZED(54),
-        THIS(55),
-        THROW(56),
-        THROWS(57),
-        TRANSIENT(58),
-        TRUE(59),
-        TRY(60),
-        VOID(61),
-        VOLATILE(62),
-        WHILE(63),
-        YIELD(64),
-        REQUIRES(65),
-        TO(66),
-        WITH(67),
-        OPEN(68),
-        OPENS(69),
-        USES(70),
-        MODULE(71),
-        EXPORTS(72),
-        PROVIDES(73),
-        TRANSITIVE(74),
-        LONG_LITERAL(75),
-        INTEGER_LITERAL(76),
-        DECIMAL_LITERAL(77),
-        HEX_LITERAL(78),
-        OCTAL_LITERAL(79),
-        BINARY_LITERAL(80),
-        FLOATING_POINT_LITERAL(81),
-        DECIMAL_FLOATING_POINT_LITERAL(82),
-        DECIMAL_EXPONENT(83),
-        HEXADECIMAL_FLOATING_POINT_LITERAL(84),
-        HEXADECIMAL_EXPONENT(85),
-        HEX_DIGITS(86),
-        UNICODE_ESCAPE(87),
-        CHARACTER_LITERAL(88),
-        STRING_LITERAL(89),
-        ENTER_TEXT_BLOCK(90),
-        TEXT_BLOCK_LITERAL(91),
-        TEXT_BLOCK_CONTENT(92),
-        IDENTIFIER(93),
-        LETTER(94),
-        PART_LETTER(95),
-        LPAREN(96),
-        RPAREN(97),
-        LBRACE(98),
-        RBRACE(99),
-        LBRACKET(100),
-        RBRACKET(101),
-        SEMICOLON(102),
-        COMMA(103),
-        DOT(104),
-        AT(105),
-        ASSIGN(106),
-        LT(107),
-        BANG(108),
-        TILDE(109),
-        HOOK(110),
-        COLON(111),
-        EQ(112),
-        LE(113),
-        GE(114),
-        NE(115),
-        SC_OR(116),
-        SC_AND(117),
-        INCR(118),
-        DECR(119),
-        PLUS(120),
-        MINUS(121),
-        STAR(122),
-        SLASH(123),
-        BIT_AND(124),
-        BIT_OR(125),
-        XOR(126),
-        REM(127),
-        LSHIFT(128),
-        PLUSASSIGN(129),
-        MINUSASSIGN(130),
-        STARASSIGN(131),
-        SLASHASSIGN(132),
-        ANDASSIGN(133),
-        ORASSIGN(134),
-        XORASSIGN(135),
-        REMASSIGN(136),
-        LSHIFTASSIGN(137),
-        RSIGNEDSHIFTASSIGN(138),
-        RUNSIGNEDSHIFTASSIGN(139),
-        ELLIPSIS(140),
-        ARROW(141),
-        DOUBLECOLON(142),
-        RUNSIGNEDSHIFT(143),
-        RSIGNEDSHIFT(144),
-        GT(145),
-        CTRL_Z(146);
+        NON_SEALED(43),
+        NULL(44),
+        PACKAGE(45),
+        PERMITS(46),
+        PRIVATE(47),
+        PROTECTED(48),
+        PUBLIC(49),
+        RECORD(50),
+        RETURN(51),
+        SEALED(52),
+        SHORT(53),
+        STATIC(54),
+        STRICTFP(55),
+        SUPER(56),
+        SWITCH(57),
+        SYNCHRONIZED(58),
+        THIS(59),
+        THROW(60),
+        THROWS(61),
+        TRANSIENT(62),
+        TRUE(63),
+        TRY(64),
+        VOID(65),
+        VOLATILE(66),
+        WHILE(67),
+        YIELD(68),
+        REQUIRES(69),
+        TO(70),
+        WITH(71),
+        OPEN(72),
+        OPENS(73),
+        USES(74),
+        MODULE(75),
+        EXPORTS(76),
+        PROVIDES(77),
+        TRANSITIVE(78),
+        WHEN(79),
+        LONG_LITERAL(80),
+        INTEGER_LITERAL(81),
+        DECIMAL_LITERAL(82),
+        HEX_LITERAL(83),
+        OCTAL_LITERAL(84),
+        BINARY_LITERAL(85),
+        FLOATING_POINT_LITERAL(86),
+        DECIMAL_FLOATING_POINT_LITERAL(87),
+        DECIMAL_EXPONENT(88),
+        HEXADECIMAL_FLOATING_POINT_LITERAL(89),
+        HEXADECIMAL_EXPONENT(90),
+        HEX_DIGITS(91),
+        UNICODE_ESCAPE(92),
+        CHARACTER_LITERAL(93),
+        STRING_LITERAL(94),
+        ENTER_TEXT_BLOCK(95),
+        TEXT_BLOCK_LITERAL(96),
+        TEXT_BLOCK_CONTENT(97),
+        IDENTIFIER(98),
+        LETTER(99),
+        PART_LETTER(100),
+        LPAREN(101),
+        RPAREN(102),
+        LBRACE(103),
+        RBRACE(104),
+        LBRACKET(105),
+        RBRACKET(106),
+        SEMICOLON(107),
+        COMMA(108),
+        DOT(109),
+        ELLIPSIS(110),
+        AT(111),
+        DOUBLECOLON(112),
+        ASSIGN(113),
+        LT(114),
+        BANG(115),
+        TILDE(116),
+        HOOK(117),
+        COLON(118),
+        ARROW(119),
+        EQ(120),
+        GE(121),
+        LE(122),
+        NE(123),
+        SC_AND(124),
+        SC_OR(125),
+        INCR(126),
+        DECR(127),
+        PLUS(128),
+        MINUS(129),
+        STAR(130),
+        SLASH(131),
+        BIT_AND(132),
+        BIT_OR(133),
+        XOR(134),
+        REM(135),
+        LSHIFT(136),
+        PLUSASSIGN(137),
+        MINUSASSIGN(138),
+        STARASSIGN(139),
+        SLASHASSIGN(140),
+        ANDASSIGN(141),
+        ORASSIGN(142),
+        XORASSIGN(143),
+        REMASSIGN(144),
+        LSHIFTASSIGN(145),
+        RSIGNEDSHIFTASSIGN(146),
+        RUNSIGNEDSHIFTASSIGN(147),
+        RUNSIGNEDSHIFT(148),
+        RSIGNEDSHIFT(149),
+        GT(150),
+        CTRL_Z(151);
 
         private final int kind;
 
@@ -403,215 +423,225 @@ public class JavaToken {
         }
 
         public static Kind valueOf(int kind) {
-            switch(kind) {
-                case 146:
+            switch (kind) {
+                case 151:
                     return CTRL_Z;
-                case 145:
+                case 150:
                     return GT;
-                case 144:
+                case 149:
                     return RSIGNEDSHIFT;
-                case 143:
+                case 148:
                     return RUNSIGNEDSHIFT;
-                case 142:
-                    return DOUBLECOLON;
-                case 141:
-                    return ARROW;
-                case 140:
-                    return ELLIPSIS;
-                case 139:
+                case 147:
                     return RUNSIGNEDSHIFTASSIGN;
-                case 138:
+                case 146:
                     return RSIGNEDSHIFTASSIGN;
-                case 137:
+                case 145:
                     return LSHIFTASSIGN;
-                case 136:
+                case 144:
                     return REMASSIGN;
-                case 135:
+                case 143:
                     return XORASSIGN;
-                case 134:
+                case 142:
                     return ORASSIGN;
-                case 133:
+                case 141:
                     return ANDASSIGN;
-                case 132:
+                case 140:
                     return SLASHASSIGN;
-                case 131:
+                case 139:
                     return STARASSIGN;
-                case 130:
+                case 138:
                     return MINUSASSIGN;
-                case 129:
+                case 137:
                     return PLUSASSIGN;
-                case 128:
+                case 136:
                     return LSHIFT;
-                case 127:
+                case 135:
                     return REM;
-                case 126:
+                case 134:
                     return XOR;
-                case 125:
+                case 133:
                     return BIT_OR;
-                case 124:
+                case 132:
                     return BIT_AND;
-                case 123:
+                case 131:
                     return SLASH;
-                case 122:
+                case 130:
                     return STAR;
-                case 121:
+                case 129:
                     return MINUS;
-                case 120:
+                case 128:
                     return PLUS;
-                case 119:
+                case 127:
                     return DECR;
-                case 118:
+                case 126:
                     return INCR;
-                case 117:
-                    return SC_AND;
-                case 116:
+                case 125:
                     return SC_OR;
-                case 115:
+                case 124:
+                    return SC_AND;
+                case 123:
                     return NE;
-                case 114:
-                    return GE;
-                case 113:
+                case 122:
                     return LE;
-                case 112:
+                case 121:
+                    return GE;
+                case 120:
                     return EQ;
-                case 111:
+                case 119:
+                    return ARROW;
+                case 118:
                     return COLON;
-                case 110:
+                case 117:
                     return HOOK;
-                case 109:
+                case 116:
                     return TILDE;
-                case 108:
+                case 115:
                     return BANG;
-                case 107:
+                case 114:
                     return LT;
-                case 106:
+                case 113:
                     return ASSIGN;
-                case 105:
+                case 112:
+                    return DOUBLECOLON;
+                case 111:
                     return AT;
-                case 104:
+                case 110:
+                    return ELLIPSIS;
+                case 109:
                     return DOT;
-                case 103:
+                case 108:
                     return COMMA;
-                case 102:
+                case 107:
                     return SEMICOLON;
-                case 101:
+                case 106:
                     return RBRACKET;
-                case 100:
+                case 105:
                     return LBRACKET;
-                case 99:
+                case 104:
                     return RBRACE;
-                case 98:
+                case 103:
                     return LBRACE;
-                case 97:
+                case 102:
                     return RPAREN;
-                case 96:
+                case 101:
                     return LPAREN;
-                case 95:
+                case 100:
                     return PART_LETTER;
-                case 94:
+                case 99:
                     return LETTER;
-                case 93:
+                case 98:
                     return IDENTIFIER;
-                case 92:
+                case 97:
                     return TEXT_BLOCK_CONTENT;
-                case 91:
+                case 96:
                     return TEXT_BLOCK_LITERAL;
-                case 90:
+                case 95:
                     return ENTER_TEXT_BLOCK;
-                case 89:
+                case 94:
                     return STRING_LITERAL;
-                case 88:
+                case 93:
                     return CHARACTER_LITERAL;
-                case 87:
+                case 92:
                     return UNICODE_ESCAPE;
-                case 86:
+                case 91:
                     return HEX_DIGITS;
-                case 85:
+                case 90:
                     return HEXADECIMAL_EXPONENT;
-                case 84:
+                case 89:
                     return HEXADECIMAL_FLOATING_POINT_LITERAL;
-                case 83:
+                case 88:
                     return DECIMAL_EXPONENT;
-                case 82:
+                case 87:
                     return DECIMAL_FLOATING_POINT_LITERAL;
-                case 81:
+                case 86:
                     return FLOATING_POINT_LITERAL;
-                case 80:
+                case 85:
                     return BINARY_LITERAL;
-                case 79:
+                case 84:
                     return OCTAL_LITERAL;
-                case 78:
+                case 83:
                     return HEX_LITERAL;
-                case 77:
+                case 82:
                     return DECIMAL_LITERAL;
-                case 76:
+                case 81:
                     return INTEGER_LITERAL;
-                case 75:
+                case 80:
                     return LONG_LITERAL;
-                case 74:
+                case 79:
+                    return WHEN;
+                case 78:
                     return TRANSITIVE;
-                case 73:
+                case 77:
                     return PROVIDES;
-                case 72:
+                case 76:
                     return EXPORTS;
-                case 71:
+                case 75:
                     return MODULE;
-                case 70:
+                case 74:
                     return USES;
-                case 69:
+                case 73:
                     return OPENS;
-                case 68:
+                case 72:
                     return OPEN;
-                case 67:
+                case 71:
                     return WITH;
-                case 66:
+                case 70:
                     return TO;
-                case 65:
+                case 69:
                     return REQUIRES;
-                case 64:
+                case 68:
                     return YIELD;
-                case 63:
+                case 67:
                     return WHILE;
-                case 62:
+                case 66:
                     return VOLATILE;
-                case 61:
+                case 65:
                     return VOID;
-                case 60:
+                case 64:
                     return TRY;
-                case 59:
+                case 63:
                     return TRUE;
-                case 58:
+                case 62:
                     return TRANSIENT;
-                case 57:
+                case 61:
                     return THROWS;
-                case 56:
+                case 60:
                     return THROW;
-                case 55:
+                case 59:
                     return THIS;
-                case 54:
+                case 58:
                     return SYNCHRONIZED;
-                case 53:
+                case 57:
                     return SWITCH;
-                case 52:
+                case 56:
                     return SUPER;
-                case 51:
+                case 55:
                     return STRICTFP;
-                case 50:
+                case 54:
                     return STATIC;
-                case 49:
+                case 53:
                     return SHORT;
-                case 48:
+                case 52:
+                    return SEALED;
+                case 51:
                     return RETURN;
-                case 47:
+                case 50:
+                    return RECORD;
+                case 49:
                     return PUBLIC;
-                case 46:
+                case 48:
                     return PROTECTED;
-                case 45:
+                case 47:
                     return PRIVATE;
-                case 44:
+                case 46:
+                    return PERMITS;
+                case 45:
                     return PACKAGE;
-                case 43:
+                case 44:
                     return NULL;
+                case 43:
+                    return NON_SEALED;
                 case 42:
                     return NEW;
                 case 41:
@@ -704,7 +734,13 @@ public class JavaToken {
         }
 
         public boolean isPrimitive() {
-            return this == BYTE || this == CHAR || this == SHORT || this == INT || this == LONG || this == FLOAT || this == DOUBLE;
+            return this == BYTE
+                    || this == CHAR
+                    || this == SHORT
+                    || this == INT
+                    || this == LONG
+                    || this == FLOAT
+                    || this == DOUBLE;
         }
 
         public int getKind() {
@@ -798,15 +834,11 @@ public class JavaToken {
 
     @Override
     public boolean equals(Object o) {
-        if (this == o)
-            return true;
-        if (o == null || getClass() != o.getClass())
-            return false;
+        if (this == o) return true;
+        if (o == null || getClass() != o.getClass()) return false;
         JavaToken javaToken = (JavaToken) o;
-        if (kind != javaToken.kind)
-            return false;
-        if (!text.equals(javaToken.text))
-            return false;
+        if (kind != javaToken.kind) return false;
+        if (!text.equals(javaToken.text)) return false;
         return true;
     }
 }
