@@ -17,7 +17,6 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU Lesser General Public License for more details.
  */
-
 package com.github.javaparser;
 
 import com.github.javaparser.ast.Node;
@@ -27,8 +26,7 @@ public class Processor {
     /**
      * Makes the parser do a post-parsing step before the result is returned to the user.
      */
-    public void postProcess(ParseResult<? extends Node> result, ParserConfiguration configuration) {
-    }
+    public void postProcess(ParseResult<? extends Node> result, ParserConfiguration configuration) {}
 
     /**
      *  Adds a pre-parsing step, which has access to the sourcecode through the innerProvider.
