@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2007-2010 Júlio Vilmar Gesser.
- * Copyright (C) 2011, 2013-2020 The JavaParser Team.
+ * Copyright (C) 2011, 2013-2024 The JavaParser Team.
  *
  * This file is part of JavaParser.
  *
@@ -20,11 +20,18 @@
  */
 package com.github.javaparser.ast;
 
+import static com.github.javaparser.JavaToken.Kind.EOF;
+import static com.github.javaparser.Providers.UTF8;
+import static com.github.javaparser.Providers.provider;
+import static com.github.javaparser.Range.range;
+import static com.github.javaparser.StaticJavaParser.parseImport;
+import static com.github.javaparser.StaticJavaParser.parseName;
+import static com.github.javaparser.ast.Modifier.createModifierList;
+import static com.github.javaparser.utils.CodeGenerationUtils.subtractPaths;
+import static com.github.javaparser.utils.Utils.assertNotNull;
+
 import com.github.javaparser.*;
-import com.github.javaparser.ast.body.AnnotationDeclaration;
-import com.github.javaparser.ast.body.ClassOrInterfaceDeclaration;
-import com.github.javaparser.ast.body.EnumDeclaration;
-import com.github.javaparser.ast.body.TypeDeclaration;
+import com.github.javaparser.ast.body.*;
 import com.github.javaparser.ast.comments.Comment;
 import com.github.javaparser.ast.comments.JavadocComment;
 import com.github.javaparser.ast.expr.Name;
@@ -38,7 +45,8 @@ import com.github.javaparser.metamodel.CompilationUnitMetaModel;
 import com.github.javaparser.metamodel.InternalProperty;
 import com.github.javaparser.metamodel.JavaParserMetaModel;
 import com.github.javaparser.metamodel.OptionalProperty;
-import com.github.javaparser.printer.PrettyPrinter;
+import com.github.javaparser.printer.Printer;
+import com.github.javaparser.printer.configuration.PrinterConfiguration;
 import com.github.javaparser.utils.ClassUtils;
 import com.github.javaparser.utils.CodeGenerationUtils;
 import com.github.javaparser.utils.Utils;
@@ -51,18 +59,7 @@ import java.util.List;
 import java.util.Objects;
 import java.util.Optional;
 import java.util.function.Function;
-import static com.github.javaparser.JavaToken.Kind.EOF;
-import static com.github.javaparser.Providers.UTF8;
-import static com.github.javaparser.Providers.provider;
-import static com.github.javaparser.Range.range;
-import static com.github.javaparser.StaticJavaParser.parseImport;
-import static com.github.javaparser.StaticJavaParser.parseName;
-import static com.github.javaparser.ast.Modifier.createModifierList;
-import static com.github.javaparser.utils.CodeGenerationUtils.subtractPaths;
-import static com.github.javaparser.utils.Utils.assertNotNull;
-import com.github.javaparser.ast.Node;
-import com.github.javaparser.TokenRange;
-import com.github.javaparser.ast.Generated;
+import java.util.stream.Collectors;
 
 /**
  * <p>
@@ -105,7 +102,11 @@ public class CompilationUnit extends Node {
     }
 
     @AllFieldsConstructor
-    public CompilationUnit(PackageDeclaration packageDeclaration, NodeList<ImportDeclaration> imports, NodeList<TypeDeclaration<?>> types, ModuleDeclaration module) {
+    public CompilationUnit(
+            PackageDeclaration packageDeclaration,
+            NodeList<ImportDeclaration> imports,
+            NodeList<TypeDeclaration<?>> types,
+            ModuleDeclaration module) {
         this(null, packageDeclaration, imports, types, module);
     }
 
@@ -113,7 +114,12 @@ public class CompilationUnit extends Node {
      * This constructor is used by the parser and is considered private.
      */
     @Generated("com.github.javaparser.generator.core.node.MainConstructorGenerator")
-    public CompilationUnit(TokenRange tokenRange, PackageDeclaration packageDeclaration, NodeList<ImportDeclaration> imports, NodeList<TypeDeclaration<?>> types, ModuleDeclaration module) {
+    public CompilationUnit(
+            TokenRange tokenRange,
+            PackageDeclaration packageDeclaration,
+            NodeList<ImportDeclaration> imports,
+            NodeList<TypeDeclaration<?>> types,
+            ModuleDeclaration module) {
         super(tokenRange);
         setPackageDeclaration(packageDeclaration);
         setImports(imports);
@@ -134,6 +140,37 @@ public class CompilationUnit extends Node {
         v.visit(this, arg);
     }
 
+    /**
+     * Declare a specific printer
+     */
+    public CompilationUnit printer(Printer printer) {
+        setData(PRINTER_KEY, printer);
+        return this;
+    }
+
+    /*
+     * If there is no declared printer, returns a new default printer else returns a new printer with the current configuration
+     */
+    @Override
+    protected Printer getPrinter() {
+        if (!containsData(PRINTER_KEY)) {
+            // create a default printer
+            Printer printer = createDefaultPrinter();
+            printer(printer);
+        }
+        return getData(PRINTER_KEY);
+    }
+
+    /*
+     * Return the printer initialized with the specified configuration
+     */
+    @Override
+    protected Printer getPrinter(PrinterConfiguration config) {
+        Printer printer = getPrinter().setConfiguration(config);
+        printer(printer);
+        return printer;
+    }
+
     /**
      * @deprecated getComments was a too generic name and it could be confused with getComment
      * or getAllContainedComments
@@ -224,11 +261,10 @@ public class CompilationUnit extends Node {
     public CompilationUnit setImports(final NodeList<ImportDeclaration> imports) {
         assertNotNull(imports);
         if (imports == this.imports) {
-            return (CompilationUnit) this;
+            return this;
         }
         notifyPropertyChange(ObservableProperty.IMPORTS, this.imports, imports);
-        if (this.imports != null)
-            this.imports.setParentNode(null);
+        if (this.imports != null) this.imports.setParentNode(null);
         this.imports = imports;
         setAsParentNodeOf(imports);
         return this;
@@ -248,9 +284,19 @@ public class CompilationUnit extends Node {
      */
     public CompilationUnit addImport(ImportDeclaration importDeclaration) {
         if (importDeclaration.isAsterisk()) {
-            getImports().removeIf(im -> Objects.equals(getImportPackageName(im).get(), getImportPackageName(importDeclaration).orElse(null)));
+            getImports()
+                    .removeIf(im -> Objects.equals(
+                            getImportPackageName(im).get(),
+                            getImportPackageName(importDeclaration).orElse(null)));
         }
-        if (!isImplicitImport(importDeclaration) && getImports().stream().noneMatch(im -> im.equals(importDeclaration) || (im.isAsterisk() && Objects.equals(getImportPackageName(im).get(), getImportPackageName(importDeclaration).orElse(null))))) {
+        if (!isImplicitImport(importDeclaration)
+                && getImports().stream()
+                        .noneMatch(im -> im.equals(importDeclaration)
+                                || (im.isAsterisk()
+                                        && Objects.equals(
+                                                getImportPackageName(im).get(),
+                                                getImportPackageName(importDeclaration)
+                                                        .orElse(null))))) {
             getImports().add(importDeclaration);
         }
         return this;
@@ -273,14 +319,15 @@ public class CompilationUnit extends Node {
                 return currentPackageName.equals(importPackageName.get());
             }
             return false;
-        } else {
-            // imports of unnamed package are not allowed
-            return true;
         }
+        return true;
     }
 
     private static Optional<Name> getImportPackageName(ImportDeclaration importDeclaration) {
-        return (importDeclaration.isAsterisk() ? new Name(importDeclaration.getName(), "*") : importDeclaration.getName()).getQualifier();
+        return (importDeclaration.isAsterisk()
+                        ? new Name(importDeclaration.getName(), "*")
+                        : importDeclaration.getName())
+                .getQualifier();
     }
 
     /**
@@ -291,11 +338,10 @@ public class CompilationUnit extends Node {
     @Generated("com.github.javaparser.generator.core.node.PropertyGenerator")
     public CompilationUnit setPackageDeclaration(final PackageDeclaration packageDeclaration) {
         if (packageDeclaration == this.packageDeclaration) {
-            return (CompilationUnit) this;
+            return this;
         }
         notifyPropertyChange(ObservableProperty.PACKAGE_DECLARATION, this.packageDeclaration, packageDeclaration);
-        if (this.packageDeclaration != null)
-            this.packageDeclaration.setParentNode(null);
+        if (this.packageDeclaration != null) this.packageDeclaration.setParentNode(null);
         this.packageDeclaration = packageDeclaration;
         setAsParentNodeOf(packageDeclaration);
         return this;
@@ -308,11 +354,10 @@ public class CompilationUnit extends Node {
     public CompilationUnit setTypes(final NodeList<TypeDeclaration<?>> types) {
         assertNotNull(types);
         if (types == this.types) {
-            return (CompilationUnit) this;
+            return this;
         }
         notifyPropertyChange(ObservableProperty.TYPES, this.types, types);
-        if (this.types != null)
-            this.types.setParentNode(null);
+        if (this.types != null) this.types.setParentNode(null);
         this.types = types;
         setAsParentNodeOf(types);
         return this;
@@ -368,10 +413,11 @@ public class CompilationUnit extends Node {
         if (clazz.isArray()) {
             return addImport(clazz.getComponentType());
         }
-        if (ClassUtils.isPrimitiveOrWrapper(clazz) || JAVA_LANG.equals(clazz.getPackage().getName()))
-            return this;
-        else if (clazz.isAnonymousClass() || clazz.isLocalClass())
-            throw new IllegalArgumentException(clazz.getName() + " is an anonymous or local class therefore it can't be added with addImport");
+        if (ClassUtils.isPrimitiveOrWrapper(clazz)
+                || JAVA_LANG.equals(clazz.getPackage().getName())) return this;
+        if (clazz.isAnonymousClass() || clazz.isLocalClass())
+            throw new IllegalArgumentException(
+                    clazz.getName() + " is an anonymous or local class therefore it can't be added with addImport");
         return addImport(clazz.getCanonicalName());
     }
 
@@ -418,7 +464,8 @@ public class CompilationUnit extends Node {
      * @return the newly created class
      */
     public ClassOrInterfaceDeclaration addClass(String name, Modifier.Keyword... modifiers) {
-        ClassOrInterfaceDeclaration classOrInterfaceDeclaration = new ClassOrInterfaceDeclaration(createModifierList(modifiers), false, name);
+        ClassOrInterfaceDeclaration classOrInterfaceDeclaration =
+                new ClassOrInterfaceDeclaration(createModifierList(modifiers), false, name);
         getTypes().add(classOrInterfaceDeclaration);
         return classOrInterfaceDeclaration;
     }
@@ -441,7 +488,8 @@ public class CompilationUnit extends Node {
      * @return the newly created class
      */
     public ClassOrInterfaceDeclaration addInterface(String name, Modifier.Keyword... modifiers) {
-        ClassOrInterfaceDeclaration classOrInterfaceDeclaration = new ClassOrInterfaceDeclaration(createModifierList(modifiers), true, name);
+        ClassOrInterfaceDeclaration classOrInterfaceDeclaration =
+                new ClassOrInterfaceDeclaration(createModifierList(modifiers), true, name);
         getTypes().add(classOrInterfaceDeclaration);
         return classOrInterfaceDeclaration;
     }
@@ -498,7 +546,23 @@ public class CompilationUnit extends Node {
      * @param className the class name (case-sensitive)
      */
     public Optional<ClassOrInterfaceDeclaration> getClassByName(String className) {
-        return getTypes().stream().filter(type -> type.getNameAsString().equals(className) && type instanceof ClassOrInterfaceDeclaration && !((ClassOrInterfaceDeclaration) type).isInterface()).findFirst().map(t -> (ClassOrInterfaceDeclaration) t);
+        return getTypes().stream()
+                .filter(type -> type.getNameAsString().equals(className)
+                        && type instanceof ClassOrInterfaceDeclaration
+                        && !((ClassOrInterfaceDeclaration) type).isInterface())
+                .findFirst()
+                .map(t -> (ClassOrInterfaceDeclaration) t);
+    }
+
+    /**
+     * Try to get all local class declarations ending by its name (top level or inner class)
+     *
+     * @param className the class name (case-sensitive)
+     */
+    public List<ClassOrInterfaceDeclaration> getLocalDeclarationFromClassname(String className) {
+        return findAll(ClassOrInterfaceDeclaration.class).stream()
+                .filter(cid -> cid.getFullyQualifiedName().get().endsWith(className))
+                .collect(Collectors.toList());
     }
 
     /**
@@ -507,7 +571,12 @@ public class CompilationUnit extends Node {
      * @param interfaceName the interface name (case-sensitive)
      */
     public Optional<ClassOrInterfaceDeclaration> getInterfaceByName(String interfaceName) {
-        return getTypes().stream().filter(type -> type.getNameAsString().equals(interfaceName) && type instanceof ClassOrInterfaceDeclaration && ((ClassOrInterfaceDeclaration) type).isInterface()).findFirst().map(t -> (ClassOrInterfaceDeclaration) t);
+        return getTypes().stream()
+                .filter(type -> type.getNameAsString().equals(interfaceName)
+                        && type instanceof ClassOrInterfaceDeclaration
+                        && ((ClassOrInterfaceDeclaration) type).isInterface())
+                .findFirst()
+                .map(t -> (ClassOrInterfaceDeclaration) t);
     }
 
     /**
@@ -516,7 +585,10 @@ public class CompilationUnit extends Node {
      * @param enumName the enum name (case-sensitive)
      */
     public Optional<EnumDeclaration> getEnumByName(String enumName) {
-        return getTypes().stream().filter(type -> type.getNameAsString().equals(enumName) && type instanceof EnumDeclaration).findFirst().map(t -> (EnumDeclaration) t);
+        return getTypes().stream()
+                .filter(type -> type.getNameAsString().equals(enumName) && type instanceof EnumDeclaration)
+                .findFirst()
+                .map(t -> (EnumDeclaration) t);
     }
 
     /**
@@ -533,7 +605,9 @@ public class CompilationUnit extends Node {
      * If for some strange reason there are multiple types of this name, the first one is returned.
      */
     public Optional<TypeDeclaration<?>> getPrimaryType() {
-        return getPrimaryTypeName().flatMap(name -> getTypes().stream().filter(t -> t.getNameAsString().equals(name)).findFirst());
+        return getPrimaryTypeName().flatMap(name -> getTypes().stream()
+                .filter(t -> t.getNameAsString().equals(name))
+                .findFirst());
     }
 
     /**
@@ -542,14 +616,30 @@ public class CompilationUnit extends Node {
      * @param annotationName the annotation name (case-sensitive)
      */
     public Optional<AnnotationDeclaration> getAnnotationDeclarationByName(String annotationName) {
-        return getTypes().stream().filter(type -> type.getNameAsString().equals(annotationName) && type instanceof AnnotationDeclaration).findFirst().map(t -> (AnnotationDeclaration) t);
+        return getTypes().stream()
+                .filter(type -> type.getNameAsString().equals(annotationName) && type instanceof AnnotationDeclaration)
+                .findFirst()
+                .map(t -> (AnnotationDeclaration) t);
+    }
+
+    /**
+     * Try to get a top level record declaration by its name
+     *
+     * @param recordName the enum name (case-sensitive)
+     */
+    public Optional<RecordDeclaration> getRecordByName(String recordName) {
+        return getTypes().stream()
+                .filter(type -> type.getNameAsString().equals(recordName) && type instanceof RecordDeclaration)
+                .findFirst()
+                .map(t -> (RecordDeclaration) t);
     }
 
     @Override
     @Generated("com.github.javaparser.generator.core.node.RemoveMethodGenerator")
     public boolean remove(Node node) {
-        if (node == null)
+        if (node == null) {
             return false;
+        }
         for (int i = 0; i < imports.size(); i++) {
             if (imports.get(i) == node) {
                 imports.remove(i);
@@ -593,11 +683,10 @@ public class CompilationUnit extends Node {
     @Generated("com.github.javaparser.generator.core.node.PropertyGenerator")
     public CompilationUnit setModule(final ModuleDeclaration module) {
         if (module == this.module) {
-            return (CompilationUnit) this;
+            return this;
         }
         notifyPropertyChange(ObservableProperty.MODULE, this.module, module);
-        if (this.module != null)
-            this.module.setParentNode(null);
+        if (this.module != null) this.module.setParentNode(null);
         this.module = module;
         setAsParentNodeOf(module);
         return this;
@@ -670,9 +759,7 @@ public class CompilationUnit extends Node {
         private final Charset encoding;
 
         private Storage(CompilationUnit compilationUnit, Path path) {
-            this.compilationUnit = compilationUnit;
-            this.path = path.toAbsolutePath();
-            this.encoding = UTF8;
+            this(compilationUnit, path, UTF8);
         }
 
         private Storage(CompilationUnit compilationUnit, Path path, Charset encoding) {
@@ -708,8 +795,12 @@ public class CompilationUnit extends Node {
          * of the path) a RuntimeException is thrown.
          */
         public Path getSourceRoot() {
-            final Optional<String> pkgAsString = compilationUnit.getPackageDeclaration().map(NodeWithName::getNameAsString);
-            return pkgAsString.map(p -> Paths.get(CodeGenerationUtils.packageToPath(p))).map(pkg -> subtractPaths(getDirectory(), pkg)).orElse(getDirectory());
+            final Optional<String> pkgAsString =
+                    compilationUnit.getPackageDeclaration().map(NodeWithName::getNameAsString);
+            return pkgAsString
+                    .map(p -> Paths.get(CodeGenerationUtils.packageToPath(p)))
+                    .map(pkg -> subtractPaths(getDirectory(), pkg))
+                    .orElseGet(() -> getDirectory());
         }
 
         public String getFileName() {
@@ -724,7 +815,7 @@ public class CompilationUnit extends Node {
          * Saves the compilation unit to its original location
          */
         public void save() {
-            save(cu -> new PrettyPrinter().print(cu));
+            save(cu -> compilationUnit.getPrinter().print(cu));
         }
 
         /**
@@ -778,8 +869,9 @@ public class CompilationUnit extends Node {
     @Override
     @Generated("com.github.javaparser.generator.core.node.ReplaceMethodGenerator")
     public boolean replace(Node node, Node replacementNode) {
-        if (node == null)
+        if (node == null) {
             return false;
+        }
         for (int i = 0; i < imports.size(); i++) {
             if (imports.get(i) == node) {
                 imports.set(i, (ImportDeclaration) replacementNode);
