@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2007-2010 Júlio Vilmar Gesser.
- * Copyright (C) 2011, 2013-2020 The JavaParser Team.
+ * Copyright (C) 2011, 2013-2024 The JavaParser Team.
  *
  * This file is part of JavaParser.
  *
@@ -20,6 +20,13 @@
  */
 package com.github.javaparser.ast;
 
+import static com.github.javaparser.ast.Node.Parsedness.PARSED;
+import static com.github.javaparser.ast.Node.TreeTraversal.PREORDER;
+import static java.util.Collections.emptySet;
+import static java.util.Collections.unmodifiableList;
+import static java.util.Spliterator.DISTINCT;
+import static java.util.Spliterator.NONNULL;
+
 import com.github.javaparser.HasParentNode;
 import com.github.javaparser.Position;
 import com.github.javaparser.Range;
@@ -27,7 +34,9 @@ import com.github.javaparser.TokenRange;
 import com.github.javaparser.ast.comments.BlockComment;
 import com.github.javaparser.ast.comments.Comment;
 import com.github.javaparser.ast.comments.LineComment;
+import com.github.javaparser.ast.nodeTypes.NodeWithOptionalScope;
 import com.github.javaparser.ast.nodeTypes.NodeWithRange;
+import com.github.javaparser.ast.nodeTypes.NodeWithScope;
 import com.github.javaparser.ast.nodeTypes.NodeWithTokenRange;
 import com.github.javaparser.ast.observer.AstObserver;
 import com.github.javaparser.ast.observer.ObservableProperty;
@@ -36,16 +45,15 @@ import com.github.javaparser.ast.visitor.CloneVisitor;
 import com.github.javaparser.ast.visitor.EqualsVisitor;
 import com.github.javaparser.ast.visitor.HashCodeVisitor;
 import com.github.javaparser.ast.visitor.Visitable;
-import com.github.javaparser.metamodel.InternalProperty;
-import com.github.javaparser.metamodel.JavaParserMetaModel;
-import com.github.javaparser.metamodel.NodeMetaModel;
-import com.github.javaparser.metamodel.OptionalProperty;
-import com.github.javaparser.metamodel.PropertyMetaModel;
-import com.github.javaparser.printer.PrettyPrinter;
-import com.github.javaparser.printer.PrettyPrinterConfiguration;
+import com.github.javaparser.metamodel.*;
+import com.github.javaparser.printer.DefaultPrettyPrinter;
+import com.github.javaparser.printer.Printer;
+import com.github.javaparser.printer.configuration.DefaultConfigurationOption;
+import com.github.javaparser.printer.configuration.DefaultPrinterConfiguration;
+import com.github.javaparser.printer.configuration.DefaultPrinterConfiguration.ConfigOption;
+import com.github.javaparser.printer.configuration.PrinterConfiguration;
 import com.github.javaparser.resolution.SymbolResolver;
 import com.github.javaparser.utils.LineSeparator;
-
 import java.util.*;
 import java.util.function.Consumer;
 import java.util.function.Function;
@@ -53,13 +61,6 @@ import java.util.function.Predicate;
 import java.util.stream.Stream;
 import java.util.stream.StreamSupport;
 
-import static com.github.javaparser.ast.Node.Parsedness.PARSED;
-import static com.github.javaparser.ast.Node.TreeTraversal.PREORDER;
-import static java.util.Collections.emptySet;
-import static java.util.Collections.unmodifiableList;
-import static java.util.Spliterator.DISTINCT;
-import static java.util.Spliterator.NONNULL;
-
 /**
  * Base class for all nodes of the abstract syntax tree.
  * <h2>Construction</h2>
@@ -92,7 +93,7 @@ import static java.util.Spliterator.NONNULL;
  * like where braces or comma's are exactly.
  * Therefore there is no position information on everything in the original source file.
  * <h2>Observers</h2>
- * <p>It is possible to add observers to the the tree.
+ * <p>It is possible to add observers to the tree.
  * Any change in the tree is sent as an event to any observers watching.
  * <h2>Visitors</h2>
  * <p>The most comfortable way of working with an abstract syntax tree is using visitors.
@@ -103,7 +104,8 @@ import static java.util.Spliterator.NONNULL;
  *
  * @author Julio Vilmar Gesser
  */
-public abstract class Node implements Cloneable, HasParentNode<Node>, Visitable, NodeWithRange<Node>, NodeWithTokenRange<Node> {
+public abstract class Node
+        implements Cloneable, HasParentNode<Node>, Visitable, NodeWithRange<Node>, NodeWithTokenRange<Node> {
 
     /**
      * Different registration mode for observers on nodes.
@@ -128,19 +130,19 @@ public abstract class Node implements Cloneable, HasParentNode<Node>, Visitable,
     }
 
     public enum Parsedness {
-
-        PARSED, UNPARSABLE
+        PARSED,
+        UNPARSABLE
     }
 
     /**
      * This can be used to sort nodes on position.
      */
     public static Comparator<NodeWithRange<?>> NODE_BY_BEGIN_POSITION = (a, b) -> {
-        if (a.getRange().isPresent() && b.getRange().isPresent()) {
+        if (a.hasRange() && b.hasRange()) {
             return a.getRange().get().begin.compareTo(b.getRange().get().begin);
         }
-        if (a.getRange().isPresent() || b.getRange().isPresent()) {
-            if (a.getRange().isPresent()) {
+        if (a.hasRange() || b.hasRange()) {
+            if (a.hasRange()) {
                 return 1;
             }
             return -1;
@@ -148,9 +150,11 @@ public abstract class Node implements Cloneable, HasParentNode<Node>, Visitable,
         return 0;
     };
 
-    private static PrettyPrinterConfiguration toStringPrettyPrinterConfiguration = new PrettyPrinterConfiguration();
+    // usefull to find if the node is a phantom node
+    private static final int LEVELS_TO_EXPLORE = 3;
 
-    protected static final PrettyPrinterConfiguration prettyPrinterNoCommentsConfiguration = new PrettyPrinterConfiguration().setPrintComments(false);
+    protected static final PrinterConfiguration prettyPrinterNoCommentsConfiguration =
+            new DefaultPrinterConfiguration().removeOption(new DefaultConfigurationOption(ConfigOption.PRINT_COMMENTS));
 
     @InternalProperty
     private Range range;
@@ -162,10 +166,10 @@ public abstract class Node implements Cloneable, HasParentNode<Node>, Visitable,
     private Node parentNode;
 
     @InternalProperty
-    private List<Node> childNodes = new LinkedList<>();
+    private ArrayList<Node> childNodes = new ArrayList<>(0);
 
     @InternalProperty
-    private List<Comment> orphanComments = new LinkedList<>();
+    private ArrayList<Comment> orphanComments = new ArrayList<>(0);
 
     @InternalProperty
     private IdentityHashMap<DataKey<?>, Object> data = null;
@@ -174,7 +178,7 @@ public abstract class Node implements Cloneable, HasParentNode<Node>, Visitable,
     private Comment comment;
 
     @InternalProperty
-    private Set<AstObserver> observers = new HashSet<>();
+    private ArrayList<AstObserver> observers = new ArrayList<>(0);
 
     @InternalProperty
     private Parsedness parsed = PARSED;
@@ -188,7 +192,38 @@ public abstract class Node implements Cloneable, HasParentNode<Node>, Visitable,
      * It can't be written in the constructor itself because it will
      * be overwritten during code generation.
      */
-    protected void customInitialization() {
+    protected void customInitialization() {}
+
+    /*
+     * If there is a printer defined in CompilationUnit, returns it
+     * else create a new DefaultPrettyPrinter with default parameters
+     */
+    protected Printer getPrinter() {
+        return findCompilationUnit().map(c -> c.getPrinter()).orElseGet(() -> createDefaultPrinter());
+    }
+
+    /*
+     * Return the printer initialized with the specified configuration
+     */
+    protected Printer getPrinter(PrinterConfiguration configuration) {
+        return findCompilationUnit()
+                .map(c -> c.getPrinter(configuration))
+                .orElseGet(() -> createDefaultPrinter(configuration));
+    }
+
+    protected Printer createDefaultPrinter() {
+        return createDefaultPrinter(getDefaultPrinterConfiguration());
+    }
+
+    protected Printer createDefaultPrinter(PrinterConfiguration configuration) {
+        return new DefaultPrettyPrinter(configuration);
+    }
+
+    /*
+     * returns a default printer configuration
+     */
+    protected PrinterConfiguration getDefaultPrinterConfiguration() {
+        return new DefaultPrinterConfiguration();
     }
 
     /**
@@ -204,6 +239,7 @@ public abstract class Node implements Cloneable, HasParentNode<Node>, Visitable,
     /**
      * @return the range of characters in the source code that this node covers.
      */
+    @Override
     public Optional<Range> getRange() {
         return Optional.ofNullable(range);
     }
@@ -211,16 +247,21 @@ public abstract class Node implements Cloneable, HasParentNode<Node>, Visitable,
     /**
      * @return the range of tokens that this node covers.
      */
+    @Override
     public Optional<TokenRange> getTokenRange() {
         return Optional.ofNullable(tokenRange);
     }
 
+    @Override
     public Node setTokenRange(TokenRange tokenRange) {
         this.tokenRange = tokenRange;
-        if (tokenRange == null || !(tokenRange.getBegin().getRange().isPresent() && tokenRange.getEnd().getRange().isPresent())) {
+        if (tokenRange == null
+                || !(tokenRange.getBegin().hasRange() && tokenRange.getEnd().hasRange())) {
             range = null;
         } else {
-            range = new Range(tokenRange.getBegin().getRange().get().begin, tokenRange.getEnd().getRange().get().end);
+            range = new Range(
+                    tokenRange.getBegin().getRange().get().begin,
+                    tokenRange.getEnd().getRange().get().end);
         }
         return this;
     }
@@ -229,6 +270,7 @@ public abstract class Node implements Cloneable, HasParentNode<Node>, Visitable,
      * @param range the range of characters in the source code that this node covers. null can be used to indicate that
      *              no range information is known, or that it is not of interest.
      */
+    @Override
     public Node setRange(Range range) {
         if (this.range == range) {
             return this;
@@ -278,23 +320,33 @@ public abstract class Node implements Cloneable, HasParentNode<Node>, Visitable,
 
     /**
      * @return pretty printed source code for this node and its children.
-     * Formatting can be configured with Node.setToStringPrettyPrinterConfiguration.
      */
     @Override
     public final String toString() {
         if (containsData(LINE_SEPARATOR_KEY)) {
+            Printer printer = getPrinter();
             LineSeparator lineSeparator = getLineEndingStyleOrDefault(LineSeparator.SYSTEM);
-            toStringPrettyPrinterConfiguration.setEndOfLineCharacter(lineSeparator.asRawString());
+            PrinterConfiguration config = printer.getConfiguration();
+            config.addOption(
+                    new DefaultConfigurationOption(ConfigOption.END_OF_LINE_CHARACTER, lineSeparator.asRawString()));
+            printer.setConfiguration(config);
+            return printer.print(this);
         }
-        return new PrettyPrinter(toStringPrettyPrinterConfiguration).print(this);
+        return getPrinter().print(this);
     }
 
     /**
      * @return pretty printed source code for this node and its children.
-     * Formatting can be configured with parameter prettyPrinterConfiguration.
+     * Formatting can be configured with parameter PrinterConfiguration.
      */
-    public final String toString(PrettyPrinterConfiguration prettyPrinterConfiguration) {
-        return new PrettyPrinter(prettyPrinterConfiguration).print(this);
+    public final String toString(PrinterConfiguration configuration) {
+        // save the current configuration
+        PrinterConfiguration previousConfiguration = getPrinter().getConfiguration();
+        // print with the new configuration
+        String result = getPrinter(configuration).print(this);
+        // restore the previous printer configuration (issue 4163)
+        getPrinter().setConfiguration(previousConfiguration);
+        return result;
     }
 
     @Override
@@ -304,7 +356,7 @@ public abstract class Node implements Cloneable, HasParentNode<Node>, Visitable,
 
     @Override
     public boolean equals(final Object obj) {
-        if (obj == null || !(obj instanceof Node)) {
+        if (!(obj instanceof Node)) {
             return false;
         }
         return EqualsVisitor.equals(this, (Node) obj);
@@ -326,6 +378,7 @@ public abstract class Node implements Cloneable, HasParentNode<Node>, Visitable,
     }
 
     public void addOrphanComment(Comment comment) {
+        notifyPropertyChange(ObservableProperty.COMMENT, null, comment);
         orphanComments.add(comment);
         comment.setParentNode(this);
     }
@@ -335,6 +388,7 @@ public abstract class Node implements Cloneable, HasParentNode<Node>, Visitable,
         if (removed) {
             notifyPropertyChange(ObservableProperty.COMMENT, comment, null);
             comment.setParentNode(null);
+            orphanComments.trimToSize();
         }
         return removed;
     }
@@ -354,7 +408,7 @@ public abstract class Node implements Cloneable, HasParentNode<Node>, Visitable,
      * @return all comments that cannot be attributed to a concept
      */
     public List<Comment> getOrphanComments() {
-        return new LinkedList<>(orphanComments);
+        return unmodifiableList(orphanComments);
     }
 
     /**
@@ -365,8 +419,7 @@ public abstract class Node implements Cloneable, HasParentNode<Node>, Visitable,
      * @return all Comments within the node as a list
      */
     public List<Comment> getAllContainedComments() {
-        List<Comment> comments = new LinkedList<>();
-        comments.addAll(getOrphanComments());
+        List<Comment> comments = new LinkedList<>(orphanComments);
         for (Node child : getChildNodes()) {
             child.getComment().ifPresent(comments::add);
             comments.addAll(child.getAllContainedComments());
@@ -388,12 +441,13 @@ public abstract class Node implements Cloneable, HasParentNode<Node>, Visitable,
         observers.forEach(o -> o.parentChange(this, parentNode, newParentNode));
         // remove from old parent, if any
         if (parentNode != null) {
-            final List<Node> parentChildNodes = parentNode.childNodes;
+            final ArrayList<Node> parentChildNodes = parentNode.childNodes;
             for (int i = 0; i < parentChildNodes.size(); i++) {
                 if (parentChildNodes.get(i) == this) {
                     parentChildNodes.remove(i);
                 }
             }
+            parentChildNodes.trimToSize();
         }
         parentNode = newParentNode;
         // add to new parent, if any
@@ -473,6 +527,22 @@ public abstract class Node implements Cloneable, HasParentNode<Node>, Visitable,
         return value;
     }
 
+    /**
+     * Gets data for this node using the given key or returns an {@code Optional.empty()}.
+     *
+     * @param <M> The type of the data.
+     * @param key The key for the data
+     * @return The data.
+     * @see DataKey
+     */
+    @SuppressWarnings("unchecked")
+    public <M> Optional<M> findData(final DataKey<M> key) {
+        if (containsData(key)) {
+            return Optional.of(getData(key));
+        }
+        return Optional.empty();
+    }
+
     /**
      * This method was added to support the clone method.
      *
@@ -583,11 +653,16 @@ public abstract class Node implements Cloneable, HasParentNode<Node>, Visitable,
     @Override
     public void unregister(AstObserver observer) {
         this.observers.remove(observer);
+        this.observers.trimToSize();
     }
 
     @Override
     public void register(AstObserver observer) {
-        this.observers.add(observer);
+        // Check if the observer is not registered yet.
+        // In this case we use a List instead of Set to save on memory space.
+        if (!this.observers.contains(observer)) {
+            this.observers.add(observer);
+        }
     }
 
     /**
@@ -598,7 +673,7 @@ public abstract class Node implements Cloneable, HasParentNode<Node>, Visitable,
         if (mode == null) {
             throw new IllegalArgumentException("Mode should be not null");
         }
-        switch(mode) {
+        switch (mode) {
             case JUST_THIS_NODE:
                 register(observer);
                 break;
@@ -622,8 +697,7 @@ public abstract class Node implements Cloneable, HasParentNode<Node>, Visitable,
         for (PropertyMetaModel property : getMetaModel().getAllPropertyMetaModels()) {
             if (property.isNodeList()) {
                 NodeList<?> nodeList = (NodeList<?>) property.getValue(this);
-                if (nodeList != null)
-                    nodeList.register(observer);
+                if (nodeList != null) nodeList.register(observer);
             }
         }
     }
@@ -635,8 +709,9 @@ public abstract class Node implements Cloneable, HasParentNode<Node>, Visitable,
 
     @Generated("com.github.javaparser.generator.core.node.RemoveMethodGenerator")
     public boolean remove(Node node) {
-        if (node == null)
+        if (node == null) {
             return false;
+        }
         if (comment != null) {
             if (node == comment) {
                 removeComment();
@@ -681,18 +756,11 @@ public abstract class Node implements Cloneable, HasParentNode<Node>, Visitable,
         return this;
     }
 
-    public static PrettyPrinterConfiguration getToStringPrettyPrinterConfiguration() {
-        return toStringPrettyPrinterConfiguration;
-    }
-
-    public static void setToStringPrettyPrinterConfiguration(PrettyPrinterConfiguration toStringPrettyPrinterConfiguration) {
-        Node.toStringPrettyPrinterConfiguration = toStringPrettyPrinterConfiguration;
-    }
-
     @Generated("com.github.javaparser.generator.core.node.ReplaceMethodGenerator")
     public boolean replace(Node node, Node replacementNode) {
-        if (node == null)
+        if (node == null) {
             return false;
+        }
         if (comment != null) {
             if (node == comment) {
                 setComment((Comment) replacementNode);
@@ -733,49 +801,53 @@ public abstract class Node implements Cloneable, HasParentNode<Node>, Visitable,
 
     public LineSeparator getLineEndingStyle() {
         Node current = this;
-
         // First check this node
-        if(current.containsData(Node.LINE_SEPARATOR_KEY)) {
+        if (current.containsData(Node.LINE_SEPARATOR_KEY)) {
             LineSeparator lineSeparator = current.getData(Node.LINE_SEPARATOR_KEY);
             return lineSeparator;
         }
-
         // Then check parent/ancestor nodes
-        while(current.getParentNode().isPresent()) {
+        while (current.getParentNode().isPresent()) {
             current = current.getParentNode().get();
-            if(current.containsData(Node.LINE_SEPARATOR_KEY)) {
+            if (current.containsData(Node.LINE_SEPARATOR_KEY)) {
                 return current.getData(Node.LINE_SEPARATOR_KEY);
             }
         }
-
         // Default to the system line separator if it's not already set within the parsed node/code.
         return LineSeparator.SYSTEM;
     }
 
-    protected SymbolResolver getSymbolResolver() {
-        return findCompilationUnit().map(cu -> {
-            if (cu.containsData(SYMBOL_RESOLVER_KEY)) {
-                return cu.getData(SYMBOL_RESOLVER_KEY);
-            } else {
-                throw new IllegalStateException("Symbol resolution not configured: to configure consider setting a SymbolResolver in the ParserConfiguration");
-            }
-        }).orElseThrow(() -> new IllegalStateException("The node is not inserted in a CompilationUnit"));
+    public SymbolResolver getSymbolResolver() {
+        return findCompilationUnit()
+                .map(cu -> {
+                    if (cu.containsData(SYMBOL_RESOLVER_KEY)) {
+                        return cu.getData(SYMBOL_RESOLVER_KEY);
+                    }
+                    throw new IllegalStateException(
+                            "Symbol resolution not configured: to configure consider setting a SymbolResolver in the ParserConfiguration");
+                })
+                .orElseThrow(() -> new IllegalStateException("The node is not inserted in a CompilationUnit"));
     }
 
     // We need to expose it because we will need to use it to inject the SymbolSolver
-    public static final DataKey<SymbolResolver> SYMBOL_RESOLVER_KEY = new DataKey<SymbolResolver>() {
-    };
+    public static final DataKey<SymbolResolver> SYMBOL_RESOLVER_KEY = new DataKey<SymbolResolver>() {};
 
-    public static final DataKey<LineSeparator> LINE_SEPARATOR_KEY = new DataKey<LineSeparator>() {
-    };
+    public static final DataKey<LineSeparator> LINE_SEPARATOR_KEY = new DataKey<LineSeparator>() {};
+
+    protected static final DataKey<Printer> PRINTER_KEY = new DataKey<Printer>() {};
+
+    protected static final DataKey<Boolean> PHANTOM_KEY = new DataKey<Boolean>() {};
 
     public enum TreeTraversal {
-
-        PREORDER, BREADTHFIRST, POSTORDER, PARENTS, DIRECT_CHILDREN
+        PREORDER,
+        BREADTHFIRST,
+        POSTORDER,
+        PARENTS,
+        DIRECT_CHILDREN
     }
 
     private Iterator<Node> treeIterator(TreeTraversal traversal) {
-        switch(traversal) {
+        switch (traversal) {
             case BREADTHFIRST:
                 return new BreadthFirstIterator(this);
             case POSTORDER:
@@ -799,14 +871,16 @@ public abstract class Node implements Cloneable, HasParentNode<Node>, Visitable,
      * Make a stream of nodes using traversal algorithm "traversal".
      */
     public Stream<Node> stream(TreeTraversal traversal) {
-        return StreamSupport.stream(Spliterators.spliteratorUnknownSize(treeIterator(traversal), NONNULL | DISTINCT), false);
+        return StreamSupport.stream(
+                Spliterators.spliteratorUnknownSize(treeIterator(traversal), NONNULL | DISTINCT), false);
     }
 
     /**
      * Make a stream of nodes using pre-order traversal.
      */
     public Stream<Node> stream() {
-        return StreamSupport.stream(Spliterators.spliteratorUnknownSize(treeIterator(PREORDER), NONNULL | DISTINCT), false);
+        return StreamSupport.stream(
+                Spliterators.spliteratorUnknownSize(treeIterator(PREORDER), NONNULL | DISTINCT), false);
     }
 
     /**
@@ -847,14 +921,26 @@ public abstract class Node implements Cloneable, HasParentNode<Node>, Visitable,
         return found;
     }
 
+    /**
+     * Walks the AST with specified traversal order, returning all nodes of type "nodeType".
+     */
+    public <T extends Node> List<T> findAll(Class<T> nodeType, TreeTraversal traversal) {
+        final List<T> found = new ArrayList<>();
+        walk(traversal, node -> {
+            if (nodeType.isAssignableFrom(node.getClass())) {
+                found.add(nodeType.cast(node));
+            }
+        });
+        return found;
+    }
+
     /**
      * Walks the AST with pre-order traversal, returning all nodes of type "nodeType" that match the predicate.
      */
     public <T extends Node> List<T> findAll(Class<T> nodeType, Predicate<T> predicate) {
         final List<T> found = new ArrayList<>();
         walk(nodeType, n -> {
-            if (predicate.test(n))
-                found.add(n);
+            if (predicate.test(n)) found.add(n);
         });
         return found;
     }
@@ -902,6 +988,28 @@ public abstract class Node implements Cloneable, HasParentNode<Node>, Visitable,
         });
     }
 
+    /*
+     * Find a node by a range. The search is performed on the current node and its children.
+     */
+    public Optional<Node> findByRange(Range range) {
+        if (isPhantom()) {
+            return Optional.empty();
+        }
+        if (!hasRange()) {
+            return Optional.empty();
+        }
+        if (!getRange().get().contains(range)) {
+            return Optional.empty();
+        }
+        for (Node child : getChildNodes()) {
+            Optional<Node> found = child.findByRange(range);
+            if (found.isPresent()) {
+                return found;
+            }
+        }
+        return Optional.of(this);
+    }
+
     /**
      * Determines whether this node is an ancestor of the given node. A node is <i>not</i> an ancestor of itself.
      *
@@ -947,7 +1055,7 @@ public abstract class Node implements Cloneable, HasParentNode<Node>, Visitable,
         private final Iterator<Node> childrenIterator;
 
         public DirectChildrenIterator(Node node) {
-            childrenIterator = new ArrayList<>(node.getChildNodes()).iterator();
+            childrenIterator = node.getChildNodes().iterator();
         }
 
         @Override
@@ -1036,7 +1144,7 @@ public abstract class Node implements Cloneable, HasParentNode<Node>, Visitable,
 
         private void fillStackToLeaf(Node node) {
             while (true) {
-                List<Node> childNodes = new ArrayList<>(node.getChildNodes());
+                List<Node> childNodes = node.getChildNodes();
                 if (childNodes.isEmpty()) {
                     break;
                 }
@@ -1060,15 +1168,14 @@ public abstract class Node implements Cloneable, HasParentNode<Node>, Visitable,
                 Node node = nodes.get(cursor);
                 fillStackToLeaf(node);
                 return nextFromLevel();
-            } else {
-                nodesStack.pop();
-                cursorStack.pop();
-                hasNext = !nodesStack.empty();
-                if (hasNext) {
-                    return nextFromLevel();
-                }
-                return root;
             }
+            nodesStack.pop();
+            cursorStack.pop();
+            hasNext = !nodesStack.empty();
+            if (hasNext) {
+                return nextFromLevel();
+            }
+            return root;
         }
 
         private Node nextFromLevel() {
@@ -1078,4 +1185,45 @@ public abstract class Node implements Cloneable, HasParentNode<Node>, Visitable,
             return nodes.get(cursor);
         }
     }
+
+    /*
+     * Returns true if the node has an (optional) scope expression eg. method calls (object.method())
+     */
+    public boolean hasScope() {
+        return (NodeWithOptionalScope.class.isAssignableFrom(this.getClass())
+                        && ((NodeWithOptionalScope) this).getScope().isPresent())
+                || (NodeWithScope.class.isAssignableFrom(this.getClass()) && ((NodeWithScope) this).getScope() != null);
+    }
+
+    /*
+     * A "phantom" node, is a node that is not really an AST node (like the fake type of variable in FieldDeclaration or an UnknownType)
+     */
+    public boolean isPhantom() {
+        return isPhantom(this);
+    }
+
+    private boolean isPhantom(Node node) {
+        if (!node.containsData(PHANTOM_KEY)) {
+            boolean res = (node.getParentNode().isPresent()
+                            && node.getParentNode().get().hasRange()
+                            && node.hasRange()
+                            && !node.getParentNode()
+                                    .get()
+                                    .getRange()
+                                    .get()
+                                    .contains(node.getRange().get())
+                    || inPhantomNode(node, LEVELS_TO_EXPLORE));
+            node.setData(PHANTOM_KEY, res);
+        }
+        return node.getData(PHANTOM_KEY);
+    }
+
+    /**
+     * A node contained in a phantom node is also a phantom node. We limit how many levels up we check just for performance reasons.
+     */
+    private boolean inPhantomNode(Node node, int levels) {
+        return node.getParentNode().isPresent()
+                && (isPhantom(node.getParentNode().get())
+                        || inPhantomNode(node.getParentNode().get(), levels - 1));
+    }
 }
