@@ -20,6 +20,8 @@
  */
 package com.github.javaparser.ast.body;
 
+import static com.github.javaparser.utils.Utils.assertNotNull;
+
 import com.github.javaparser.TokenRange;
 import com.github.javaparser.ast.*;
 import com.github.javaparser.ast.expr.AnnotationExpr;
@@ -39,8 +41,6 @@ import com.github.javaparser.metamodel.ParameterMetaModel;
 import com.github.javaparser.resolution.Resolvable;
 import com.github.javaparser.resolution.declarations.ResolvedParameterDeclaration;
 
-import static com.github.javaparser.utils.Utils.assertNotNull;
-
 /**
  * The parameters to a method or lambda. Lambda parameters may have inferred types, in that case "type" is UnknownType.
  * <br>Note that <a href="https://en.wikipedia.org/wiki/Parameter_(computer_programming)#Parameters_and_arguments">parameters
@@ -52,7 +52,12 @@ import static com.github.javaparser.utils.Utils.assertNotNull;
  *
  * @author Julio Vilmar Gesser
  */
-public class Parameter extends Node implements NodeWithType<Parameter, Type>, NodeWithAnnotations<Parameter>, NodeWithSimpleName<Parameter>, NodeWithFinalModifier<Parameter>, Resolvable<ResolvedParameterDeclaration> {
+public class Parameter extends Node
+        implements NodeWithType<Parameter, Type>,
+                NodeWithAnnotations<Parameter>,
+                NodeWithSimpleName<Parameter>,
+                NodeWithFinalModifier<Parameter>,
+                Resolvable<ResolvedParameterDeclaration> {
 
     private Type type;
 
@@ -67,7 +72,14 @@ public class Parameter extends Node implements NodeWithType<Parameter, Type>, No
     private SimpleName name;
 
     public Parameter() {
-        this(null, new NodeList<>(), new NodeList<>(), new ClassOrInterfaceType(), false, new NodeList<>(), new SimpleName());
+        this(
+                null,
+                new NodeList<>(),
+                new NodeList<>(),
+                new ClassOrInterfaceType(),
+                false,
+                new NodeList<>(),
+                new SimpleName());
     }
 
     public Parameter(Type type, SimpleName name) {
@@ -89,7 +101,13 @@ public class Parameter extends Node implements NodeWithType<Parameter, Type>, No
     }
 
     @AllFieldsConstructor
-    public Parameter(NodeList<Modifier> modifiers, NodeList<AnnotationExpr> annotations, Type type, boolean isVarArgs, NodeList<AnnotationExpr> varArgsAnnotations, SimpleName name) {
+    public Parameter(
+            NodeList<Modifier> modifiers,
+            NodeList<AnnotationExpr> annotations,
+            Type type,
+            boolean isVarArgs,
+            NodeList<AnnotationExpr> varArgsAnnotations,
+            SimpleName name) {
         this(null, modifiers, annotations, type, isVarArgs, varArgsAnnotations, name);
     }
 
@@ -97,7 +115,14 @@ public class Parameter extends Node implements NodeWithType<Parameter, Type>, No
      * This constructor is used by the parser and is considered private.
      */
     @Generated("com.github.javaparser.generator.core.node.MainConstructorGenerator")
-    public Parameter(TokenRange tokenRange, NodeList<Modifier> modifiers, NodeList<AnnotationExpr> annotations, Type type, boolean isVarArgs, NodeList<AnnotationExpr> varArgsAnnotations, SimpleName name) {
+    public Parameter(
+            TokenRange tokenRange,
+            NodeList<Modifier> modifiers,
+            NodeList<AnnotationExpr> annotations,
+            Type type,
+            boolean isVarArgs,
+            NodeList<AnnotationExpr> varArgsAnnotations,
+            SimpleName name) {
         super(tokenRange);
         setModifiers(modifiers);
         setAnnotations(annotations);
@@ -137,8 +162,7 @@ public class Parameter extends Node implements NodeWithType<Parameter, Type>, No
             return this;
         }
         notifyPropertyChange(ObservableProperty.TYPE, this.type, type);
-        if (this.type != null)
-            this.type.setParentNode(null);
+        if (this.type != null) this.type.setParentNode(null);
         this.type = type;
         setAsParentNodeOf(type);
         return this;
@@ -189,8 +213,7 @@ public class Parameter extends Node implements NodeWithType<Parameter, Type>, No
             return this;
         }
         notifyPropertyChange(ObservableProperty.ANNOTATIONS, this.annotations, annotations);
-        if (this.annotations != null)
-            this.annotations.setParentNode(null);
+        if (this.annotations != null) this.annotations.setParentNode(null);
         this.annotations = annotations;
         setAsParentNodeOf(annotations);
         return this;
@@ -203,8 +226,7 @@ public class Parameter extends Node implements NodeWithType<Parameter, Type>, No
             return this;
         }
         notifyPropertyChange(ObservableProperty.NAME, this.name, name);
-        if (this.name != null)
-            this.name.setParentNode(null);
+        if (this.name != null) this.name.setParentNode(null);
         this.name = name;
         setAsParentNodeOf(name);
         return this;
@@ -217,8 +239,7 @@ public class Parameter extends Node implements NodeWithType<Parameter, Type>, No
             return this;
         }
         notifyPropertyChange(ObservableProperty.MODIFIERS, this.modifiers, modifiers);
-        if (this.modifiers != null)
-            this.modifiers.setParentNode(null);
+        if (this.modifiers != null) this.modifiers.setParentNode(null);
         this.modifiers = modifiers;
         setAsParentNodeOf(modifiers);
         return this;
@@ -263,8 +284,7 @@ public class Parameter extends Node implements NodeWithType<Parameter, Type>, No
             return this;
         }
         notifyPropertyChange(ObservableProperty.VAR_ARGS_ANNOTATIONS, this.varArgsAnnotations, varArgsAnnotations);
-        if (this.varArgsAnnotations != null)
-            this.varArgsAnnotations.setParentNode(null);
+        if (this.varArgsAnnotations != null) this.varArgsAnnotations.setParentNode(null);
         this.varArgsAnnotations = varArgsAnnotations;
         setAsParentNodeOf(varArgsAnnotations);
         return this;
