@@ -23,5 +23,4 @@ package com.github.javaparser.ast.validator.postprocessors;
 /**
  * Processes the generic AST into a Java 12 AST and validates it.
  */
-public class Java12PostProcessor extends Java11PostProcessor {
-}
+public class Java12PostProcessor extends Java11PostProcessor {}
