@@ -22,12 +22,10 @@ package com.github.javaparser.javadoc;
 
 import com.github.javaparser.ast.comments.JavadocComment;
 import com.github.javaparser.javadoc.description.JavadocDescription;
-
+import com.github.javaparser.utils.LineSeparator;
 import java.util.LinkedList;
 import java.util.List;
 
-import static com.github.javaparser.utils.Utils.SYSTEM_EOL;
-
 /**
  * The structured content of a single Javadoc comment.
  * <p>
@@ -83,14 +81,14 @@ public class Javadoc {
         StringBuilder sb = new StringBuilder();
         if (!description.isEmpty()) {
             sb.append(description.toText());
-            sb.append(SYSTEM_EOL);
+            sb.append(LineSeparator.SYSTEM);
         }
         if (!blockTags.isEmpty()) {
-            sb.append(SYSTEM_EOL);
+            sb.append(LineSeparator.SYSTEM);
         }
         blockTags.forEach(bt -> {
             sb.append(bt.toText());
-            sb.append(SYSTEM_EOL);
+            sb.append(LineSeparator.SYSTEM);
         });
         return sb.toString();
     }
@@ -108,18 +106,19 @@ public class Javadoc {
     public JavadocComment toComment(String indentation) {
         for (char c : indentation.toCharArray()) {
             if (!Character.isWhitespace(c)) {
-                throw new IllegalArgumentException("The indentation string should be composed only by whitespace characters");
+                throw new IllegalArgumentException(
+                        "The indentation string should be composed only by whitespace characters");
             }
         }
         StringBuilder sb = new StringBuilder();
-        sb.append(SYSTEM_EOL);
+        sb.append(LineSeparator.SYSTEM);
         final String text = toText();
         if (!text.isEmpty()) {
-            for (String line : text.split(SYSTEM_EOL)) {
+            for (String line : text.split(LineSeparator.SYSTEM.asRawString())) {
                 sb.append(indentation);
                 sb.append(" * ");
                 sb.append(line);
-                sb.append(SYSTEM_EOL);
+                sb.append(LineSeparator.SYSTEM);
             }
         }
         sb.append(indentation);
@@ -140,10 +139,8 @@ public class Javadoc {
 
     @Override
     public boolean equals(Object o) {
-        if (this == o)
-            return true;
-        if (o == null || getClass() != o.getClass())
-            return false;
+        if (this == o) return true;
+        if (o == null || getClass() != o.getClass()) return false;
         Javadoc document = (Javadoc) o;
         return description.equals(document.description) && blockTags.equals(document.blockTags);
     }
