@@ -26,11 +26,6 @@ import static com.github.javaparser.utils.Utils.*;
 import static java.util.Comparator.comparingInt;
 import static java.util.stream.Collectors.joining;
 
-import java.util.*;
-import java.util.concurrent.atomic.AtomicBoolean;
-import java.util.regex.Pattern;
-import java.util.stream.Collectors;
-
 import com.github.javaparser.ast.*;
 import com.github.javaparser.ast.body.*;
 import com.github.javaparser.ast.comments.BlockComment;
@@ -45,6 +40,10 @@ import com.github.javaparser.ast.type.*;
 import com.github.javaparser.ast.visitor.Visitable;
 import com.github.javaparser.ast.visitor.VoidVisitor;
 import com.github.javaparser.printer.configuration.PrettyPrinterConfiguration;
+import java.util.*;
+import java.util.concurrent.atomic.AtomicBoolean;
+import java.util.regex.Pattern;
+import java.util.stream.Collectors;
 
 /**
  * Outputs the AST as formatted Java source code.
@@ -57,7 +56,7 @@ import com.github.javaparser.printer.configuration.PrettyPrinterConfiguration;
 @Deprecated
 public class PrettyPrintVisitor implements VoidVisitor<Void> {
 
-	private static Pattern RTRIM = Pattern.compile("\\s+$");
+    private static Pattern RTRIM = Pattern.compile("\\s+$");
 
     protected PrettyPrinterConfiguration configuration;
 
@@ -87,7 +86,11 @@ public class PrettyPrintVisitor implements VoidVisitor<Void> {
 
     protected void printModifiers(final NodeList<Modifier> modifiers) {
         if (modifiers.size() > 0) {
-            printer.print(modifiers.stream().map(Modifier::getKeyword).map(Modifier.Keyword::asString).collect(joining(" ")) + " ");
+            printer.print(
+                    modifiers.stream()
+                                    .map(Modifier::getKeyword)
+                                    .map(Modifier.Keyword::asString)
+                                    .collect(joining(" ")) + " ");
         }
     }
 
@@ -109,7 +112,8 @@ public class PrettyPrintVisitor implements VoidVisitor<Void> {
         }
     }
 
-    protected void printAnnotations(final NodeList<AnnotationExpr> annotations, boolean prefixWithASpace, final Void arg) {
+    protected void printAnnotations(
+            final NodeList<AnnotationExpr> annotations, boolean prefixWithASpace, final Void arg) {
         if (annotations.isEmpty()) {
             return;
         }
@@ -151,15 +155,15 @@ public class PrettyPrintVisitor implements VoidVisitor<Void> {
         }
     }
 
-    protected void printArguments(final NodeList<Expression> args, final Void arg) {
+    protected <T extends Expression> void printArguments(final NodeList<T> args, final Void arg) {
         printer.print("(");
         if (!isNullOrEmpty(args)) {
             boolean columnAlignParameters = (args.size() > 1) && configuration.isColumnAlignParameters();
             if (columnAlignParameters) {
                 printer.indentWithAlignTo(printer.getCursor().column);
             }
-            for (final Iterator<Expression> i = args.iterator(); i.hasNext(); ) {
-                final Expression e = i.next();
+            for (final Iterator<T> i = args.iterator(); i.hasNext(); ) {
+                final T e = i.next();
                 e.accept(this, arg);
                 if (i.hasNext()) {
                     printer.print(",");
@@ -177,7 +181,8 @@ public class PrettyPrintVisitor implements VoidVisitor<Void> {
         printer.print(")");
     }
 
-    protected void printPrePostFixOptionalList(final NodeList<? extends Visitable> args, final Void arg, String prefix, String separator, String postfix) {
+    protected void printPrePostFixOptionalList(
+            final NodeList<? extends Visitable> args, final Void arg, String prefix, String separator, String postfix) {
         if (!args.isEmpty()) {
             printer.print(prefix);
             for (final Iterator<? extends Visitable> i = args.iterator(); i.hasNext(); ) {
@@ -191,7 +196,8 @@ public class PrettyPrintVisitor implements VoidVisitor<Void> {
         }
     }
 
-    protected void printPrePostFixRequiredList(final NodeList<? extends Visitable> args, final Void arg, String prefix, String separator, String postfix) {
+    protected void printPrePostFixRequiredList(
+            final NodeList<? extends Visitable> args, final Void arg, String prefix, String separator, String postfix) {
         printer.print(prefix);
         if (!args.isEmpty()) {
             for (final Iterator<? extends Visitable> i = args.iterator(); i.hasNext(); ) {
@@ -297,7 +303,9 @@ public class PrettyPrintVisitor implements VoidVisitor<Void> {
         }
         if (!n.getImplementedTypes().isEmpty()) {
             printer.print(" implements ");
-            for (final Iterator<ClassOrInterfaceType> i = n.getImplementedTypes().iterator(); i.hasNext(); ) {
+            for (final Iterator<ClassOrInterfaceType> i =
+                            n.getImplementedTypes().iterator();
+                    i.hasNext(); ) {
                 final ClassOrInterfaceType c = i.next();
                 c.accept(this, arg);
                 if (i.hasNext()) {
@@ -305,7 +313,7 @@ public class PrettyPrintVisitor implements VoidVisitor<Void> {
                 }
             }
         }
-        if(!n.getPermittedTypes().isEmpty()){
+        if (!n.getPermittedTypes().isEmpty()) {
             printer.print(" permits ");
             for (final Iterator<ClassOrInterfaceType> i = n.getPermittedTypes().iterator(); i.hasNext(); ) {
                 final ClassOrInterfaceType c = i.next();
@@ -347,7 +355,9 @@ public class PrettyPrintVisitor implements VoidVisitor<Void> {
         printTypeParameters(n.getTypeParameters(), arg);
         if (!n.getImplementedTypes().isEmpty()) {
             printer.print(" implements ");
-            for (final Iterator<ClassOrInterfaceType> i = n.getImplementedTypes().iterator(); i.hasNext(); ) {
+            for (final Iterator<ClassOrInterfaceType> i =
+                            n.getImplementedTypes().iterator();
+                    i.hasNext(); ) {
                 final ClassOrInterfaceType c = i.next();
                 c.accept(this, arg);
                 if (i.hasNext()) {
@@ -370,7 +380,8 @@ public class PrettyPrintVisitor implements VoidVisitor<Void> {
         printOrphanCommentsBeforeThisChildNode(n);
         if (configuration.isPrintComments() && configuration.isPrintJavadoc()) {
             printer.println(n.getHeader());
-            final String commentContent = normalizeEolInTextBlock(n.getContent(), configuration.getEndOfLineCharacter());
+            final String commentContent =
+                    normalizeEolInTextBlock(n.getContent(), configuration.getEndOfLineCharacter());
             String[] lines = commentContent.split("\\R");
             List<String> strippedLines = new ArrayList<>();
             for (String line : lines) {
@@ -402,7 +413,7 @@ public class PrettyPrintVisitor implements VoidVisitor<Void> {
                     printer.println(line);
                 }
             }
-            printer.println(" "+n.getFooter());
+            printer.println(" " + n.getFooter());
         }
     }
 
@@ -557,19 +568,21 @@ public class PrettyPrintVisitor implements VoidVisitor<Void> {
         printOrphanCommentsBeforeThisChildNode(n);
         printComment(n.getComment(), arg);
         n.getName().accept(this, arg);
-        n.findAncestor(NodeWithVariables.class).ifPresent(ancestor -> ((NodeWithVariables<?>) ancestor).getMaximumCommonType().ifPresent(commonType -> {
-            final Type type = n.getType();
-            ArrayType arrayType = null;
-            for (int i = commonType.getArrayLevel(); i < type.getArrayLevel(); i++) {
-                if (arrayType == null) {
-                    arrayType = (ArrayType) type;
-                } else {
-                    arrayType = (ArrayType) arrayType.getComponentType();
-                }
-                printAnnotations(arrayType.getAnnotations(), true, arg);
-                printer.print("[]");
-            }
-        }));
+        n.findAncestor(NodeWithVariables.class).ifPresent(ancestor -> ((NodeWithVariables<?>) ancestor)
+                .getMaximumCommonType()
+                .ifPresent(commonType -> {
+                    final Type type = n.getType();
+                    ArrayType arrayType = null;
+                    for (int i = commonType.getArrayLevel(); i < type.getArrayLevel(); i++) {
+                        if (arrayType == null) {
+                            arrayType = (ArrayType) type;
+                        } else {
+                            arrayType = (ArrayType) arrayType.getComponentType();
+                        }
+                        printAnnotations(arrayType.getAnnotations(), true, arg);
+                        printer.print("[]");
+                    }
+                }));
         if (n.getInitializer().isPresent()) {
             printer.print(" = ");
             n.getInitializer().get().accept(this, arg);
@@ -737,13 +750,21 @@ public class PrettyPrintVisitor implements VoidVisitor<Void> {
     }
 
     @Override
-    public void visit(final PatternExpr n, final Void arg) {
+    public void visit(final TypePatternExpr n, final Void arg) {
         printModifiers(n.getModifiers());
         n.getType().accept(this, arg);
         printer.print(" ");
         n.getName().accept(this, arg);
     }
 
+    @Override
+    public void visit(final RecordPatternExpr n, final Void arg) {
+        printOrphanCommentsBeforeThisChildNode(n);
+        printComment(n.getComment(), arg);
+        n.getType().accept(this, arg);
+        printArguments(n.getPatternList(), arg);
+    }
+
     @Override
     public void visit(final CharLiteralExpr n, final Void arg) {
         printOrphanCommentsBeforeThisChildNode(n);
@@ -844,16 +865,24 @@ public class PrettyPrintVisitor implements VoidVisitor<Void> {
         AtomicBoolean columnAlignFirstMethodChain = new AtomicBoolean();
         if (configuration.isColumnAlignFirstMethodChain()) {
             // pick the kind of expressions where vertically aligning method calls is okay.
-            if (n.findAncestor(Statement.class).map(p -> p.isReturnStmt() || p.isThrowStmt() || p.isAssertStmt() || p.isExpressionStmt()).orElse(false)) {
+            if (n.findAncestor(Statement.class)
+                    .map(p -> p.isReturnStmt() || p.isThrowStmt() || p.isAssertStmt() || p.isExpressionStmt())
+                    .orElse(false)) {
                 // search for first parent that does not have its child as scope
                 Node c = n;
                 Optional<Node> p = c.getParentNode();
-                while (p.isPresent() && p.filter(NodeWithTraversableScope.class::isInstance).map(NodeWithTraversableScope.class::cast).flatMap(NodeWithTraversableScope::traverseScope).map(c::equals).orElse(false)) {
+                while (p.isPresent()
+                        && p.filter(NodeWithTraversableScope.class::isInstance)
+                                .map(NodeWithTraversableScope.class::cast)
+                                .flatMap(NodeWithTraversableScope::traverseScope)
+                                .map(c::equals)
+                                .orElse(false)) {
                     c = p.get();
                     p = c.getParentNode();
                 }
                 // check if the parent is a method call and thus we are in an argument list
-                columnAlignFirstMethodChain.set(!p.filter(MethodCallExpr.class::isInstance).isPresent());
+                columnAlignFirstMethodChain.set(
+                        !p.filter(MethodCallExpr.class::isInstance).isPresent());
             }
         }
         // we are at the last method call of a call chain
@@ -861,7 +890,12 @@ public class PrettyPrintVisitor implements VoidVisitor<Void> {
         AtomicBoolean lastMethodInCallChain = new AtomicBoolean(true);
         if (columnAlignFirstMethodChain.get()) {
             Node node = n;
-            while (node.getParentNode().filter(NodeWithTraversableScope.class::isInstance).map(NodeWithTraversableScope.class::cast).flatMap(NodeWithTraversableScope::traverseScope).map(node::equals).orElse(false)) {
+            while (node.getParentNode()
+                    .filter(NodeWithTraversableScope.class::isInstance)
+                    .map(NodeWithTraversableScope.class::cast)
+                    .flatMap(NodeWithTraversableScope::traverseScope)
+                    .map(node::equals)
+                    .orElse(false)) {
                 node = node.getParentNode().orElseThrow(AssertionError::new);
                 if (node instanceof MethodCallExpr) {
                     lastMethodInCallChain.set(false);
@@ -875,7 +909,8 @@ public class PrettyPrintVisitor implements VoidVisitor<Void> {
         if (columnAlignFirstMethodChain.get()) {
             Optional<Expression> s = n.getScope();
             while (s.filter(NodeWithTraversableScope.class::isInstance).isPresent()) {
-                Optional<Expression> parentScope = s.map(NodeWithTraversableScope.class::cast).flatMap(NodeWithTraversableScope::traverseScope);
+                Optional<Expression> parentScope =
+                        s.map(NodeWithTraversableScope.class::cast).flatMap(NodeWithTraversableScope::traverseScope);
                 if (s.filter(MethodCallExpr.class::isInstance).isPresent() && parentScope.isPresent()) {
                     methodCallWithScopeInScope.set(true);
                     break;
@@ -890,18 +925,18 @@ public class PrettyPrintVisitor implements VoidVisitor<Void> {
             if (columnAlignFirstMethodChain.get()) {
                 if (methodCallWithScopeInScope.get()) {
                     /* We're a method call on the result of something (method call, property access, ...) that is not stand alone,
-                       and not the first one with scope, like:
-                       we're x() in a.b().x(), or in a=b().c[15].d.e().x().
-                       That means that the "else" has been executed by one of the methods in the scope chain, so that the alignment
-                       is set to the "." of that method.
-                       That means we will align to that "." when we start a new line: */
+                    and not the first one with scope, like:
+                    we're x() in a.b().x(), or in a=b().c[15].d.e().x().
+                    That means that the "else" has been executed by one of the methods in the scope chain, so that the alignment
+                    is set to the "." of that method.
+                    That means we will align to that "." when we start a new line: */
                     printer.println();
                 } else if (!lastMethodInCallChain.get()) {
                     /* We're the first method call on the result of something in the chain (method call, property access, ...),
-                       but we are not at the same time the last method call in that chain, like:
-                       we're x() in a().x().y(), or in Long.x().y.z(). That means we get to dictate the indent of following method
-                       calls in this chain by setting the cursor to where we are now: just before the "."
-                       that start this method call. */
+                    but we are not at the same time the last method call in that chain, like:
+                    we're x() in a().x().y(), or in Long.x().y.z(). That means we get to dictate the indent of following method
+                    calls in this chain by setting the cursor to where we are now: just before the "."
+                    that start this method call. */
                     printer.reindentWithAlignToCursor();
                 }
             }
@@ -1245,6 +1280,14 @@ public class PrettyPrintVisitor implements VoidVisitor<Void> {
                     printer.print(", ");
                 }
             }
+            // `case null, default -> ...` added in JEP 441
+            if (n.getLabels().isNonEmpty() && n.isDefault()) {
+                printer.print(", default");
+            }
+            if (n.getGuard().isPresent()) {
+                printer.print(" when ");
+                n.getGuard().get().accept(this, arg);
+            }
             printer.print(separator);
         }
         printer.println();
@@ -1298,7 +1341,9 @@ public class PrettyPrintVisitor implements VoidVisitor<Void> {
         n.getName().accept(this, arg);
         if (!n.getImplementedTypes().isEmpty()) {
             printer.print(" implements ");
-            for (final Iterator<ClassOrInterfaceType> i = n.getImplementedTypes().iterator(); i.hasNext(); ) {
+            for (final Iterator<ClassOrInterfaceType> i =
+                            n.getImplementedTypes().iterator();
+                    i.hasNext(); ) {
                 final ClassOrInterfaceType c = i.next();
                 c.accept(this, arg);
                 if (i.hasNext()) {
@@ -1309,9 +1354,10 @@ public class PrettyPrintVisitor implements VoidVisitor<Void> {
         printer.println(" {");
         printer.indent();
         if (n.getEntries().isNonEmpty()) {
-            final boolean alignVertically = // Either we hit the constant amount limit in the configurations, or...
-            n.getEntries().size() > configuration.getMaxEnumConstantsToAlignHorizontally() || // any of the constants has a comment.
-            n.getEntries().stream().anyMatch(e -> e.getComment().isPresent());
+            // Either we hit the constant amount limit in the configurations, or any of the constants has a comment
+            final boolean alignVertically = n.getEntries().size()
+                            > configuration.getMaxEnumConstantsToAlignHorizontally()
+                    || n.getEntries().stream().anyMatch(e -> e.getComment().isPresent());
             printer.println();
             for (final Iterator<EnumConstantDeclaration> i = n.getEntries().iterator(); i.hasNext(); ) {
                 final EnumConstantDeclaration e = i.next();
@@ -1372,34 +1418,27 @@ public class PrettyPrintVisitor implements VoidVisitor<Void> {
         printer.print("if (");
         n.getCondition().accept(this, arg);
         final boolean thenBlock = n.getThenStmt() instanceof BlockStmt;
-        if (// block statement should start on the same line
-        thenBlock)
-            printer.print(") ");
+        if ( // block statement should start on the same line
+        thenBlock) printer.print(") ");
         else {
             printer.println(")");
             printer.indent();
         }
         n.getThenStmt().accept(this, arg);
-        if (!thenBlock)
-            printer.unindent();
+        if (!thenBlock) printer.unindent();
         if (n.getElseStmt().isPresent()) {
-            if (thenBlock)
-                printer.print(" ");
-            else
-                printer.println();
+            if (thenBlock) printer.print(" ");
+            else printer.println();
             final boolean elseIf = n.getElseStmt().orElse(null) instanceof IfStmt;
             final boolean elseBlock = n.getElseStmt().orElse(null) instanceof BlockStmt;
-            if (// put chained if and start of block statement on a same level
-            elseIf || elseBlock)
-                printer.print("else ");
+            if ( // put chained if and start of block statement on a same level
+            elseIf || elseBlock) printer.print("else ");
             else {
                 printer.println("else");
                 printer.indent();
             }
-            if (n.getElseStmt().isPresent())
-                n.getElseStmt().get().accept(this, arg);
-            if (!(elseIf || elseBlock))
-                printer.unindent();
+            if (n.getElseStmt().isPresent()) n.getElseStmt().get().accept(this, arg);
+            if (!(elseIf || elseBlock)) printer.unindent();
         }
     }
 
@@ -1627,7 +1666,8 @@ public class PrettyPrintVisitor implements VoidVisitor<Void> {
         if (configuration.isIgnoreComments()) {
             return;
         }
-        printer.print(n.getHeader()).println(normalizeEolInTextBlock(RTRIM.matcher(n.getContent()).replaceAll(""), ""));
+        printer.print(n.getHeader())
+                .println(normalizeEolInTextBlock(RTRIM.matcher(n.getContent()).replaceAll(""), ""));
     }
 
     @Override
@@ -1641,7 +1681,8 @@ public class PrettyPrintVisitor implements VoidVisitor<Void> {
         printer.print(n.getHeader());
         for (int i = 0; i < (lines.length - 1); i++) {
             printer.print(lines[i]);
-            // Avoids introducing indentation in blockcomments. ie: do not use println() as it would trigger indentation at the next print call.
+            // Avoids introducing indentation in blockcomments. ie: do not use println() as it would trigger indentation
+            // at the next print call.
             printer.print(configuration.getEndOfLineCharacter());
         }
         // last line is not followed by a newline, and simply terminated with `*/`
@@ -1708,7 +1749,8 @@ public class PrettyPrintVisitor implements VoidVisitor<Void> {
         if (configuration.isOrderImports() && n.size() > 0 && n.get(0) instanceof ImportDeclaration) {
             // noinspection unchecked
             NodeList<ImportDeclaration> modifiableList = new NodeList<>(n);
-            modifiableList.sort(comparingInt((ImportDeclaration i) -> i.isStatic() ? 0 : 1).thenComparing(NodeWithName::getNameAsString));
+            modifiableList.sort(comparingInt((ImportDeclaration i) -> i.isStatic() ? 0 : 1)
+                    .thenComparing(NodeWithName::getNameAsString));
             for (Object node : modifiableList) {
                 ((Node) node).accept(this, arg);
             }
@@ -1793,13 +1835,10 @@ public class PrettyPrintVisitor implements VoidVisitor<Void> {
     }
 
     private void printOrphanCommentsBeforeThisChildNode(final Node node) {
-        if (configuration.isIgnoreComments())
-            return;
-        if (node instanceof Comment)
-            return;
+        if (configuration.isIgnoreComments()) return;
+        if (node instanceof Comment) return;
         Node parent = node.getParentNode().orElse(null);
-        if (parent == null)
-            return;
+        if (parent == null) return;
         List<Node> everything = new ArrayList<>(parent.getChildNodes());
         sortByBeginPosition(everything);
         int positionOfTheChild = -1;
@@ -1815,22 +1854,23 @@ public class PrettyPrintVisitor implements VoidVisitor<Void> {
         }
         int positionOfPreviousChild = -1;
         for (int i = positionOfTheChild - 1; i >= 0 && positionOfPreviousChild == -1; i--) {
-            if (!(everything.get(i) instanceof Comment))
-                positionOfPreviousChild = i;
+            if (!(everything.get(i) instanceof Comment)) positionOfPreviousChild = i;
         }
         for (int i = positionOfPreviousChild + 1; i < positionOfTheChild; i++) {
             Node nodeToPrint = everything.get(i);
             if (!(nodeToPrint instanceof Comment))
-                throw new RuntimeException("Expected comment, instead " + nodeToPrint.getClass() + ". Position of previous child: " + positionOfPreviousChild + ", position of child " + positionOfTheChild);
+                throw new RuntimeException(
+                        "Expected comment, instead " + nodeToPrint.getClass() + ". Position of previous child: "
+                                + positionOfPreviousChild + ", position of child " + positionOfTheChild);
             nodeToPrint.accept(this, null);
         }
     }
 
     private void printOrphanCommentsEnding(final Node node) {
-        if (configuration.isIgnoreComments())
-            return;
+        if (configuration.isIgnoreComments()) return;
         // extract all nodes for which the position/range is indicated to avoid to skip orphan comments
-        List<Node> everything = node.getChildNodes().stream().filter(n -> n.hasRange()).collect(Collectors.toList());
+        List<Node> everything =
+                node.getChildNodes().stream().filter(n -> n.hasRange()).collect(Collectors.toList());
         sortByBeginPosition(everything);
         if (everything.isEmpty()) {
             return;
@@ -1850,12 +1890,10 @@ public class PrettyPrintVisitor implements VoidVisitor<Void> {
     }
 
     private void indentIf(boolean expr) {
-        if (expr)
-            printer.indent();
+        if (expr) printer.indent();
     }
 
     private void unindentIf(boolean expr) {
-        if (expr)
-            printer.unindent();
+        if (expr) printer.unindent();
     }
 }
