@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2007-2010 Júlio Vilmar Gesser.
- * Copyright (C) 2011, 2013-2020 The JavaParser Team.
+ * Copyright (C) 2011, 2013-2024 The JavaParser Team.
  *
  * This file is part of JavaParser.
  *
@@ -18,7 +18,6 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU Lesser General Public License for more details.
  */
-
 package com.github.javaparser.printer.concretesyntaxmodel;
 
 import com.github.javaparser.ast.Node;
@@ -26,16 +25,26 @@ import com.github.javaparser.ast.observer.ObservableProperty;
 import com.github.javaparser.printer.SourcePrinter;
 
 public class CsmChar implements CsmElement {
+
     private final ObservableProperty property;
 
     public CsmChar(ObservableProperty property) {
         this.property = property;
     }
 
+    public ObservableProperty getProperty() {
+        return property;
+    }
+
     @Override
     public void prettyPrint(Node node, SourcePrinter printer) {
         printer.print("'");
         printer.print(property.getValueAsStringAttribute(node));
         printer.print("'");
     }
+
+    @Override
+    public String toString() {
+        return String.format("%s(property:%s)", this.getClass().getSimpleName(), getProperty());
+    }
 }
