@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2007-2010 Júlio Vilmar Gesser.
- * Copyright (C) 2011, 2013-2020 The JavaParser Team.
+ * Copyright (C) 2011, 2013-2024 The JavaParser Team.
  *
  * This file is part of JavaParser.
  *
@@ -18,11 +18,12 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU Lesser General Public License for more details.
  */
-
 package com.github.javaparser.printer.concretesyntaxmodel;
 
 import com.github.javaparser.ast.Node;
 import com.github.javaparser.printer.SourcePrinter;
+import com.github.javaparser.printer.lexicalpreservation.TextElement;
+import com.github.javaparser.printer.lexicalpreservation.TokenTextElement;
 
 public class CsmIndent implements CsmElement {
 
@@ -31,6 +32,14 @@ public class CsmIndent implements CsmElement {
         printer.indent();
     }
 
+    /*
+     * Verifies if the content of the {@code CsmElement} is the same as the provided {@code TextElement}
+     */
+    @Override
+    public boolean isCorrespondingElement(TextElement textElement) {
+        return (textElement instanceof TokenTextElement) && ((TokenTextElement) textElement).isSpaceOrTab();
+    }
+
     @Override
     public int hashCode() {
         return 1;
