@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2007-2010 Júlio Vilmar Gesser.
- * Copyright (C) 2011, 2013-2020 The JavaParser Team.
+ * Copyright (C) 2011, 2013-2024 The JavaParser Team.
  *
  * This file is part of JavaParser.
  *
@@ -18,7 +18,6 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU Lesser General Public License for more details.
  */
-
 package com.github.javaparser.printer.concretesyntaxmodel;
 
 import com.github.javaparser.ast.Node;
@@ -27,8 +26,5 @@ import com.github.javaparser.printer.SourcePrinter;
 public class CsmNone implements CsmElement {
 
     @Override
-    public void prettyPrint(Node node, SourcePrinter printer) {
-
-    }
-
+    public void prettyPrint(Node node, SourcePrinter printer) {}
 }
