@@ -40,10 +40,8 @@ public class Removed implements DifferenceElement {
 
     @Override
     public boolean equals(Object o) {
-        if (this == o)
-            return true;
-        if (o == null || getClass() != o.getClass())
-            return false;
+        if (this == o) return true;
+        if (o == null || getClass() != o.getClass()) return false;
         Removed removed = (Removed) o;
         return element.equals(removed.element);
     }
@@ -63,7 +61,8 @@ public class Removed implements DifferenceElement {
             LexicalDifferenceCalculator.CsmChild csmChild = (LexicalDifferenceCalculator.CsmChild) element;
             return csmChild.getChild();
         }
-        throw new IllegalStateException("Removed is not a " + LexicalDifferenceCalculator.CsmChild.class.getSimpleName());
+        throw new IllegalStateException(
+                "Removed is not a " + LexicalDifferenceCalculator.CsmChild.class.getSimpleName());
     }
 
     public int getTokenType() {
@@ -108,7 +107,7 @@ public class Removed implements DifferenceElement {
         }
         return false;
     }
-    
+
     public boolean isWhiteSpaceNotEol() {
         if (isToken()) {
             CsmToken csmToken = (CsmToken) element;
