@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2007-2010 Júlio Vilmar Gesser.
- * Copyright (C) 2011, 2013-2020 The JavaParser Team.
+ * Copyright (C) 2011, 2013-2024 The JavaParser Team.
  *
  * This file is part of JavaParser.
  *
@@ -18,18 +18,26 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU Lesser General Public License for more details.
  */
-
 package com.github.javaparser.resolution.declarations;
 
-import com.github.javaparser.ast.body.AnnotationDeclaration;
-
 import java.util.List;
 
 /**
  * @author Federico Tomassetti
  */
-public interface ResolvedAnnotationDeclaration extends ResolvedReferenceTypeDeclaration,
-        AssociableToAST<AnnotationDeclaration> {
+public interface ResolvedAnnotationDeclaration extends ResolvedReferenceTypeDeclaration {
+
+    @Override
+    default boolean isAnnotation() {
+        return true;
+    }
+
+    @Override
+    default ResolvedAnnotationDeclaration asAnnotation() {
+        return this;
+    }
 
     List<ResolvedAnnotationMemberDeclaration> getAnnotationMembers();
+
+    boolean isInheritable();
 }
