@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2007-2010 Júlio Vilmar Gesser.
- * Copyright (C) 2011, 2013-2020 The JavaParser Team.
+ * Copyright (C) 2011, 2013-2024 The JavaParser Team.
  *
  * This file is part of JavaParser.
  *
@@ -18,18 +18,8 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU Lesser General Public License for more details.
  */
-
 package com.github.javaparser.resolution.types;
 
-import java.util.ArrayList;
-import java.util.Collections;
-import java.util.LinkedList;
-import java.util.List;
-import java.util.Map;
-import java.util.Optional;
-import java.util.Set;
-import java.util.stream.Collectors;
-
 import com.github.javaparser.ast.AccessSpecifier;
 import com.github.javaparser.resolution.MethodUsage;
 import com.github.javaparser.resolution.declarations.ResolvedFieldDeclaration;
@@ -37,10 +27,14 @@ import com.github.javaparser.resolution.declarations.ResolvedMethodDeclaration;
 import com.github.javaparser.resolution.declarations.ResolvedReferenceTypeDeclaration;
 import com.github.javaparser.resolution.declarations.ResolvedTypeParameterDeclaration;
 import com.github.javaparser.resolution.declarations.ResolvedTypeParameterDeclaration.Bound;
+import com.github.javaparser.resolution.model.typesystem.LazyType;
 import com.github.javaparser.resolution.types.parametrization.ResolvedTypeParameterValueProvider;
 import com.github.javaparser.resolution.types.parametrization.ResolvedTypeParametersMap;
 import com.github.javaparser.resolution.types.parametrization.ResolvedTypeParametrized;
 import com.github.javaparser.utils.Pair;
+import java.util.*;
+import java.util.function.Function;
+import java.util.stream.Collectors;
 
 /**
  * A ReferenceType like a class, an interface or an enum. Note that this type can contain also the values
@@ -48,20 +42,23 @@ import com.github.javaparser.utils.Pair;
  *
  * @author Federico Tomassetti
  */
-public abstract class ResolvedReferenceType implements ResolvedType,
-        ResolvedTypeParametrized, ResolvedTypeParameterValueProvider {
+public abstract class ResolvedReferenceType
+        implements ResolvedType, ResolvedTypeParametrized, ResolvedTypeParameterValueProvider {
+
+    protected static String JAVA_LANG_ENUM = java.lang.Enum.class.getCanonicalName();
+
+    protected static String JAVA_LANG_OBJECT = java.lang.Object.class.getCanonicalName();
 
     //
     // Fields
     //
-
     protected ResolvedReferenceTypeDeclaration typeDeclaration;
+
     protected ResolvedTypeParametersMap typeParametersMap;
 
     //
     // Constructors
     //
-
     public ResolvedReferenceType(ResolvedReferenceTypeDeclaration typeDeclaration) {
         this(typeDeclaration, deriveParams(typeDeclaration));
     }
@@ -73,14 +70,16 @@ public abstract class ResolvedReferenceType implements ResolvedType,
         if (typeDeclaration.isTypeParameter()) {
             throw new IllegalArgumentException("You should use only Classes, Interfaces and enums");
         }
-        if (typeArguments.size() > 0 && typeArguments.size() != typeDeclaration.getTypeParameters().size()) {
+        if (typeArguments.size() > 0
+                && typeArguments.size() != typeDeclaration.getTypeParameters().size()) {
             throw new IllegalArgumentException(String.format(
                     "expected either zero type arguments or has many as defined in the declaration (%d). Found %d",
                     typeDeclaration.getTypeParameters().size(), typeArguments.size()));
         }
         ResolvedTypeParametersMap.Builder typeParametersMapBuilder = new ResolvedTypeParametersMap.Builder();
         for (int i = 0; i < typeArguments.size(); i++) {
-            typeParametersMapBuilder.setValue(typeDeclaration.getTypeParameters().get(i), typeArguments.get(i));
+            typeParametersMapBuilder.setValue(
+                    typeDeclaration.getTypeParameters().get(i), typeArguments.get(i));
         }
         this.typeParametersMap = typeParametersMapBuilder.build();
         this.typeDeclaration = typeDeclaration;
@@ -89,17 +88,19 @@ public abstract class ResolvedReferenceType implements ResolvedType,
     //
     // Public Object methods
     //
-
     @Override
     public boolean equals(Object o) {
         if (this == o) return true;
-        if (o == null || getClass() != o.getClass()) return false;
-
+        if (o == null) return false;
+        if (o instanceof LazyType) {
+            final LazyType lazyType = (LazyType) o;
+            if (!lazyType.isReferenceType()) return false;
+            return this.equals(lazyType.asReferenceType());
+        }
+        if (getClass() != o.getClass()) return false;
         ResolvedReferenceType that = (ResolvedReferenceType) o;
-
         if (!typeDeclaration.equals(that.typeDeclaration)) return false;
         if (!typeParametersMap.equals(that.typeParametersMap)) return false;
-
         return true;
     }
 
@@ -112,33 +113,28 @@ public abstract class ResolvedReferenceType implements ResolvedType,
 
     @Override
     public String toString() {
-        return "ReferenceType{" + getQualifiedName() +
-                ", typeParametersMap=" + typeParametersMap +
-                '}';
+        return "ReferenceType{" + getQualifiedName() + ", typeParametersMap=" + typeParametersMap + '}';
     }
 
-    ///
-    /// Relation with other types
-    ///
-
+    // /
+    // / Relation with other types
+    // /
     @Override
     public final boolean isReferenceType() {
         return true;
     }
 
-    ///
-    /// Downcasting
-    ///
-
+    // /
+    // / Downcasting
+    // /
     @Override
     public ResolvedReferenceType asReferenceType() {
         return this;
     }
 
-    ///
-    /// Naming
-    ///
-
+    // /
+    // / Naming
+    // /
     @Override
     public String describe() {
         StringBuilder sb = new StringBuilder();
@@ -149,30 +145,32 @@ public abstract class ResolvedReferenceType implements ResolvedType,
         }
         if (!typeParametersMap().isEmpty()) {
             sb.append("<");
-            sb.append(String.join(", ", typeDeclaration.getTypeParameters().stream()
-                    .map(tp -> typeParametersMap().getValue(tp).describe())
-                    .collect(Collectors.toList())));
+            sb.append(String.join(
+                    ", ",
+                    typeDeclaration.getTypeParameters().stream()
+                            .map(tp -> typeParametersMap().getValue(tp).describe())
+                            .collect(Collectors.toList())));
             sb.append(">");
         }
         return sb.toString();
     }
 
-    ///
-    /// TypeParameters
-    ///
-
+    // /
+    // / TypeParameters
+    // /
     /**
      * Execute a transformation on all the type parameters of this element.
      */
     public abstract ResolvedType transformTypeParameters(ResolvedTypeTransformer transformer);
 
     @Override
-    public ResolvedType replaceTypeVariables(ResolvedTypeParameterDeclaration tpToReplace, ResolvedType replaced,
-                                             Map<ResolvedTypeParameterDeclaration, ResolvedType> inferredTypes) {
+    public ResolvedType replaceTypeVariables(
+            ResolvedTypeParameterDeclaration tpToReplace,
+            ResolvedType replaced,
+            Map<ResolvedTypeParameterDeclaration, ResolvedType> inferredTypes) {
         if (replaced == null) {
             throw new IllegalArgumentException();
         }
-
         ResolvedReferenceType result = this;
         int i = 0;
         for (ResolvedType tp : this.typeParametersValues()) {
@@ -183,44 +181,42 @@ public abstract class ResolvedReferenceType implements ResolvedType,
             }
             // FIXME
             if (true) {
-                List<ResolvedType> typeParametersCorrected = result.asReferenceType().typeParametersValues();
+                List<ResolvedType> typeParametersCorrected =
+                        result.asReferenceType().typeParametersValues();
                 typeParametersCorrected.set(i, transformedTp);
                 result = create(typeDeclaration, typeParametersCorrected);
             }
             i++;
         }
-
         List<ResolvedType> values = result.typeParametersValues();
         // FIXME
         if (values.contains(tpToReplace)) {
             int index = values.indexOf(tpToReplace);
             values.set(index, replaced);
-            if(result.getTypeDeclaration().isPresent()) {
+            if (result.getTypeDeclaration().isPresent()) {
                 return create(result.getTypeDeclaration().get(), values);
             }
         }
-
         return result;
     }
 
-    ///
-    /// Assignability
-    ///
-
+    // /
+    // / Assignability
+    // /
     /**
      * This method checks if ThisType t = new OtherType() would compile.
      */
     @Override
     public abstract boolean isAssignableBy(ResolvedType other);
 
-    ///
-    /// Ancestors
-    ///
-
+    // /
+    // / Ancestors
+    // /
     /**
      * Return all ancestors, that means all superclasses and interfaces.
      * This list should always include Object (unless this is a reference to Object).
      * The type typeParametersValues should be expressed in terms of this type typeParametersValues.
+     * The default order of presenting ancestors corresponds to a search in depth.
      * <p>
      * For example, given:
      * <p>
@@ -232,6 +228,14 @@ public abstract class ResolvedReferenceType implements ResolvedType,
      */
     public abstract List<ResolvedReferenceType> getAllAncestors();
 
+    /**
+     * Return all ancestors, that means all superclasses and interfaces.
+     * This list should always include Object (unless this is a reference to Object).
+     * The type typeParametersValues should be expressed in terms of this type typeParametersValues.
+     */
+    public abstract List<ResolvedReferenceType> getAllAncestors(
+            Function<ResolvedReferenceTypeDeclaration, List<ResolvedReferenceType>> traverser);
+
     /**
      * Return direct ancestors, that means the superclasses and interfaces implemented directly.
      * This list should include Object if the class has no other superclass or the interface is not extending another interface.
@@ -253,14 +257,14 @@ public abstract class ResolvedReferenceType implements ResolvedType,
                 .collect(Collectors.toList());
     }
 
-    ///
-    /// Type parameters
-    ///
-
+    // /
+    // / Type parameters
+    // /
     /**
      * Get the type associated with the type parameter with the given name.
      * It returns Optional.empty unless the type declaration declares a type parameter with the given name.
      */
+    @Override
     public Optional<ResolvedType> getGenericParameterByName(String name) {
         for (ResolvedTypeParameterDeclaration tp : typeDeclaration.getTypeParameters()) {
             if (tp.getName().equals(name)) {
@@ -275,7 +279,11 @@ public abstract class ResolvedReferenceType implements ResolvedType,
      * The list can be empty for raw types.
      */
     public List<ResolvedType> typeParametersValues() {
-        return this.typeParametersMap.isEmpty() ? Collections.emptyList() : typeDeclaration.getTypeParameters().stream().map(tp -> typeParametersMap.getValue(tp)).collect(Collectors.toList());
+        return this.typeParametersMap.isEmpty()
+                ? Collections.emptyList()
+                : typeDeclaration.getTypeParameters().stream()
+                        .map(tp -> typeParametersMap.getValue(tp))
+                        .collect(Collectors.toList());
     }
 
     /**
@@ -286,7 +294,9 @@ public abstract class ResolvedReferenceType implements ResolvedType,
         List<Pair<ResolvedTypeParameterDeclaration, ResolvedType>> typeParametersMap = new ArrayList<>();
         if (!isRawType()) {
             for (int i = 0; i < typeDeclaration.getTypeParameters().size(); i++) {
-                typeParametersMap.add(new Pair<>(typeDeclaration.getTypeParameters().get(i), typeParametersValues().get(i)));
+                typeParametersMap.add(new Pair<>(
+                        typeDeclaration.getTypeParameters().get(i),
+                        typeParametersValues().get(i)));
             }
         }
         return typeParametersMap;
@@ -297,10 +307,9 @@ public abstract class ResolvedReferenceType implements ResolvedType,
         return typeParametersMap;
     }
 
-    ///
-    /// Other methods introduced by ReferenceType
-    ///
-
+    // /
+    // / Other methods introduced by ReferenceType
+    // /
     /**
      * Corresponding TypeDeclaration
      */
@@ -352,30 +361,32 @@ public abstract class ResolvedReferenceType implements ResolvedType,
      */
     public abstract Set<ResolvedFieldDeclaration> getDeclaredFields();
 
+    /*
+     * A class or interface whose declaration has one or more type parameters is a
+     * generic class or interface [JLS, 8.1.2, 9.1.2]. For example, the List
+     * interface has a single type parameter, E, representing its element type.
+     * A raw type, is the name of the generic type used without any accompanying type
+     * parameters [JLS, 4.8]. For example, the raw type corresponding to List<E> is
+     * List.
+     */
     public boolean isRawType() {
         if (!typeDeclaration.getTypeParameters().isEmpty()) {
             if (typeParametersMap().isEmpty()) {
                 return true;
             }
-            for (String name : typeParametersMap().getNames()) {
-                Optional<ResolvedType> value = typeParametersMap().getValueBySignature(name);
-                if (!value.isPresent() || !value.get().isTypeVariable() || !value.get().asTypeVariable().qualifiedName().equals(name)) {
-                    return false;
-                }
-            }
-            return true;
         }
         return false;
     }
 
+    @Override
     public Optional<ResolvedType> typeParamValue(ResolvedTypeParameterDeclaration typeParameterDeclaration) {
         if (typeParameterDeclaration.declaredOnMethod()) {
             throw new IllegalArgumentException();
         }
-        if(!this.getTypeDeclaration().isPresent()) {
-            return Optional.empty(); // TODO: Consider IllegalStateException or similar
+        if (!this.getTypeDeclaration().isPresent()) {
+            // TODO: Consider IllegalStateException or similar
+            return Optional.empty();
         }
-
         String typeId = this.getTypeDeclaration().get().getId();
         if (typeId.equals(typeParameterDeclaration.getContainerId())) {
             return Optional.of(this.typeParametersMap().getValue(typeParameterDeclaration));
@@ -388,6 +399,9 @@ public abstract class ResolvedReferenceType implements ResolvedType,
         return Optional.empty();
     }
 
+    /**
+     * @return A copy of the current reference type, without type parameters.
+     */
     public abstract ResolvedType toRawType();
 
     /**
@@ -396,17 +410,15 @@ public abstract class ResolvedReferenceType implements ResolvedType,
      * that have been overwritten.
      */
     public List<ResolvedMethodDeclaration> getAllMethods() {
-        if(!this.getTypeDeclaration().isPresent()) {
-            return new ArrayList<>(); // empty list -- consider IllegalStateException or similar
+        if (!this.getTypeDeclaration().isPresent()) {
+            // empty list -- consider IllegalStateException or similar
+            return new ArrayList<>();
         }
-
         // Get the methods declared directly on this.
-        List<ResolvedMethodDeclaration> allMethods = new LinkedList<>(
-                this.getTypeDeclaration().get().getDeclaredMethods()
-        );
+        List<ResolvedMethodDeclaration> allMethods =
+                new LinkedList<>(this.getTypeDeclaration().get().getDeclaredMethods());
         // Also get methods inherited from ancestors.
         getDirectAncestors().forEach(a -> allMethods.addAll(a.getAllMethods()));
-
         return allMethods;
     }
 
@@ -418,10 +430,7 @@ public abstract class ResolvedReferenceType implements ResolvedType,
         List<ResolvedFieldDeclaration> res = new LinkedList<>(this.getDeclaredFields().stream()
                 .filter(f -> f.accessSpecifier() != AccessSpecifier.PRIVATE)
                 .collect(Collectors.toList()));
-
-        getDirectAncestors().forEach(a ->
-                res.addAll(a.getAllFieldsVisibleToInheritors()));
-
+        getDirectAncestors().forEach(a -> res.addAll(a.getAllFieldsVisibleToInheritors()));
         return res;
     }
 
@@ -434,38 +443,26 @@ public abstract class ResolvedReferenceType implements ResolvedType,
     //
     // Protected methods
     //
+    protected abstract ResolvedReferenceType create(
+            ResolvedReferenceTypeDeclaration typeDeclaration, List<ResolvedType> typeParameters);
 
-    protected abstract ResolvedReferenceType create(ResolvedReferenceTypeDeclaration typeDeclaration, List<ResolvedType> typeParameters);
-
-    protected ResolvedReferenceType create(ResolvedReferenceTypeDeclaration typeDeclaration, ResolvedTypeParametersMap typeParametersMap) {
-        return create(typeDeclaration, typeDeclaration.getTypeParameters().stream()
-                .map(typeParametersMap::getValue)
-                .collect(Collectors.toList()));
+    protected ResolvedReferenceType create(
+            ResolvedReferenceTypeDeclaration typeDeclaration, ResolvedTypeParametersMap typeParametersMap) {
+        return create(
+                typeDeclaration,
+                typeDeclaration.getTypeParameters().stream()
+                        .map(typeParametersMap::getValue)
+                        .collect(Collectors.toList()));
     }
 
     protected abstract ResolvedReferenceType create(ResolvedReferenceTypeDeclaration typeDeclaration);
 
+    /*
+     * Verify if the resolved type is a boxing type of a primitive
+     */
     protected boolean isCorrespondingBoxingType(String typeName) {
-        switch (typeName) {
-            case "boolean":
-                return getQualifiedName().equals(Boolean.class.getCanonicalName());
-            case "char":
-                return getQualifiedName().equals(Character.class.getCanonicalName());
-            case "byte":
-                return getQualifiedName().equals(Byte.class.getCanonicalName());
-            case "short":
-                return getQualifiedName().equals(Short.class.getCanonicalName());
-            case "int":
-                return getQualifiedName().equals(Integer.class.getCanonicalName());
-            case "long":
-                return getQualifiedName().equals(Long.class.getCanonicalName());
-            case "float":
-                return getQualifiedName().equals(Float.class.getCanonicalName());
-            case "double":
-                return getQualifiedName().equals(Double.class.getCanonicalName());
-            default:
-                throw new UnsupportedOperationException(typeName);
-        }
+        ResolvedPrimitiveType resolvedPrimitiveType = (ResolvedPrimitiveType) ResolvedPrimitiveType.byName(typeName);
+        return getQualifiedName().equals(resolvedPrimitiveType.getBoxTypeQName());
     }
 
     protected boolean compareConsideringTypeParameters(ResolvedReferenceType other) {
@@ -486,9 +483,11 @@ public abstract class ResolvedReferenceType implements ResolvedType,
                 if (!thisParam.equals(otherParam)) {
                     if (thisParam instanceof ResolvedWildcard) {
                         ResolvedWildcard thisParamAsWildcard = (ResolvedWildcard) thisParam;
-                        if (thisParamAsWildcard.isSuper() && otherParam.isAssignableBy(thisParamAsWildcard.getBoundedType())) {
+                        if (thisParamAsWildcard.isSuper()
+                                && otherParam.isAssignableBy(thisParamAsWildcard.getBoundedType())) {
                             // ok
-                        } else if (thisParamAsWildcard.isExtends() && thisParamAsWildcard.getBoundedType().isAssignableBy(otherParam)) {
+                        } else if (thisParamAsWildcard.isExtends()
+                                && thisParamAsWildcard.getBoundedType().isAssignableBy(otherParam)) {
                             // ok
                         } else if (!thisParamAsWildcard.isBounded()) {
                             // ok
@@ -497,17 +496,25 @@ public abstract class ResolvedReferenceType implements ResolvedType,
                         }
                     } else {
                         if (thisParam instanceof ResolvedTypeVariable && otherParam instanceof ResolvedTypeVariable) {
-                            List<ResolvedType> thisBounds = thisParam.asTypeVariable().asTypeParameter().getBounds()
-                                    .stream().map(ResolvedTypeParameterDeclaration.Bound::getType)
-                                    .collect(Collectors.toList());
-                            List<ResolvedType> otherBounds = otherParam.asTypeVariable().asTypeParameter().getBounds()
-                                    .stream().map(ResolvedTypeParameterDeclaration.Bound::getType)
-                                    .collect(Collectors.toList());
+                            List<ResolvedType> thisBounds =
+                                    thisParam.asTypeVariable().asTypeParameter().getBounds().stream()
+                                            .map(ResolvedTypeParameterDeclaration.Bound::getType)
+                                            .collect(Collectors.toList());
+                            List<ResolvedType> otherBounds =
+                                    otherParam.asTypeVariable().asTypeParameter().getBounds().stream()
+                                            .map(ResolvedTypeParameterDeclaration.Bound::getType)
+                                            .collect(Collectors.toList());
                             return thisBounds.size() == otherBounds.size() && otherBounds.containsAll(thisBounds);
-                        } else if (!(thisParam instanceof ResolvedTypeVariable) && otherParam instanceof ResolvedTypeVariable) {
-                            return compareConsideringVariableTypeParameters(thisParam, (ResolvedTypeVariable)otherParam);
-                        } else if (thisParam instanceof ResolvedTypeVariable && !(otherParam instanceof ResolvedTypeVariable)) {
-                            return compareConsideringVariableTypeParameters(otherParam, (ResolvedTypeVariable) thisParam);
+                        }
+                        if (!(thisParam instanceof ResolvedTypeVariable)
+                                && otherParam instanceof ResolvedTypeVariable) {
+                            return compareConsideringVariableTypeParameters(
+                                    thisParam, (ResolvedTypeVariable) otherParam);
+                        }
+                        if (thisParam instanceof ResolvedTypeVariable
+                                && !(otherParam instanceof ResolvedTypeVariable)) {
+                            return compareConsideringVariableTypeParameters(
+                                    otherParam, (ResolvedTypeVariable) thisParam);
                         }
                         return false;
                     }
@@ -521,10 +528,10 @@ public abstract class ResolvedReferenceType implements ResolvedType,
     //
     // Private methods
     //
-    
-    private boolean compareConsideringVariableTypeParameters(ResolvedType referenceType, ResolvedTypeVariable typeVariable) {
+    private boolean compareConsideringVariableTypeParameters(
+            ResolvedType referenceType, ResolvedTypeVariable typeVariable) {
         // verify if the ResolvedTypeVariable has only one type variable and the bound is
-        // not a reference type with a bound parameter 
+        // not a reference type with a bound parameter
         // for example EnumSet<E> noneOf(Class<E> elementType)
         List<Bound> bounds = typeVariable.asTypeVariable().asTypeParameter().getBounds();
         if (bounds.size() == 1) {
@@ -551,7 +558,6 @@ public abstract class ResolvedReferenceType implements ResolvedType,
 
     public abstract ResolvedReferenceType deriveTypeParameters(ResolvedTypeParametersMap typeParametersMap);
 
-
     /**
      * We don't make this _ex_plicit in the data representation because that would affect codegen
      * and make everything generate like {@code <T extends Object>} instead of {@code <T>}
@@ -562,8 +568,9 @@ public abstract class ResolvedReferenceType implements ResolvedType,
      */
     public boolean isJavaLangObject() {
         return this.isReferenceType()
-                && hasName() // Consider anonymous classes
-                && getQualifiedName().equals(java.lang.Object.class.getCanonicalName());
+                && // Consider anonymous classes
+                hasName()
+                && getQualifiedName().equals(JAVA_LANG_OBJECT);
     }
 
     /**
@@ -572,8 +579,60 @@ public abstract class ResolvedReferenceType implements ResolvedType,
      */
     public boolean isJavaLangEnum() {
         return this.isReferenceType()
-                && hasName() // Consider anonymous classes
-                && getQualifiedName().equals(java.lang.Enum.class.getCanonicalName());
+                && // Consider anonymous classes
+                hasName()
+                && getQualifiedName().equals(JAVA_LANG_ENUM);
     }
 
+    // /
+    // / boxing/unboxing capability
+    // /
+    /*
+     * Returns true if the reference type can be unboxed to the primitive type
+     * For example : Integer to int
+     */
+    public boolean isUnboxable() {
+        return Arrays.stream(ResolvedPrimitiveType.values())
+                .anyMatch(pt -> getQualifiedName().equals(pt.getBoxTypeQName()));
+    }
+
+    /*
+     * Returns true if the reference type can be unboxed to the specified primitive type
+     * For example : Integer to int
+     */
+    public boolean isUnboxableTo(ResolvedPrimitiveType primitiveType) {
+        return primitiveType.getBoxTypeQName().equals(this.asReferenceType().describe());
+    }
+
+    /*
+     * Returns the optional corresponding primitive type
+     */
+    public Optional<ResolvedPrimitiveType> toUnboxedType() {
+        return Arrays.stream(ResolvedPrimitiveType.values())
+                .filter(pt -> this.asReferenceType().getQualifiedName().equals(pt.getBoxTypeQName()))
+                .findFirst();
+    }
+
+    // /
+    // / Erasure
+    // /
+    // The erasure of a parameterized type (§4.5) G<T1,...,Tn> is |G|.
+    @Override
+    public ResolvedType erasure() {
+        if (!typeDeclaration.isGeneric()) return this;
+        return create(typeDeclaration, erasureOfParamaters(typeParametersMap));
+    }
+
+    private List<ResolvedType> erasureOfParamaters(ResolvedTypeParametersMap typeParametersMap) {
+        return new ArrayList<ResolvedType>();
+    }
+
+    private boolean isJavaObject(ResolvedType rt) {
+        return rt != null && rt.isReferenceType() && rt.asReferenceType().isJavaLangObject();
+    }
+
+    @Override
+    public String toDescriptor() {
+        return String.format("L%s;", getQualifiedName().replace(".", "/"));
+    }
 }
