@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2015-2016 Federico Tomassetti
- * Copyright (C) 2017-2020 The JavaParser Team.
+ * Copyright (C) 2017-2024 The JavaParser Team.
  *
  * This file is part of JavaParser.
  *
@@ -24,27 +24,21 @@ package com.github.javaparser.symbolsolver.javaparsermodel.contexts;
 import com.github.javaparser.ast.CompilationUnit;
 import com.github.javaparser.ast.ImportDeclaration;
 import com.github.javaparser.ast.Node;
-import com.github.javaparser.ast.body.AnnotationDeclaration;
-import com.github.javaparser.ast.body.ClassOrInterfaceDeclaration;
-import com.github.javaparser.ast.body.EnumDeclaration;
 import com.github.javaparser.ast.body.TypeDeclaration;
 import com.github.javaparser.ast.expr.Name;
 import com.github.javaparser.ast.type.ClassOrInterfaceType;
+import com.github.javaparser.resolution.TypeSolver;
 import com.github.javaparser.resolution.declarations.*;
+import com.github.javaparser.resolution.logic.MethodResolutionLogic;
+import com.github.javaparser.resolution.model.SymbolReference;
 import com.github.javaparser.resolution.types.ResolvedType;
 import com.github.javaparser.symbolsolver.javaparsermodel.JavaParserFacade;
-import com.github.javaparser.symbolsolver.javaparsermodel.declarations.JavaParserAnnotationDeclaration;
 import com.github.javaparser.symbolsolver.javaparsermodel.declarations.JavaParserClassDeclaration;
-import com.github.javaparser.symbolsolver.javaparsermodel.declarations.JavaParserEnumDeclaration;
 import com.github.javaparser.symbolsolver.javaparsermodel.declarations.JavaParserInterfaceDeclaration;
-import com.github.javaparser.symbolsolver.model.resolution.SymbolReference;
-import com.github.javaparser.symbolsolver.model.resolution.TypeSolver;
-import com.github.javaparser.symbolsolver.resolution.MethodResolutionLogic;
 import com.github.javaparser.symbolsolver.resolution.SymbolSolver;
-
+import java.util.ArrayList;
 import java.util.LinkedList;
 import java.util.List;
-import java.util.Optional;
 import java.util.stream.Collectors;
 
 /**
@@ -52,14 +46,19 @@ import java.util.stream.Collectors;
  */
 public class CompilationUnitContext extends AbstractJavaParserContext<CompilationUnit> {
 
+    private static final String DEFAULT_PACKAGE = "java.lang";
+
+    // Contains the names of static import declarations with asterisks that have
+    // already been resolved. The aim is to keep a history of name searches for the
+    // same resolution attempt in order to avoid a recursive issue leading to a
+    // stackoverflow exception. See issues 4450 & 2720
+    private static ThreadLocal<List<String>> resolvedStaticImport =
+            ThreadLocal.withInitial(() -> new ArrayList<String>());
+
     ///
     /// Static methods
     ///
 
-    private static boolean isQualifiedName(String name) {
-        return name.contains(".");
-    }
-
     ///
     /// Constructors
     ///
@@ -83,9 +82,8 @@ public class CompilationUnitContext extends AbstractJavaParserContext<Compilatio
             SymbolReference<ResolvedTypeDeclaration> type = this.solveType(typeName);
             if (type.isSolved()) {
                 return new SymbolSolver(typeSolver).solveSymbolInType(type.getCorrespondingDeclaration(), memberName);
-            } else {
-                itName = typeName;
             }
+            itName = typeName;
         }
 
         // Look among statically imported values
@@ -93,12 +91,17 @@ public class CompilationUnitContext extends AbstractJavaParserContext<Compilatio
             if (importDecl.isStatic()) {
                 if (importDecl.isAsterisk()) {
                     String qName = importDecl.getNameAsString();
-                    ResolvedTypeDeclaration importedType = typeSolver.solveType(qName);
+                    // Try to resolve the name in from declarations imported with asterisks only if
+                    // they have not already been analysed, otherwise this can lead to an infinite
+                    // loop via circular dependencies.
+                    if (!isAlreadyResolved(qName)) {
+                        resolvedStaticImport.get().add(qName);
+                        ResolvedTypeDeclaration importedType = typeSolver.solveType(qName);
 
-                    // avoid infinite recursion
-                    if (!isAncestorOf(importedType)) {
-                        SymbolReference<? extends ResolvedValueDeclaration> ref = new SymbolSolver(typeSolver).solveSymbolInType(importedType, name);
+                        SymbolReference<? extends ResolvedValueDeclaration> ref =
+                                new SymbolSolver(typeSolver).solveSymbolInType(importedType, name);
                         if (ref.isSolved()) {
+                            resolvedStaticImport.remove(); // clear the search history
                             return ref;
                         }
                     }
@@ -117,27 +120,29 @@ public class CompilationUnitContext extends AbstractJavaParserContext<Compilatio
             }
         }
 
-        return SymbolReference.unsolved(ResolvedValueDeclaration.class);
+        // Clear of the search history because we don't want this context to be reused
+        // in another search.
+        resolvedStaticImport.remove();
+        return SymbolReference.unsolved();
+    }
+
+    private boolean isAlreadyResolved(String qName) {
+        return resolvedStaticImport.get().contains(qName);
     }
 
     @Override
-    public SymbolReference<ResolvedTypeDeclaration> solveType(String name) {
+    public SymbolReference<ResolvedTypeDeclaration> solveType(String name, List<ResolvedType> typeArguments) {
 
         if (wrappedNode.getTypes() != null) {
             // Look for types in this compilation unit. For instance, if the given name is "A", there may be a class or
             // interface in this compilation unit called "A".
             for (TypeDeclaration<?> type : wrappedNode.getTypes()) {
                 if (type.getName().getId().equals(name)
-                    || type.getFullyQualifiedName().map(qualified -> qualified.equals(name)).orElse(false)) {
-                    if (type instanceof ClassOrInterfaceDeclaration) {
-                        return SymbolReference.solved(JavaParserFacade.get(typeSolver).getTypeDeclaration((ClassOrInterfaceDeclaration) type));
-                    } else if (type instanceof AnnotationDeclaration) {
-                        return SymbolReference.solved(new JavaParserAnnotationDeclaration((AnnotationDeclaration) type, typeSolver));
-                    } else if (type instanceof EnumDeclaration) {
-                        return SymbolReference.solved(new JavaParserEnumDeclaration((EnumDeclaration) type, typeSolver));
-                    } else {
-                        throw new UnsupportedOperationException(type.getClass().getCanonicalName());
-                    }
+                        || type.getFullyQualifiedName()
+                                .map(qualified -> qualified.equals(name))
+                                .orElse(false)) {
+                    return SymbolReference.solved(
+                            JavaParserFacade.get(typeSolver).getTypeDeclaration(type));
                 }
             }
 
@@ -146,19 +151,8 @@ public class CompilationUnitContext extends AbstractJavaParserContext<Compilatio
             // class or interface called "B". Since the type that we're looking for can be nested arbitrarily deeply
             // ("A.B.C.D"), we look for the outermost type ("A" in the previous example) first, then recursively invoke
             // this method for the remaining part of the given name.
-            if (name.indexOf('.') > -1) {
-                SymbolReference<ResolvedTypeDeclaration> ref = null;
-                SymbolReference<ResolvedTypeDeclaration> outerMostRef =
-                    solveType(name.substring(0, name.indexOf(".")));
-                if (outerMostRef != null && outerMostRef.isSolved() &&
-                    outerMostRef.getCorrespondingDeclaration() instanceof JavaParserClassDeclaration) {
-                    ref = ((JavaParserClassDeclaration) outerMostRef.getCorrespondingDeclaration())
-                        .solveType(name.substring(name.indexOf(".") + 1));
-                } else if (outerMostRef != null && outerMostRef.isSolved() &&
-                    outerMostRef.getCorrespondingDeclaration() instanceof JavaParserInterfaceDeclaration) {
-                    ref = ((JavaParserInterfaceDeclaration) outerMostRef.getCorrespondingDeclaration())
-                        .solveType(name.substring(name.indexOf(".") + 1));
-                }
+            if (isCompositeName(name)) {
+                SymbolReference<ResolvedTypeDeclaration> ref = solveTypeFromOuterMostRef(name);
                 if (ref != null && ref.isSolved()) {
                     return ref;
                 }
@@ -167,16 +161,14 @@ public class CompilationUnitContext extends AbstractJavaParserContext<Compilatio
 
         // Inspect imports for matches, prior to inspecting other classes within the package (per issue #1526)
         int dotPos = name.indexOf('.');
-        String prefix = null;
-        if (dotPos > -1) {
-            prefix = name.substring(0, dotPos);
-        }
+        String prefix = isCompositeName(name) ? name.substring(0, dotPos) : null;
         // look into single type imports
         for (ImportDeclaration importDecl : wrappedNode.getImports()) {
             if (!importDecl.isAsterisk()) {
                 String qName = importDecl.getNameAsString();
                 boolean defaultPackage = !importDecl.getName().getQualifier().isPresent();
-                boolean found = !defaultPackage && importDecl.getName().getIdentifier().equals(name);
+                boolean found =
+                        !defaultPackage && importDecl.getName().getIdentifier().equals(name);
                 if (!found && prefix != null) {
                     found = qName.endsWith("." + prefix);
                     if (found) {
@@ -194,17 +186,24 @@ public class CompilationUnitContext extends AbstractJavaParserContext<Compilatio
 
         // Look in current package
         if (this.wrappedNode.getPackageDeclaration().isPresent()) {
-            String qName = this.wrappedNode.getPackageDeclaration().get().getName().toString() + "." + name;
+            String qName = this.wrappedNode.getPackageDeclaration().get().getNameAsString() + "." + name;
             SymbolReference<ResolvedReferenceTypeDeclaration> ref = typeSolver.tryToSolveType(qName);
             if (ref != null && ref.isSolved()) {
                 return SymbolReference.adapt(ref, ResolvedTypeDeclaration.class);
             }
         } else {
             // look for classes in the default package
-            String qName = name;
-            SymbolReference<ResolvedReferenceTypeDeclaration> ref = typeSolver.tryToSolveType(qName);
-            if (ref != null && ref.isSolved()) {
-                return SymbolReference.adapt(ref, ResolvedTypeDeclaration.class);
+            if (isCompositeName(name)) {
+                SymbolReference<ResolvedTypeDeclaration> ref = solveExternalTypeFromOuterMostRef(name);
+                if (ref != null && ref.isSolved()) {
+                    return ref;
+                }
+            } else {
+                String qName = name;
+                SymbolReference<ResolvedReferenceTypeDeclaration> ref = typeSolver.tryToSolveType(qName);
+                if (ref != null && ref.isSolved()) {
+                    return SymbolReference.adapt(ref, ResolvedTypeDeclaration.class);
+                }
             }
         }
 
@@ -220,33 +219,79 @@ public class CompilationUnitContext extends AbstractJavaParserContext<Compilatio
         }
 
         // Look in the java.lang package
-        SymbolReference<ResolvedReferenceTypeDeclaration> ref = typeSolver.tryToSolveType("java.lang." + name);
+        SymbolReference<ResolvedReferenceTypeDeclaration> ref = typeSolver.tryToSolveType(DEFAULT_PACKAGE + "." + name);
         if (ref != null && ref.isSolved()) {
             return SymbolReference.adapt(ref, ResolvedTypeDeclaration.class);
         }
 
-        // DO NOT look for absolute name if this name is not qualified: you cannot import classes from the default package
-        if (isQualifiedName(name)) {
+        if (isCompositeName(name)) {
             return SymbolReference.adapt(typeSolver.tryToSolveType(name), ResolvedTypeDeclaration.class);
-        } else {
-            return SymbolReference.unsolved(ResolvedReferenceTypeDeclaration.class);
         }
+        return SymbolReference.unsolved();
+    }
+
+    /*
+     * Returns true if the name contains 'dot' separator.
+     */
+    protected boolean isCompositeName(String name) {
+        return name.contains(".");
+    }
+
+    /*
+     * Look for member classes/interfaces of types in this compilation unit.
+     */
+    private SymbolReference<ResolvedTypeDeclaration> solveTypeFromOuterMostRef(String name) {
+        SymbolReference<ResolvedTypeDeclaration> ref = null;
+        SymbolReference<ResolvedTypeDeclaration> outerMostRef = solveType(name.substring(0, name.indexOf(".")));
+        if (outerMostRef != null
+                && outerMostRef.isSolved()
+                && outerMostRef.getCorrespondingDeclaration() instanceof JavaParserClassDeclaration) {
+            ref = ((JavaParserClassDeclaration) outerMostRef.getCorrespondingDeclaration())
+                    .solveType(name.substring(name.indexOf(".") + 1));
+        } else if (outerMostRef != null
+                && outerMostRef.isSolved()
+                && outerMostRef.getCorrespondingDeclaration() instanceof JavaParserInterfaceDeclaration) {
+            ref = ((JavaParserInterfaceDeclaration) outerMostRef.getCorrespondingDeclaration())
+                    .solveType(name.substring(name.indexOf(".") + 1));
+        }
+        return ref;
+    }
+
+    /*
+     * Look for member classes/interfaces of types defined in another compilation unit.
+     */
+    private SymbolReference<ResolvedTypeDeclaration> solveExternalTypeFromOuterMostRef(String name) {
+        SymbolReference<ResolvedTypeDeclaration> ref = null;
+        SymbolReference<ResolvedReferenceTypeDeclaration> outerMostRef =
+                typeSolver.tryToSolveType(name.substring(0, name.indexOf(".")));
+        if (outerMostRef != null
+                && outerMostRef.isSolved()
+                && outerMostRef.getCorrespondingDeclaration() instanceof JavaParserClassDeclaration) {
+            ref = ((JavaParserClassDeclaration) outerMostRef.getCorrespondingDeclaration())
+                    .getContext()
+                    .solveType(name.substring(name.indexOf(".") + 1));
+        } else if (outerMostRef != null
+                && outerMostRef.isSolved()
+                && outerMostRef.getCorrespondingDeclaration() instanceof JavaParserInterfaceDeclaration) {
+            ref = ((JavaParserInterfaceDeclaration) outerMostRef.getCorrespondingDeclaration())
+                    .getContext()
+                    .solveType(name.substring(name.indexOf(".") + 1));
+        }
+        return ref;
     }
 
     private String qName(ClassOrInterfaceType type) {
         if (type.getScope().isPresent()) {
             return qName(type.getScope().get()) + "." + type.getName().getId();
-        } else {
-            return type.getName().getId();
         }
+        return type.getName().getId();
     }
 
     private String qName(Name name) {
         if (name.getQualifier().isPresent()) {
             return qName(name.getQualifier().get()) + "." + name.getId();
-        } else {
-            return name.getId();
         }
+        return name.getId();
     }
 
     private String toSimpleName(String qName) {
@@ -258,33 +303,37 @@ public class CompilationUnitContext extends AbstractJavaParserContext<Compilatio
         int lastDot = qName.lastIndexOf('.');
         if (lastDot == -1) {
             throw new UnsupportedOperationException();
-        } else {
-            return qName.substring(0, lastDot);
         }
+        return qName.substring(0, lastDot);
     }
 
     @Override
-    public SymbolReference<ResolvedMethodDeclaration> solveMethod(String name, List<ResolvedType> argumentsTypes, boolean staticOnly) {
+    public SymbolReference<ResolvedMethodDeclaration> solveMethod(
+            String name, List<ResolvedType> argumentsTypes, boolean staticOnly) {
         for (ImportDeclaration importDecl : wrappedNode.getImports()) {
             if (importDecl.isStatic()) {
                 if (importDecl.isAsterisk()) {
                     String importString = importDecl.getNameAsString();
 
                     if (this.wrappedNode.getPackageDeclaration().isPresent()
-                        && this.wrappedNode.getPackageDeclaration().get().getName().getIdentifier().equals(packageName(importString))
-                        && this.wrappedNode.getTypes().stream().anyMatch(it -> it.getName().getIdentifier().equals(toSimpleName(importString)))) {
-                        // We are using a static import on a type defined in this file. It means the value was not found at
-                        // a lower level so this will fail
-                        return SymbolReference.unsolved(ResolvedMethodDeclaration.class);
+                            && this.wrappedNode
+                                    .getPackageDeclaration()
+                                    .get()
+                                    .getName()
+                                    .getIdentifier()
+                                    .equals(packageName(importString))
+                            && this.wrappedNode.getTypes().stream()
+                                    .anyMatch(it -> it.getName().getIdentifier().equals(toSimpleName(importString)))) {
+                        // We are using a static import on a type defined in this file. It means the value was not found
+                        // at a lower level so this will fail
+                        return SymbolReference.unsolved();
                     }
 
                     ResolvedTypeDeclaration ref = typeSolver.solveType(importString);
-                    // avoid infinite recursion
-                    if (!isAncestorOf(ref)) {
-                        SymbolReference<ResolvedMethodDeclaration> method = MethodResolutionLogic.solveMethodInType(ref, name, argumentsTypes, true);
-                        if (method.isSolved()) {
-                            return method;
-                        }
+                    SymbolReference<ResolvedMethodDeclaration> method =
+                            MethodResolutionLogic.solveMethodInType(ref, name, argumentsTypes, true);
+                    if (method.isSolved()) {
+                        return method;
                     }
                 } else {
                     String qName = importDecl.getNameAsString();
@@ -292,17 +341,17 @@ public class CompilationUnitContext extends AbstractJavaParserContext<Compilatio
                     if (qName.equals(name) || qName.endsWith("." + name)) {
                         String typeName = getType(qName);
                         ResolvedTypeDeclaration ref = typeSolver.solveType(typeName);
-                        SymbolReference<ResolvedMethodDeclaration> method = MethodResolutionLogic.solveMethodInType(ref, name, argumentsTypes, true);
+                        SymbolReference<ResolvedMethodDeclaration> method =
+                                MethodResolutionLogic.solveMethodInType(ref, name, argumentsTypes, true);
                         if (method.isSolved()) {
                             return method;
-                        } else {
-                            return SymbolReference.unsolved(ResolvedMethodDeclaration.class);
                         }
+                        return SymbolReference.unsolved();
                     }
                 }
             }
         }
-        return SymbolReference.unsolved(ResolvedMethodDeclaration.class);
+        return SymbolReference.unsolved();
     }
 
     @Override
@@ -311,13 +360,16 @@ public class CompilationUnitContext extends AbstractJavaParserContext<Compilatio
         // Consider the static imports for static fields
         for (ImportDeclaration importDeclaration : wrappedNode.getImports()) {
             if (importDeclaration.isStatic()) {
-                Name typeNameAsNode = importDeclaration.isAsterisk() ? importDeclaration.getName() : importDeclaration.getName().getQualifier().get();
+                Name typeNameAsNode = importDeclaration.isAsterisk()
+                        ? importDeclaration.getName()
+                        : importDeclaration.getName().getQualifier().get();
                 String typeName = typeNameAsNode.asString();
                 ResolvedReferenceTypeDeclaration typeDeclaration = typeSolver.solveType(typeName);
                 res.addAll(typeDeclaration.getAllFields().stream()
-                               .filter(f -> f.isStatic())
-                               .filter(f -> importDeclaration.isAsterisk() || importDeclaration.getName().getIdentifier().equals(f.getName()))
-                               .collect(Collectors.toList()));
+                        .filter(f -> f.isStatic())
+                        .filter(f -> importDeclaration.isAsterisk()
+                                || importDeclaration.getName().getIdentifier().equals(f.getName()))
+                        .collect(Collectors.toList()));
             }
         }
         return res;
@@ -344,20 +396,4 @@ public class CompilationUnitContext extends AbstractJavaParserContext<Compilatio
         String memberName = qName.substring(index + 1);
         return memberName;
     }
-
-    private boolean isAncestorOf(ResolvedTypeDeclaration descendant) {
-        if (descendant instanceof AssociableToAST) {
-            Optional<Node> astOpt = ((AssociableToAST<Node>) descendant).toAst();
-            if (astOpt.isPresent()) {
-                return wrappedNode.isAncestorOf(astOpt.get());
-            } else {
-                return false;
-            }
-        } else if (descendant instanceof JavaParserEnumDeclaration) {
-            return wrappedNode.isAncestorOf(((JavaParserEnumDeclaration) descendant).getWrappedNode());
-        } else {
-            throw new UnsupportedOperationException();
-        }
-    }
-
 }
