@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2015-2016 Federico Tomassetti
- * Copyright (C) 2017-2020 The JavaParser Team.
+ * Copyright (C) 2017-2024 The JavaParser Team.
  *
  * This file is part of JavaParser.
  *
@@ -22,9 +22,8 @@
 package com.github.javaparser.symbolsolver.javaparsermodel.declarators;
 
 import com.github.javaparser.ast.Node;
+import com.github.javaparser.resolution.TypeSolver;
 import com.github.javaparser.resolution.declarations.ResolvedValueDeclaration;
-import com.github.javaparser.symbolsolver.model.resolution.TypeSolver;
-
 import java.util.Collections;
 import java.util.List;
 
@@ -41,5 +40,4 @@ public class NoSymbolDeclarator<N extends Node> extends AbstractSymbolDeclarator
     public List<ResolvedValueDeclaration> getSymbolDeclarations() {
         return Collections.emptyList();
     }
-
 }
