@@ -28,29 +28,48 @@ import com.github.javaparser.resolution.declarations.ResolvedReferenceTypeDeclar
 import com.github.javaparser.resolution.model.SymbolReference;
 import com.github.javaparser.resolution.model.typesystem.ReferenceTypeImpl;
 import com.github.javaparser.resolution.types.ResolvedType;
+import java.util.HashMap;
+import java.util.Map;
+import java.util.function.Function;
 import javassist.CtMethod;
 import javassist.bytecode.AnnotationDefaultAttribute;
 import javassist.bytecode.BadBytecode;
 import javassist.bytecode.SignatureAttribute;
 import javassist.bytecode.annotation.*;
 
-import java.util.HashMap;
-import java.util.Map;
-import java.util.function.Function;
-
 /**
  * @author Malte Skoruppa
  */
 public class JavassistAnnotationMemberDeclaration implements ResolvedAnnotationMemberDeclaration {
-    
-    private static Map<Class<? extends MemberValue>, Function<MemberValue, ? extends Expression>> memberValueAsExressionConverter = new HashMap<>();
+
+    private static Map<Class<? extends MemberValue>, Function<MemberValue, ? extends Expression>>
+            memberValueAsExressionConverter = new HashMap<>();
+
     static {
-        memberValueAsExressionConverter.put(BooleanMemberValue.class, (memberValue) -> new BooleanLiteralExpr(BooleanMemberValue.class.cast(memberValue).getValue()));
-        memberValueAsExressionConverter.put(CharMemberValue.class, (memberValue) -> new CharLiteralExpr(CharMemberValue.class.cast(memberValue).getValue()));
-        memberValueAsExressionConverter.put(DoubleMemberValue.class, (memberValue) -> new DoubleLiteralExpr(DoubleMemberValue.class.cast(memberValue).getValue()));
-        memberValueAsExressionConverter.put(IntegerMemberValue.class, (memberValue) -> new IntegerLiteralExpr(IntegerMemberValue.class.cast(memberValue).getValue()));
-        memberValueAsExressionConverter.put(LongMemberValue.class, (memberValue) -> new LongLiteralExpr(LongMemberValue.class.cast(memberValue).getValue()));
-        memberValueAsExressionConverter.put(StringMemberValue.class, (memberValue) -> new StringLiteralExpr(StringMemberValue.class.cast(memberValue).getValue()));
+        memberValueAsExressionConverter.put(
+                BooleanMemberValue.class,
+                (memberValue) -> new BooleanLiteralExpr(
+                        BooleanMemberValue.class.cast(memberValue).getValue()));
+        memberValueAsExressionConverter.put(
+                CharMemberValue.class,
+                (memberValue) -> new CharLiteralExpr(
+                        CharMemberValue.class.cast(memberValue).getValue()));
+        memberValueAsExressionConverter.put(
+                DoubleMemberValue.class,
+                (memberValue) -> new DoubleLiteralExpr(
+                        DoubleMemberValue.class.cast(memberValue).getValue()));
+        memberValueAsExressionConverter.put(
+                IntegerMemberValue.class,
+                (memberValue) -> new IntegerLiteralExpr(
+                        IntegerMemberValue.class.cast(memberValue).getValue()));
+        memberValueAsExressionConverter.put(
+                LongMemberValue.class,
+                (memberValue) -> new LongLiteralExpr(
+                        LongMemberValue.class.cast(memberValue).getValue()));
+        memberValueAsExressionConverter.put(
+                StringMemberValue.class,
+                (memberValue) -> new StringLiteralExpr(
+                        StringMemberValue.class.cast(memberValue).getValue()));
     }
 
     private CtMethod annotationMember;
@@ -63,20 +82,25 @@ public class JavassistAnnotationMemberDeclaration implements ResolvedAnnotationM
 
     @Override
     public Expression getDefaultValue() {
-         AnnotationDefaultAttribute defaultAttribute = (AnnotationDefaultAttribute) annotationMember.getMethodInfo().getAttribute(AnnotationDefaultAttribute.tag);
-         if (defaultAttribute == null) return null;
-         MemberValue memberValue = defaultAttribute.getDefaultValue();
-         Function<MemberValue, ? extends Expression> fn = memberValueAsExressionConverter.get(memberValue.getClass());
-         if (fn == null) throw new UnsupportedOperationException(String.format("Obtaining the type of the annotation member %s is not supported yet.", annotationMember.getName()));
-         return fn.apply(memberValue);
+        AnnotationDefaultAttribute defaultAttribute = (AnnotationDefaultAttribute)
+                annotationMember.getMethodInfo().getAttribute(AnnotationDefaultAttribute.tag);
+        if (defaultAttribute == null) return null;
+        MemberValue memberValue = defaultAttribute.getDefaultValue();
+        Function<MemberValue, ? extends Expression> fn = memberValueAsExressionConverter.get(memberValue.getClass());
+        if (fn == null)
+            throw new UnsupportedOperationException(String.format(
+                    "Obtaining the type of the annotation member %s is not supported yet.",
+                    annotationMember.getName()));
+        return fn.apply(memberValue);
     }
-    
+
     @Override
     public ResolvedType getType() {
         try {
             String descriptor = annotationMember.getMethodInfo().getDescriptor();
             SignatureAttribute.MethodSignature signature = SignatureAttribute.toMethodSignature(descriptor);
-            SymbolReference<ResolvedReferenceTypeDeclaration> returnType = typeSolver.tryToSolveType(signature.getReturnType().jvmTypeName());
+            SymbolReference<ResolvedReferenceTypeDeclaration> returnType =
+                    typeSolver.tryToSolveType(signature.getReturnType().jvmTypeName());
             if (returnType.isSolved()) {
                 return new ReferenceTypeImpl(returnType.getCorrespondingDeclaration());
             }
@@ -84,7 +108,9 @@ public class JavassistAnnotationMemberDeclaration implements ResolvedAnnotationM
             // We don't expect this to happen, but we handle it anyway.
             throw new IllegalStateException("An invalid descriptor was received from JavaAssist.", e);
         }
-        throw new UnsupportedOperationException(String.format("Obtaining the type of the annotation member %s is not supported yet.", annotationMember.getLongName()));
+        throw new UnsupportedOperationException(String.format(
+                "Obtaining the type of the annotation member %s is not supported yet.",
+                annotationMember.getLongName()));
     }
 
     @Override
