@@ -33,7 +33,6 @@ import com.github.javaparser.resolution.types.ResolvedReferenceType;
 import com.github.javaparser.resolution.types.ResolvedType;
 import com.github.javaparser.symbolsolver.core.resolution.MethodUsageResolutionCapability;
 import com.github.javaparser.symbolsolver.logic.AbstractTypeDeclaration;
-
 import java.lang.annotation.Inherited;
 import java.util.*;
 import java.util.stream.Collectors;
@@ -42,9 +41,8 @@ import java.util.stream.Stream;
 /**
  * @author Malte Skoruppa
  */
-public class ReflectionAnnotationDeclaration extends AbstractTypeDeclaration implements ResolvedAnnotationDeclaration,
-                                                                                        MethodUsageResolutionCapability,
-                                                                                        MethodResolutionCapability {
+public class ReflectionAnnotationDeclaration extends AbstractTypeDeclaration
+        implements ResolvedAnnotationDeclaration, MethodUsageResolutionCapability, MethodResolutionCapability {
 
     ///
     /// Fields
@@ -96,9 +94,7 @@ public class ReflectionAnnotationDeclaration extends AbstractTypeDeclaration imp
 
     @Override
     public String toString() {
-        return getClass().getSimpleName() + "{" +
-               "clazz=" + clazz.getCanonicalName() +
-               '}';
+        return getClass().getSimpleName() + "{" + "clazz=" + clazz.getCanonicalName() + '}';
     }
 
     @Override
@@ -158,7 +154,8 @@ public class ReflectionAnnotationDeclaration extends AbstractTypeDeclaration imp
     @Override
     public Optional<ResolvedReferenceTypeDeclaration> containerType() {
         // TODO #1841
-        throw new UnsupportedOperationException("containerType() is not supported for " + this.getClass().getCanonicalName());
+        throw new UnsupportedOperationException(
+                "containerType() is not supported for " + this.getClass().getCanonicalName());
     }
 
     /**
@@ -175,8 +172,8 @@ public class ReflectionAnnotationDeclaration extends AbstractTypeDeclaration imp
     @Override
     public Set<ResolvedReferenceTypeDeclaration> internalTypes() {
         return Arrays.stream(this.clazz.getDeclaredClasses())
-            .map(ic -> ReflectionFactory.typeDeclarationFor(ic, typeSolver))
-            .collect(Collectors.toSet());
+                .map(ic -> ReflectionFactory.typeDeclarationFor(ic, typeSolver))
+                .collect(Collectors.toSet());
     }
 
     @Override
@@ -187,17 +184,18 @@ public class ReflectionAnnotationDeclaration extends AbstractTypeDeclaration imp
     @Override
     public List<ResolvedAnnotationMemberDeclaration> getAnnotationMembers() {
         return Stream.of(clazz.getDeclaredMethods())
-                       .map(m -> new ReflectionAnnotationMemberDeclaration(m, typeSolver))
-                       .collect(Collectors.toList());
+                .map(m -> new ReflectionAnnotationMemberDeclaration(m, typeSolver))
+                .collect(Collectors.toList());
     }
 
     @Override
-    public Optional<MethodUsage> solveMethodAsUsage(final String name,
-                                                    final List<ResolvedType> parameterTypes,
-                                                    final Context invokationContext,
-                                                    final List<ResolvedType> typeParameterValues) {
-        Optional<MethodUsage> res = ReflectionMethodResolutionLogic.solveMethodAsUsage(name, parameterTypes, typeSolver, invokationContext,
-            typeParameterValues, this, clazz);
+    public Optional<MethodUsage> solveMethodAsUsage(
+            final String name,
+            final List<ResolvedType> parameterTypes,
+            final Context invokationContext,
+            final List<ResolvedType> typeParameterValues) {
+        Optional<MethodUsage> res = ReflectionMethodResolutionLogic.solveMethodAsUsage(
+                name, parameterTypes, typeSolver, invokationContext, typeParameterValues, this, clazz);
         if (res.isPresent()) {
             // We have to replace method type typeParametersValues here
             InferenceContext inferenceContext = new InferenceContext(typeSolver);
@@ -213,7 +211,7 @@ public class ReflectionAnnotationDeclaration extends AbstractTypeDeclaration imp
             }
             try {
                 ResolvedType returnType = inferenceContext.addSingle(methodUsage.returnType());
-                for (int j=0;j<parameters.size();j++) {
+                for (int j = 0; j < parameters.size(); j++) {
                     methodUsage = methodUsage.replaceParamType(j, inferenceContext.resolve(parameters.get(j)));
                 }
                 methodUsage = methodUsage.replaceReturnType(inferenceContext.resolve(returnType));
@@ -227,11 +225,9 @@ public class ReflectionAnnotationDeclaration extends AbstractTypeDeclaration imp
     }
 
     @Override
-    public SymbolReference<ResolvedMethodDeclaration> solveMethod(final String name,
-                                                                  final List<ResolvedType> argumentsTypes,
-                                                                  final boolean staticOnly) {
-        return ReflectionMethodResolutionLogic.solveMethod(name, argumentsTypes, staticOnly,
-            typeSolver,this, clazz);
+    public SymbolReference<ResolvedMethodDeclaration> solveMethod(
+            final String name, final List<ResolvedType> argumentsTypes, final boolean staticOnly) {
+        return ReflectionMethodResolutionLogic.solveMethod(name, argumentsTypes, staticOnly, typeSolver, this, clazz);
     }
 
     @Override
