@@ -21,6 +21,12 @@
 
 package com.github.javaparser.symbolsolver.reflectionmodel;
 
+import com.github.javaparser.ast.AccessSpecifier;
+import com.github.javaparser.resolution.TypeSolver;
+import com.github.javaparser.resolution.declarations.ResolvedReferenceTypeDeclaration;
+import com.github.javaparser.resolution.declarations.ResolvedTypeParameterDeclaration;
+import com.github.javaparser.resolution.model.typesystem.ReferenceTypeImpl;
+import com.github.javaparser.resolution.types.*;
 import java.lang.reflect.GenericArrayType;
 import java.lang.reflect.Modifier;
 import java.lang.reflect.ParameterizedType;
@@ -29,13 +35,6 @@ import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.List;
 
-import com.github.javaparser.ast.AccessSpecifier;
-import com.github.javaparser.resolution.TypeSolver;
-import com.github.javaparser.resolution.declarations.ResolvedReferenceTypeDeclaration;
-import com.github.javaparser.resolution.declarations.ResolvedTypeParameterDeclaration;
-import com.github.javaparser.resolution.model.typesystem.ReferenceTypeImpl;
-import com.github.javaparser.resolution.types.*;
-
 /**
  * @author Federico Tomassetti
  */
@@ -47,16 +46,16 @@ public class ReflectionFactory {
         if (clazz.isArray()) {
             throw new IllegalArgumentException("No type declaration available for an Array");
         }
-            if (clazz.isPrimitive()) {
+        if (clazz.isPrimitive()) {
             throw new IllegalArgumentException();
         }
-            if (clazz.isAnnotation()) {
+        if (clazz.isAnnotation()) {
             return new ReflectionAnnotationDeclaration(clazz, typeSolver);
         }
-            if (clazz.isInterface()) {
+        if (clazz.isInterface()) {
             return new ReflectionInterfaceDeclaration(clazz, typeSolver);
         }
-            if (clazz.isEnum()) {
+        if (clazz.isEnum()) {
             return new ReflectionEnumDeclaration(clazz, typeSolver);
         }
         return new ReflectionClassDeclaration(clazz, typeSolver);
@@ -66,19 +65,22 @@ public class ReflectionFactory {
         if (type instanceof java.lang.reflect.TypeVariable) {
             java.lang.reflect.TypeVariable<?> tv = (java.lang.reflect.TypeVariable<?>) type;
             boolean declaredOnClass = tv.getGenericDeclaration() instanceof java.lang.reflect.Type;
-            ResolvedTypeParameterDeclaration typeParameter = new ReflectionTypeParameter(tv, declaredOnClass, typeSolver);
+            ResolvedTypeParameterDeclaration typeParameter =
+                    new ReflectionTypeParameter(tv, declaredOnClass, typeSolver);
             return new ResolvedTypeVariable(typeParameter);
         }
-            if (type instanceof ParameterizedType) {
+        if (type instanceof ParameterizedType) {
             ParameterizedType pt = (ParameterizedType) type;
-            ResolvedReferenceType rawType = typeUsageFor(pt.getRawType(), typeSolver).asReferenceType();
+            ResolvedReferenceType rawType =
+                    typeUsageFor(pt.getRawType(), typeSolver).asReferenceType();
             List<java.lang.reflect.Type> actualTypes = new ArrayList<>();
             actualTypes.addAll(Arrays.asList(pt.getActualTypeArguments()));
             // we consume the actual types
-            rawType = rawType.transformTypeParameters(tp -> typeUsageFor(actualTypes.remove(0), typeSolver)).asReferenceType();
+            rawType = rawType.transformTypeParameters(tp -> typeUsageFor(actualTypes.remove(0), typeSolver))
+                    .asReferenceType();
             return rawType;
         }
-            if (type instanceof Class) {
+        if (type instanceof Class) {
             Class<?> c = (Class<?>) type;
             if (c.isPrimitive()) {
                 if (c.getName().equals(Void.TYPE.getName())) {
@@ -86,20 +88,21 @@ public class ReflectionFactory {
                 }
                 return ResolvedPrimitiveType.byName(c.getName());
             }
-                    if (c.isArray()) {
+            if (c.isArray()) {
                 return new ResolvedArrayType(typeUsageFor(c.getComponentType(), typeSolver));
             }
             return new ReferenceTypeImpl(typeDeclarationFor(c, typeSolver));
         }
-            if (type instanceof GenericArrayType) {
+        if (type instanceof GenericArrayType) {
             GenericArrayType genericArrayType = (GenericArrayType) type;
             return new ResolvedArrayType(typeUsageFor(genericArrayType.getGenericComponentType(), typeSolver));
         }
-            if (type instanceof WildcardType) {
+        if (type instanceof WildcardType) {
             WildcardType wildcardType = (WildcardType) type;
             if (wildcardType.getLowerBounds().length > 0 && wildcardType.getUpperBounds().length > 0) {
-                if (wildcardType.getUpperBounds().length == 1 && wildcardType.getUpperBounds()[0].getTypeName().equals(JAVA_LANG_OBJECT)) {
-                	// ok, it does not matter
+                if (wildcardType.getUpperBounds().length == 1
+                        && wildcardType.getUpperBounds()[0].getTypeName().equals(JAVA_LANG_OBJECT)) {
+                    // ok, it does not matter
                 }
             }
             if (wildcardType.getLowerBounds().length > 0) {
@@ -112,8 +115,9 @@ public class ReflectionFactory {
                 if (wildcardType.getUpperBounds().length > 1) {
                     throw new UnsupportedOperationException();
                 }
-                if (wildcardType.getUpperBounds().length == 1 && wildcardType.getUpperBounds()[0].getTypeName().equals(JAVA_LANG_OBJECT)) {
-                	return ResolvedWildcard.UNBOUNDED;
+                if (wildcardType.getUpperBounds().length == 1
+                        && wildcardType.getUpperBounds()[0].getTypeName().equals(JAVA_LANG_OBJECT)) {
+                    return ResolvedWildcard.UNBOUNDED;
                 }
                 return ResolvedWildcard.extendsBound(typeUsageFor(wildcardType.getUpperBounds()[0], typeSolver));
             }
@@ -126,10 +130,10 @@ public class ReflectionFactory {
         if (Modifier.isPublic(modifiers)) {
             return AccessSpecifier.PUBLIC;
         }
-            if (Modifier.isProtected(modifiers)) {
+        if (Modifier.isProtected(modifiers)) {
             return AccessSpecifier.PROTECTED;
         }
-            if (Modifier.isPrivate(modifiers)) {
+        if (Modifier.isPrivate(modifiers)) {
             return AccessSpecifier.PRIVATE;
         }
         return AccessSpecifier.NONE;
