@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2015-2016 Federico Tomassetti
- * Copyright (C) 2017-2020 The JavaParser Team.
+ * Copyright (C) 2017-2024 The JavaParser Team.
  *
  * This file is part of JavaParser.
  *
@@ -21,31 +21,35 @@
 
 package com.github.javaparser.symbolsolver.resolution.typeinference;
 
+import static com.github.javaparser.symbolsolver.resolution.typeinference.TypeHelper.*;
+
+import com.github.javaparser.resolution.TypeSolver;
 import com.github.javaparser.resolution.declarations.ResolvedReferenceTypeDeclaration;
+import com.github.javaparser.resolution.model.typesystem.ReferenceTypeImpl;
 import com.github.javaparser.resolution.types.ResolvedReferenceType;
 import com.github.javaparser.resolution.types.ResolvedType;
-import com.github.javaparser.symbolsolver.model.resolution.TypeSolver;
-import com.github.javaparser.symbolsolver.model.typesystem.ReferenceTypeImpl;
-import com.github.javaparser.symbolsolver.resolution.typeinference.bounds.*;
+import com.github.javaparser.symbolsolver.resolution.typeinference.bounds.CapturesBound;
+import com.github.javaparser.symbolsolver.resolution.typeinference.bounds.FalseBound;
+import com.github.javaparser.symbolsolver.resolution.typeinference.bounds.SameAsBound;
+import com.github.javaparser.symbolsolver.resolution.typeinference.bounds.SubtypeOfBound;
 import com.github.javaparser.symbolsolver.resolution.typeinference.constraintformulas.TypeSameAsType;
 import com.github.javaparser.symbolsolver.resolution.typeinference.constraintformulas.TypeSubtypeOfType;
 import com.github.javaparser.utils.Pair;
-
 import java.util.*;
 import java.util.function.Predicate;
 import java.util.stream.Collectors;
 
-import static com.github.javaparser.symbolsolver.resolution.typeinference.TypeHelper.*;
-
 /**
  * @author Federico Tomassetti
  */
 public class BoundSet {
 
-    private List<Bound> bounds = new LinkedList<>();
+    private static String JAVA_LANG_RUNTIME_EXCEPTION = RuntimeException.class.getCanonicalName();
 
     private static final BoundSet EMPTY = new BoundSet();
 
+    private List<Bound> bounds = new LinkedList<>();
+
     @Override
     public boolean equals(Object o) {
         if (this == o) return true;
@@ -63,13 +67,11 @@ public class BoundSet {
 
     @Override
     public String toString() {
-        return "BoundSet{" +
-                "bounds=" + bounds +
-                '}';
+        return "BoundSet{" + "bounds=" + bounds + '}';
     }
 
     /**
-
+     *
      * It is sometimes convenient to refer to an empty bound set with the symbol true; this is merely out of
      * convenience, and the two are interchangeable.
      */
@@ -91,15 +93,16 @@ public class BoundSet {
         return boundSet;
     }
 
-    private Optional<Pair<SameAsBound, SameAsBound>> findPairSameAs(Predicate<Pair<SameAsBound, SameAsBound>> condition) {
-        for (int i=0;i<bounds.size();i++) {
+    private Optional<Pair<SameAsBound, SameAsBound>> findPairSameAs(
+            Predicate<Pair<SameAsBound, SameAsBound>> condition) {
+        for (int i = 0; i < bounds.size(); i++) {
             Bound bi = bounds.get(i);
             if (bi instanceof SameAsBound) {
-                SameAsBound si = (SameAsBound)bi;
+                SameAsBound si = (SameAsBound) bi;
                 for (int j = i + 1; j < bounds.size(); j++) {
                     Bound bj = bounds.get(j);
                     if (bj instanceof SameAsBound) {
-                        SameAsBound sj = (SameAsBound)bj;
+                        SameAsBound sj = (SameAsBound) bj;
                         Pair<SameAsBound, SameAsBound> pair = new Pair<SameAsBound, SameAsBound>(si, sj);
                         if (condition.test(pair)) {
                             return Optional.of(pair);
@@ -121,14 +124,14 @@ public class BoundSet {
 
     private <T> T forEachPairSameAs(Processor<SameAsBound, SameAsBound, T> processor, T initialValue) {
         T currentValue = initialValue;
-        for (int i=0;i<bounds.size();i++) {
+        for (int i = 0; i < bounds.size(); i++) {
             Bound bi = bounds.get(i);
             if (bi instanceof SameAsBound) {
-                SameAsBound si = (SameAsBound)bi;
+                SameAsBound si = (SameAsBound) bi;
                 for (int j = i + 1; j < bounds.size(); j++) {
                     Bound bj = bounds.get(j);
                     if (bj instanceof SameAsBound) {
-                        SameAsBound sj = (SameAsBound)bj;
+                        SameAsBound sj = (SameAsBound) bj;
                         currentValue = processor.process(si, sj, currentValue);
                     }
                 }
@@ -139,14 +142,14 @@ public class BoundSet {
 
     private <T> T forEachPairSameAndSubtype(Processor<SameAsBound, SubtypeOfBound, T> processor, T initialValue) {
         T currentValue = initialValue;
-        for (int i=0;i<bounds.size();i++) {
+        for (int i = 0; i < bounds.size(); i++) {
             Bound bi = bounds.get(i);
             if (bi instanceof SameAsBound) {
-                SameAsBound si = (SameAsBound)bi;
+                SameAsBound si = (SameAsBound) bi;
                 for (int j = i + 1; j < bounds.size(); j++) {
                     Bound bj = bounds.get(j);
                     if (bj instanceof SubtypeOfBound) {
-                        SubtypeOfBound sj = (SubtypeOfBound)bj;
+                        SubtypeOfBound sj = (SubtypeOfBound) bj;
                         currentValue = processor.process(si, sj, currentValue);
                     }
                 }
@@ -157,14 +160,14 @@ public class BoundSet {
 
     private <T> T forEachPairSubtypeAndSubtype(Processor<SubtypeOfBound, SubtypeOfBound, T> processor, T initialValue) {
         T currentValue = initialValue;
-        for (int i=0;i<bounds.size();i++) {
+        for (int i = 0; i < bounds.size(); i++) {
             Bound bi = bounds.get(i);
             if (bi instanceof SubtypeOfBound) {
-                SubtypeOfBound si = (SubtypeOfBound)bi;
+                SubtypeOfBound si = (SubtypeOfBound) bi;
                 for (int j = i + 1; j < bounds.size(); j++) {
                     Bound bj = bounds.get(j);
                     if (bj instanceof SubtypeOfBound) {
-                        SubtypeOfBound sj = (SubtypeOfBound)bj;
+                        SubtypeOfBound sj = (SubtypeOfBound) bj;
                         currentValue = processor.process(si, sj, currentValue);
                     }
                 }
@@ -174,10 +177,11 @@ public class BoundSet {
     }
 
     private boolean areSameTypeInference(ResolvedType a, ResolvedType b) {
-        return isInferenceVariable(a) && isInferenceVariable(b) && a.equals(b);
+        return a.isInferenceVariable() && b.isInferenceVariable() && a.equals(b);
     }
 
-    private List<Pair<ResolvedReferenceType, ResolvedReferenceType>> findPairsOfCommonAncestors(ResolvedReferenceType r1, ResolvedReferenceType r2) {
+    private List<Pair<ResolvedReferenceType, ResolvedReferenceType>> findPairsOfCommonAncestors(
+            ResolvedReferenceType r1, ResolvedReferenceType r2) {
         List<ResolvedReferenceType> set1 = new LinkedList<>();
         set1.add(r1);
         set1.addAll(r1.getAllAncestors());
@@ -190,7 +194,7 @@ public class BoundSet {
                 Optional<ResolvedReferenceTypeDeclaration> rtFrom1TypeDeclaration = rtFrom1.getTypeDeclaration();
                 Optional<ResolvedReferenceTypeDeclaration> rtFrom2TypeDeclaration = rtFrom2.getTypeDeclaration();
                 if (rtFrom1TypeDeclaration.isPresent() && rtFrom2TypeDeclaration.isPresent()) {
-                    if(rtFrom1TypeDeclaration.get().equals(rtFrom2TypeDeclaration.get())) {
+                    if (rtFrom1TypeDeclaration.get().equals(rtFrom2TypeDeclaration.get())) {
                         pairs.add(new Pair<>(rtFrom1, rtFrom2));
                     }
                 }
@@ -248,155 +252,200 @@ public class BoundSet {
         //
         // - α = S and α = T imply ‹S = T›
 
-        newConstraintsSet = forEachPairSameAs((a, b, currentConstraintSet) -> {
-            if (areSameTypeInference(a.getS(), b.getS())) {
-                currentConstraintSet = currentConstraintSet.withConstraint(new TypeSameAsType(a.getT(), b.getT()));
-            }
-            if (areSameTypeInference(a.getS(), b.getT())) {
-                currentConstraintSet = currentConstraintSet.withConstraint(new TypeSameAsType(a.getS(), b.getT()));
-            }
-            if (areSameTypeInference(a.getT(), b.getS())) {
-                currentConstraintSet = currentConstraintSet.withConstraint(new TypeSameAsType(a.getT(), b.getS()));
-            }
-            if (areSameTypeInference(a.getT(), b.getT())) {
-                currentConstraintSet = currentConstraintSet.withConstraint(new TypeSameAsType(a.getS(), b.getS()));
-            }
-            return currentConstraintSet;
-        }, newConstraintsSet);
+        newConstraintsSet = forEachPairSameAs(
+                (a, b, currentConstraintSet) -> {
+                    if (areSameTypeInference(a.getS(), b.getS())) {
+                        currentConstraintSet =
+                                currentConstraintSet.withConstraint(new TypeSameAsType(a.getT(), b.getT()));
+                    }
+                    if (areSameTypeInference(a.getS(), b.getT())) {
+                        currentConstraintSet =
+                                currentConstraintSet.withConstraint(new TypeSameAsType(a.getS(), b.getT()));
+                    }
+                    if (areSameTypeInference(a.getT(), b.getS())) {
+                        currentConstraintSet =
+                                currentConstraintSet.withConstraint(new TypeSameAsType(a.getT(), b.getS()));
+                    }
+                    if (areSameTypeInference(a.getT(), b.getT())) {
+                        currentConstraintSet =
+                                currentConstraintSet.withConstraint(new TypeSameAsType(a.getS(), b.getS()));
+                    }
+                    return currentConstraintSet;
+                },
+                newConstraintsSet);
 
         // - α = S and α <: T imply ‹S <: T›
 
-        newConstraintsSet = forEachPairSameAndSubtype((a, b, currentConstraintSet) -> {
-            if (areSameTypeInference(a.getS(), b.getS())) {
-                currentConstraintSet = currentConstraintSet.withConstraint(new TypeSubtypeOfType(typeSolver, a.getT(), b.getT()));
-            }
-            if (areSameTypeInference(a.getT(), b.getS())) {
-                currentConstraintSet = currentConstraintSet.withConstraint(new TypeSubtypeOfType(typeSolver, a.getS(), b.getT()));
-            }
-            return currentConstraintSet;
-        }, newConstraintsSet);
+        newConstraintsSet = forEachPairSameAndSubtype(
+                (a, b, currentConstraintSet) -> {
+                    if (areSameTypeInference(a.getS(), b.getS())) {
+                        currentConstraintSet = currentConstraintSet.withConstraint(
+                                new TypeSubtypeOfType(typeSolver, a.getT(), b.getT()));
+                    }
+                    if (areSameTypeInference(a.getT(), b.getS())) {
+                        currentConstraintSet = currentConstraintSet.withConstraint(
+                                new TypeSubtypeOfType(typeSolver, a.getS(), b.getT()));
+                    }
+                    return currentConstraintSet;
+                },
+                newConstraintsSet);
 
         // - α = S and T <: α imply ‹T <: S›
 
-        newConstraintsSet = forEachPairSameAndSubtype((a, b, currentConstraintSet) -> {
-            if (areSameTypeInference(a.getS(), b.getT())) {
-                currentConstraintSet = currentConstraintSet.withConstraint(new TypeSubtypeOfType(typeSolver, b.getS(), a.getT()));
-            }
-            if (areSameTypeInference(a.getT(), b.getT())) {
-                currentConstraintSet = currentConstraintSet.withConstraint(new TypeSubtypeOfType(typeSolver, b.getS(), a.getS()));
-            }
-            return currentConstraintSet;
-        }, newConstraintsSet);
+        newConstraintsSet = forEachPairSameAndSubtype(
+                (a, b, currentConstraintSet) -> {
+                    if (areSameTypeInference(a.getS(), b.getT())) {
+                        currentConstraintSet = currentConstraintSet.withConstraint(
+                                new TypeSubtypeOfType(typeSolver, b.getS(), a.getT()));
+                    }
+                    if (areSameTypeInference(a.getT(), b.getT())) {
+                        currentConstraintSet = currentConstraintSet.withConstraint(
+                                new TypeSubtypeOfType(typeSolver, b.getS(), a.getS()));
+                    }
+                    return currentConstraintSet;
+                },
+                newConstraintsSet);
 
         // - S <: α and α <: T imply ‹S <: T›
 
-        newConstraintsSet = forEachPairSubtypeAndSubtype((a, b, currentConstraintSet) -> {
-            if (areSameTypeInference(a.getT(), b.getS())) {
-                currentConstraintSet = currentConstraintSet.withConstraint(new TypeSubtypeOfType(typeSolver, b.getS(), a.getT()));
-            }
-            return currentConstraintSet;
-        }, newConstraintsSet);
+        newConstraintsSet = forEachPairSubtypeAndSubtype(
+                (a, b, currentConstraintSet) -> {
+                    if (areSameTypeInference(a.getT(), b.getS())) {
+                        currentConstraintSet = currentConstraintSet.withConstraint(
+                                new TypeSubtypeOfType(typeSolver, b.getS(), a.getT()));
+                    }
+                    return currentConstraintSet;
+                },
+                newConstraintsSet);
 
         // - α = U and S = T imply ‹S[α:=U] = T[α:=U]›
 
-        newConstraintsSet = forEachPairSameAs((a, b, currentConstraintSet) -> {
-            if (isInferenceVariable(a.getS()) && isProperType(a.getT())) {
-                InferenceVariable alpha = (InferenceVariable)a.getS();
-                ResolvedType U = a.getT();
-                ResolvedType S = b.getS();
-                ResolvedType T = b.getT();
-                Substitution sub = Substitution.empty().withPair(alpha.getTypeParameterDeclaration(), U);
-                currentConstraintSet = currentConstraintSet.withConstraint(new TypeSameAsType(sub.apply(S), sub.apply(T)));
-            }
-            if (isInferenceVariable(a.getT()) && isProperType(a.getS())) {
-                InferenceVariable alpha = (InferenceVariable)a.getT();
-                ResolvedType U = a.getS();
-                ResolvedType S = b.getS();
-                ResolvedType T = b.getT();
-                Substitution sub = Substitution.empty().withPair(alpha.getTypeParameterDeclaration(), U);
-                currentConstraintSet = currentConstraintSet.withConstraint(new TypeSameAsType(sub.apply(S), sub.apply(T)));
-            }
-            if (isInferenceVariable(b.getS()) && isProperType(b.getT())) {
-                InferenceVariable alpha = (InferenceVariable)b.getS();
-                ResolvedType U = b.getT();
-                ResolvedType S = a.getS();
-                ResolvedType T = a.getT();
-                Substitution sub = Substitution.empty().withPair(alpha.getTypeParameterDeclaration(), U);
-                currentConstraintSet = currentConstraintSet.withConstraint(new TypeSameAsType(sub.apply(S), sub.apply(T)));
-            }
-            if (isInferenceVariable(b.getT()) && isProperType(b.getS())) {
-                InferenceVariable alpha = (InferenceVariable)b.getT();
-                ResolvedType U = b.getS();
-                ResolvedType S = a.getS();
-                ResolvedType T = a.getT();
-                Substitution sub = Substitution.empty().withPair(alpha.getTypeParameterDeclaration(), U);
-                currentConstraintSet = currentConstraintSet.withConstraint(new TypeSameAsType(sub.apply(S), sub.apply(T)));
-            }
-            return currentConstraintSet;
-        }, newConstraintsSet);
+        newConstraintsSet = forEachPairSameAs(
+                (a, b, currentConstraintSet) -> {
+                    if (a.getS().isInferenceVariable() && isProperType(a.getT())) {
+                        InferenceVariable alpha = (InferenceVariable) a.getS();
+                        ResolvedType U = a.getT();
+                        ResolvedType S = b.getS();
+                        ResolvedType T = b.getT();
+                        Substitution sub = Substitution.empty().withPair(alpha.getTypeParameterDeclaration(), U);
+                        currentConstraintSet =
+                                currentConstraintSet.withConstraint(new TypeSameAsType(sub.apply(S), sub.apply(T)));
+                    }
+                    if (a.getT().isInferenceVariable() && isProperType(a.getS())) {
+                        InferenceVariable alpha = (InferenceVariable) a.getT();
+                        ResolvedType U = a.getS();
+                        ResolvedType S = b.getS();
+                        ResolvedType T = b.getT();
+                        Substitution sub = Substitution.empty().withPair(alpha.getTypeParameterDeclaration(), U);
+                        currentConstraintSet =
+                                currentConstraintSet.withConstraint(new TypeSameAsType(sub.apply(S), sub.apply(T)));
+                    }
+                    if (b.getS().isInferenceVariable() && isProperType(b.getT())) {
+                        InferenceVariable alpha = (InferenceVariable) b.getS();
+                        ResolvedType U = b.getT();
+                        ResolvedType S = a.getS();
+                        ResolvedType T = a.getT();
+                        Substitution sub = Substitution.empty().withPair(alpha.getTypeParameterDeclaration(), U);
+                        currentConstraintSet =
+                                currentConstraintSet.withConstraint(new TypeSameAsType(sub.apply(S), sub.apply(T)));
+                    }
+                    if (b.getT().isInferenceVariable() && isProperType(b.getS())) {
+                        InferenceVariable alpha = (InferenceVariable) b.getT();
+                        ResolvedType U = b.getS();
+                        ResolvedType S = a.getS();
+                        ResolvedType T = a.getT();
+                        Substitution sub = Substitution.empty().withPair(alpha.getTypeParameterDeclaration(), U);
+                        currentConstraintSet =
+                                currentConstraintSet.withConstraint(new TypeSameAsType(sub.apply(S), sub.apply(T)));
+                    }
+                    return currentConstraintSet;
+                },
+                newConstraintsSet);
 
         // - α = U and S <: T imply ‹S[α:=U] <: T[α:=U]›
 
-        newConstraintsSet = forEachPairSameAndSubtype((a, b, currentConstraintSet) -> {
-            if (isInferenceVariable(a.getS()) && isProperType(a.getT())) {
-                InferenceVariable alpha = (InferenceVariable)a.getS();
-                ResolvedType U = a.getT();
-                ResolvedType S = b.getS();
-                ResolvedType T = b.getT();
-                Substitution sub = Substitution.empty().withPair(alpha.getTypeParameterDeclaration(), U);
-                currentConstraintSet = currentConstraintSet.withConstraint(new TypeSubtypeOfType(typeSolver, sub.apply(S), sub.apply(T)));
-            }
-            if (isInferenceVariable(a.getT()) && isProperType(a.getS())) {
-                InferenceVariable alpha = (InferenceVariable)a.getT();
-                ResolvedType U = a.getS();
-                ResolvedType S = b.getS();
-                ResolvedType T = b.getT();
-                Substitution sub = Substitution.empty().withPair(alpha.getTypeParameterDeclaration(), U);
-                currentConstraintSet = currentConstraintSet.withConstraint(new TypeSubtypeOfType(typeSolver, sub.apply(S), sub.apply(T)));
-            }
-            return currentConstraintSet;
-        }, newConstraintsSet);
+        newConstraintsSet = forEachPairSameAndSubtype(
+                (a, b, currentConstraintSet) -> {
+                    if (a.getS().isInferenceVariable() && isProperType(a.getT())) {
+                        InferenceVariable alpha = (InferenceVariable) a.getS();
+                        ResolvedType U = a.getT();
+                        ResolvedType S = b.getS();
+                        ResolvedType T = b.getT();
+                        Substitution sub = Substitution.empty().withPair(alpha.getTypeParameterDeclaration(), U);
+                        currentConstraintSet = currentConstraintSet.withConstraint(
+                                new TypeSubtypeOfType(typeSolver, sub.apply(S), sub.apply(T)));
+                    }
+                    if (a.getT().isInferenceVariable() && isProperType(a.getS())) {
+                        InferenceVariable alpha = (InferenceVariable) a.getT();
+                        ResolvedType U = a.getS();
+                        ResolvedType S = b.getS();
+                        ResolvedType T = b.getT();
+                        Substitution sub = Substitution.empty().withPair(alpha.getTypeParameterDeclaration(), U);
+                        currentConstraintSet = currentConstraintSet.withConstraint(
+                                new TypeSubtypeOfType(typeSolver, sub.apply(S), sub.apply(T)));
+                    }
+                    return currentConstraintSet;
+                },
+                newConstraintsSet);
 
         // When a bound set contains a pair of bounds α <: S and α <: T, and there exists a supertype of S of the
         // form G<S1, ..., Sn> and a supertype of T of the form G<T1, ..., Tn> (for some generic class or interface, G),
         // then for all i (1 ≤ i ≤ n), if Si and Ti are types (not wildcards), the constraint formula ‹Si = Ti› is
         // implied.
 
-        newConstraintsSet = forEachPairSubtypeAndSubtype((a, b, currentConstraintSet) -> {
-            if (isInferenceVariable(a.getS()) && isInferenceVariable(b.getS())) {
-                if (a.getT().isReferenceType() && b.getT().isReferenceType()) {
-                    ResolvedReferenceType S = a.getT().asReferenceType();
-                    ResolvedReferenceType T = b.getT().asReferenceType();
-                    List<Pair<ResolvedReferenceType, ResolvedReferenceType>> pairs = findPairsOfCommonAncestors(S, T);
-                    for (Pair<ResolvedReferenceType, ResolvedReferenceType> pair : pairs) {
-                        for (int i=0;i<Math.min(pair.a.typeParametersValues().size(), pair.b.typeParametersValues().size()); i++) {
-                            ResolvedType si = pair.a.typeParametersValues().get(i);
-                            ResolvedType ti = pair.b.typeParametersValues().get(i);
-                            if (!si.isWildcard() && !ti.isWildcard()) {
-                                currentConstraintSet = currentConstraintSet.withConstraint(new TypeSameAsType(si, ti));
+        newConstraintsSet = forEachPairSubtypeAndSubtype(
+                (a, b, currentConstraintSet) -> {
+                    if (a.getS().isInferenceVariable() && b.getS().isInferenceVariable()) {
+                        if (a.getT().isReferenceType() && b.getT().isReferenceType()) {
+                            ResolvedReferenceType S = a.getT().asReferenceType();
+                            ResolvedReferenceType T = b.getT().asReferenceType();
+                            List<Pair<ResolvedReferenceType, ResolvedReferenceType>> pairs =
+                                    findPairsOfCommonAncestors(S, T);
+                            for (Pair<ResolvedReferenceType, ResolvedReferenceType> pair : pairs) {
+                                for (int i = 0;
+                                        i
+                                                < Math.min(
+                                                        pair.a
+                                                                .typeParametersValues()
+                                                                .size(),
+                                                        pair.b
+                                                                .typeParametersValues()
+                                                                .size());
+                                        i++) {
+                                    ResolvedType si =
+                                            pair.a.typeParametersValues().get(i);
+                                    ResolvedType ti =
+                                            pair.b.typeParametersValues().get(i);
+                                    if (!si.isWildcard() && !ti.isWildcard()) {
+                                        currentConstraintSet =
+                                                currentConstraintSet.withConstraint(new TypeSameAsType(si, ti));
+                                    }
+                                }
                             }
                         }
                     }
-                }
-            }
-            return currentConstraintSet;
-        }, newConstraintsSet);
+                    return currentConstraintSet;
+                },
+                newConstraintsSet);
 
         // SECTION Bounds Involving Capture Conversion
         //
         // When a bound set contains a bound of the form G<α1, ..., αn> = capture(G<A1, ..., An>), new bounds are
         // implied and new constraint formulas may be implied, as follows.
 
-        for (Bound b : this.bounds.stream().filter(b -> b instanceof CapturesBound).collect(Collectors.toList())) {
-            CapturesBound capturesBound = (CapturesBound)b;
+        for (Bound b :
+                this.bounds.stream().filter(b -> b instanceof CapturesBound).collect(Collectors.toList())) {
+            CapturesBound capturesBound = (CapturesBound) b;
 
             throw new UnsupportedOperationException();
 
             // Let P1, ..., Pn represent the type parameters of G and let B1, ..., Bn represent the bounds of these type
-            // parameters. Let θ represent the substitution [P1:=α1, ..., Pn:=αn]. Let R be a type that is not an inference
+            // parameters. Let θ represent the substitution [P1:=α1, ..., Pn:=αn]. Let R be a type that is not an
+            // inference
             // variable (but is not necessarily a proper type).
             //
-            // A set of bounds on α1, ..., αn is implied, constructed from the declared bounds of P1, ..., Pn as specified
+            // A set of bounds on α1, ..., αn is implied, constructed from the declared bounds of P1, ..., Pn as
+            // specified
             // in §18.1.3.
             //
             // In addition, for all i (1 ≤ i ≤ n):
@@ -497,7 +546,7 @@ public class BoundSet {
         for (InferenceVariable alphaJ : alphas) {
             for (Bound b : bounds) {
                 if (b instanceof SameAsBound) {
-                    SameAsBound sameAsBound = (SameAsBound)b;
+                    SameAsBound sameAsBound = (SameAsBound) b;
                     if (sameAsBound.getS().equals(alphaJ) && sameAsBound.getT().equals(beta)) {
                         return true;
                     }
@@ -532,10 +581,10 @@ public class BoundSet {
     /**
      * there exists no non-empty proper subset of { α1, ..., αn } with this property.
      */
-    private Optional<Set<InferenceVariable>> smallestSetWithProperty(Set<InferenceVariable> uninstantiatedVariables,
-                                                                     List<VariableDependency> dependencies) {
-        for (int i=1;i<=uninstantiatedVariables.size();i++) {
-            for (Set<InferenceVariable> aSubSet : buildAllSubsetsOfSize(uninstantiatedVariables, i)){
+    private Optional<Set<InferenceVariable>> smallestSetWithProperty(
+            Set<InferenceVariable> uninstantiatedVariables, List<VariableDependency> dependencies) {
+        for (int i = 1; i <= uninstantiatedVariables.size(); i++) {
+            for (Set<InferenceVariable> aSubSet : buildAllSubsetsOfSize(uninstantiatedVariables, i)) {
                 if (hasProperty(aSubSet, dependencies)) {
                     return Optional.of(aSubSet);
                 }
@@ -550,8 +599,8 @@ public class BoundSet {
      * @return
      */
     private boolean hasProperty(Set<InferenceVariable> alphas, List<VariableDependency> dependencies) {
-        for (InferenceVariable alphaI: alphas) {
-            for (InferenceVariable beta: dependencies.stream()
+        for (InferenceVariable alphaI : alphas) {
+            for (InferenceVariable beta : dependencies.stream()
                     .filter(d -> d.depending.equals(alphaI))
                     .filter(d -> !d.isReflexive())
                     .map(d -> d.dependedOn)
@@ -568,7 +617,8 @@ public class BoundSet {
      * Examines the bounds on an inference variable and determines an instantiation that is compatible with those
      * bounds. It also decides the order in which interdependent inference variables are to be resolved.
      */
-    public Optional<InstantiationSet> performResolution(List<InferenceVariable> variablesToResolve, TypeSolver typeSolver) {
+    public Optional<InstantiationSet> performResolution(
+            List<InferenceVariable> variablesToResolve, TypeSolver typeSolver) {
 
         if (this.containsFalse()) {
             return Optional.empty();
@@ -616,9 +666,9 @@ public class BoundSet {
         // - An inference variable α depends on the resolution of an inference variable β if there exists an inference
         //   variable γ such that α depends on the resolution of γ and γ depends on the resolution of β.
 
-        for (int i=0;i<dependencies.size();i++) {
+        for (int i = 0; i < dependencies.size(); i++) {
             VariableDependency di = dependencies.get(i);
-            for (int j=i+1;j<dependencies.size();j++) {
+            for (int j = i + 1; j < dependencies.size(); j++) {
                 VariableDependency dj = dependencies.get(j);
                 if (di.dependedOn.equals(dj.depending)) {
                     dependencies.add(new VariableDependency(di.getDepending(), dj.getDependedOn()));
@@ -670,14 +720,12 @@ public class BoundSet {
                 uninstantiatedPortionOfV.add(v);
             }
         }
-        for (Set<InferenceVariable> alphas: allSetsWithProperty(uninstantiatedPortionOfV, dependencies)) {
+        for (Set<InferenceVariable> alphas : allSetsWithProperty(uninstantiatedPortionOfV, dependencies)) {
 
             // Resolution proceeds by generating an instantiation for each of α1, ..., αn based on the
             // bounds in the bound set:
 
-            boolean hasSomeCaptureForAlphas = alphas.stream().anyMatch(
-                    alphaI -> appearInLeftPartOfCapture(alphaI)
-            );
+            boolean hasSomeCaptureForAlphas = alphas.stream().anyMatch(alphaI -> appearInLeftPartOfCapture(alphaI));
 
             // - If the bound set does not contain a bound of the form G<..., αi, ...> = capture(G<...>)
             //   for all i (1 ≤ i ≤ n), then a candidate instantiation Ti is defined for each αi:
@@ -698,12 +746,13 @@ public class BoundSet {
                         Ti = leastUpperBound(properLowerBounds);
                     }
 
-                    //   - Otherwise, if the bound set contains throws αi, and the proper upper bounds of αi are, at most,
+                    //   - Otherwise, if the bound set contains throws αi, and the proper upper bounds of αi are, at
+                    // most,
                     //     Exception, Throwable, and Object, then Ti = RuntimeException.
 
                     boolean throwsBound = bounds.stream().anyMatch(b -> b.isThrowsBoundOn(alphaI));
                     if (Ti == null && throwsBound && properUpperBoundsAreAtMostExceptionThrowableAndObject(alphaI)) {
-                        Ti = new ReferenceTypeImpl(typeSolver.solveType(RuntimeException.class.getCanonicalName()), typeSolver);
+                        Ti = new ReferenceTypeImpl(typeSolver.solveType(JAVA_LANG_RUNTIME_EXCEPTION));
                     }
 
                     //   - Otherwise, where αi has proper upper bounds U1, ..., Uk, Ti = glb(U1, ..., Uk) (§5.1.10).
@@ -726,20 +775,23 @@ public class BoundSet {
 
                 BoundSet incorporatedBoundSet = this.incorporate(newBounds, typeSolver);
 
-                //   If the result does not contain the bound false, then the result becomes the new bound set, and resolution
+                //   If the result does not contain the bound false, then the result becomes the new bound set, and
+                // resolution
                 //   proceeds by selecting a new set of variables to instantiate (if necessary), as described above.
 
                 if (!incorporatedBoundSet.containsFalse()) {
                     return incorporatedBoundSet.performResolution(variablesToResolve, typeSolver);
                 }
 
-                //   Otherwise, the result contains the bound false, so a second attempt is made to instantiate { α1, ..., αn }
+                //   Otherwise, the result contains the bound false, so a second attempt is made to instantiate { α1,
+                // ..., αn }
                 //   by performing the step below.
 
                 throw new UnsupportedOperationException();
             }
 
-            // - If the bound set contains a bound of the form G<..., αi, ...> = capture(G<...>) for some i (1 ≤ i ≤ n), or;
+            // - If the bound set contains a bound of the form G<..., αi, ...> = capture(G<...>) for some i (1 ≤ i ≤ n),
+            // or;
 
             else {
 
@@ -747,19 +799,23 @@ public class BoundSet {
                 //
                 //   then let Y1, ..., Yn be fresh type variables whose bounds are as follows:
                 //
-                //   - For all i (1 ≤ i ≤ n), if αi has one or more proper lower bounds L1, ..., Lk, then let the lower bound
+                //   - For all i (1 ≤ i ≤ n), if αi has one or more proper lower bounds L1, ..., Lk, then let the lower
+                // bound
                 //     of Yi be lub(L1, ..., Lk); if not, then Yi has no lower bound.
                 //
                 //   - For all i (1 ≤ i ≤ n), where αi has upper bounds U1, ..., Uk, let the upper bound of Yi be
                 //     glb(U1 θ, ..., Uk θ), where θ is the substitution [α1:=Y1, ..., αn:=Yn].
                 //
-                //   If the type variables Y1, ..., Yn do not have well-formed bounds (that is, a lower bound is not a subtype
+                //   If the type variables Y1, ..., Yn do not have well-formed bounds (that is, a lower bound is not a
+                // subtype
                 //   of an upper bound, or an intersection type is inconsistent), then resolution fails.
                 //
-                //   Otherwise, for all i (1 ≤ i ≤ n), all bounds of the form G<..., αi, ...> = capture(G<...>) are removed
+                //   Otherwise, for all i (1 ≤ i ≤ n), all bounds of the form G<..., αi, ...> = capture(G<...>) are
+                // removed
                 //   from the current bound set, and the bounds α1 = Y1, ..., αn = Yn are incorporated.
                 //
-                //   If the result does not contain the bound false, then the result becomes the new bound set, and resolution
+                //   If the result does not contain the bound false, then the result becomes the new bound set, and
+                // resolution
                 //   proceeds by selecting a new set of variables to instantiate (if necessary), as described above.
                 //
                 //   Otherwise, the result contains the bound false, and resolution fails.
@@ -770,10 +826,11 @@ public class BoundSet {
         return Optional.empty();
     }
 
-    private Set<Set<InferenceVariable>> allPossibleSetsWithProperty(Set<InferenceVariable> allElements, List<VariableDependency> dependencies) {
+    private Set<Set<InferenceVariable>> allPossibleSetsWithProperty(
+            Set<InferenceVariable> allElements, List<VariableDependency> dependencies) {
         Set<Set<InferenceVariable>> result = new HashSet<>();
-        for (int i=1;i<=allElements.size();i++) {
-            for (Set<InferenceVariable> aSubSet : buildAllSubsetsOfSize(allElements, i)){
+        for (int i = 1; i <= allElements.size(); i++) {
+            for (Set<InferenceVariable> aSubSet : buildAllSubsetsOfSize(allElements, i)) {
                 if (hasProperty(aSubSet, dependencies)) {
                     result.add(aSubSet);
                 }
@@ -793,11 +850,13 @@ public class BoundSet {
         return false;
     }
 
-    private boolean isTheFirstAProperSubsetOfTheSecond(Set<InferenceVariable> subset, Set<InferenceVariable> originalSet) {
+    private boolean isTheFirstAProperSubsetOfTheSecond(
+            Set<InferenceVariable> subset, Set<InferenceVariable> originalSet) {
         return originalSet.containsAll(subset) && originalSet.size() > subset.size();
     }
 
-    private Set<Set<InferenceVariable>> allSetsWithProperty(Set<InferenceVariable> allElements, List<VariableDependency> dependencies) {
+    private Set<Set<InferenceVariable>> allSetsWithProperty(
+            Set<InferenceVariable> allElements, List<VariableDependency> dependencies) {
         Set<Set<InferenceVariable>> allPossibleSets = allPossibleSetsWithProperty(allElements, dependencies);
         Set<Set<InferenceVariable>> selected = new HashSet<>();
         for (Set<InferenceVariable> aSet : allPossibleSets) {
@@ -815,7 +874,7 @@ public class BoundSet {
     private boolean appearInLeftPartOfCapture(InferenceVariable inferenceVariable) {
         for (Bound b : bounds) {
             if (b instanceof CapturesBound) {
-                CapturesBound capturesBound = (CapturesBound)b;
+                CapturesBound capturesBound = (CapturesBound) b;
                 if (capturesBound.getInferenceVariables().contains(inferenceVariable)) {
                     return true;
                 }
@@ -825,6 +884,8 @@ public class BoundSet {
     }
 
     public List<Bound> getProperUpperBoundsFor(InferenceVariable inferenceVariable) {
-        return bounds.stream().filter(b -> b.isProperUpperBoundFor(inferenceVariable).isPresent()).collect(Collectors.toList());
+        return bounds.stream()
+                .filter(b -> b.isProperUpperBoundFor(inferenceVariable).isPresent())
+                .collect(Collectors.toList());
     }
 }
