@@ -24,7 +24,6 @@ package com.github.javaparser.symbolsolver.resolution.typeinference;
 import com.github.javaparser.ast.expr.LambdaExpr;
 import com.github.javaparser.resolution.TypeSolver;
 import com.github.javaparser.resolution.types.ResolvedType;
-
 import java.util.*;
 
 /**
@@ -32,8 +31,10 @@ import java.util.*;
  */
 public class TypeInferenceCache {
 
-    private static Map<TypeSolver, IdentityHashMap<LambdaExpr, Map<String, ResolvedType>>> typeForLambdaParameters = new HashMap<>();
-    private static Map<TypeSolver, IdentityHashMap<LambdaExpr, List<InferenceVariable>>> inferenceVariables = new HashMap<>();
+    private static Map<TypeSolver, IdentityHashMap<LambdaExpr, Map<String, ResolvedType>>> typeForLambdaParameters =
+            new HashMap<>();
+    private static Map<TypeSolver, IdentityHashMap<LambdaExpr, List<InferenceVariable>>> inferenceVariables =
+            new HashMap<>();
 
     public static void addRecord(TypeSolver typeSolver, LambdaExpr lambdaExpr, String paramName, ResolvedType type) {
         if (!typeForLambdaParameters.containsKey(typeSolver)) {
@@ -55,17 +56,20 @@ public class TypeInferenceCache {
         if (!typeForLambdaParameters.get(typeSolver).get(lambdaExpr).containsKey(paramName)) {
             return Optional.empty();
         }
-        return Optional.of(typeForLambdaParameters.get(typeSolver).get(lambdaExpr).get(paramName));
+        return Optional.of(
+                typeForLambdaParameters.get(typeSolver).get(lambdaExpr).get(paramName));
     }
 
-    public static void recordInferenceVariables(TypeSolver typeSolver, LambdaExpr lambdaExpr, List<InferenceVariable> _inferenceVariables) {
+    public static void recordInferenceVariables(
+            TypeSolver typeSolver, LambdaExpr lambdaExpr, List<InferenceVariable> _inferenceVariables) {
         if (!inferenceVariables.containsKey(typeSolver)) {
             inferenceVariables.put(typeSolver, new IdentityHashMap<>());
         }
         inferenceVariables.get(typeSolver).put(lambdaExpr, _inferenceVariables);
     }
 
-    public static Optional<List<InferenceVariable>> retrieveInferenceVariables(TypeSolver typeSolver, LambdaExpr lambdaExpr) {
+    public static Optional<List<InferenceVariable>> retrieveInferenceVariables(
+            TypeSolver typeSolver, LambdaExpr lambdaExpr) {
         if (!inferenceVariables.containsKey(typeSolver)) {
             return Optional.empty();
         }
