@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2015-2016 Federico Tomassetti
- * Copyright (C) 2017-2020 The JavaParser Team.
+ * Copyright (C) 2017-2024 The JavaParser Team.
  *
  * This file is part of JavaParser.
  *
@@ -21,28 +21,29 @@
 
 package com.github.javaparser.symbolsolver.resolution.typeinference.constraintformulas;
 
-import com.github.javaparser.ast.expr.*;
-import com.github.javaparser.ast.stmt.*;
-import com.github.javaparser.ast.type.UnknownType;
+import static com.github.javaparser.symbolsolver.resolution.typeinference.TypeHelper.isCompatibleInALooseInvocationContext;
+import static com.github.javaparser.symbolsolver.resolution.typeinference.TypeHelper.isProperType;
+import static java.util.stream.Collectors.toList;
+
+import com.github.javaparser.ast.expr.ConditionalExpr;
+import com.github.javaparser.ast.expr.EnclosedExpr;
+import com.github.javaparser.ast.expr.Expression;
+import com.github.javaparser.ast.expr.LambdaExpr;
+import com.github.javaparser.ast.stmt.BlockStmt;
+import com.github.javaparser.ast.stmt.ReturnStmt;
+import com.github.javaparser.ast.stmt.Statement;
+import com.github.javaparser.resolution.TypeSolver;
+import com.github.javaparser.resolution.logic.FunctionalInterfaceLogic;
 import com.github.javaparser.resolution.types.ResolvedType;
 import com.github.javaparser.resolution.types.ResolvedTypeVariable;
 import com.github.javaparser.symbolsolver.javaparsermodel.JavaParserFacade;
-import com.github.javaparser.symbolsolver.logic.FunctionalInterfaceLogic;
-import com.github.javaparser.symbolsolver.model.resolution.TypeSolver;
 import com.github.javaparser.symbolsolver.resolution.typeinference.*;
 import com.github.javaparser.utils.Pair;
-
 import java.util.HashMap;
 import java.util.LinkedList;
 import java.util.List;
 import java.util.Map;
 
-import static com.github.javaparser.symbolsolver.resolution.typeinference.ExpressionHelper.isPolyExpression;
-import static com.github.javaparser.symbolsolver.resolution.typeinference.ExpressionHelper.isStandaloneExpression;
-import static com.github.javaparser.symbolsolver.resolution.typeinference.TypeHelper.isCompatibleInALooseInvocationContext;
-import static com.github.javaparser.symbolsolver.resolution.typeinference.TypeHelper.isProperType;
-import static java.util.stream.Collectors.*;
-
 /**
  * An expression is compatible in a loose invocation context with type T
  *
@@ -67,29 +68,29 @@ public class ExpressionCompatibleWithType extends ConstraintFormula {
         if (isProperType(T)) {
             if (isCompatibleInALooseInvocationContext(typeSolver, expression, T)) {
                 return ReductionResult.trueResult();
-            } else {
-                return ReductionResult.falseResult();
             }
+            return ReductionResult.falseResult();
         }
 
         // Otherwise, if the expression is a standalone expression (§15.2) of type S, the constraint reduces
         // to ‹S → T›.
 
-        if (isStandaloneExpression(expression)) {
+        if (expression.isStandaloneExpression()) {
             ResolvedType s = JavaParserFacade.get(typeSolver).getType(expression, false);
             return ReductionResult.empty().withConstraint(new TypeCompatibleWithType(typeSolver, s, T));
         }
 
         // Otherwise, the expression is a poly expression (§15.2). The result depends on the form of the expression:
 
-        if (isPolyExpression(expression)) {
+        if (expression.isPolyExpression()) {
 
             // - If the expression is a parenthesized expression of the form ( Expression' ), the constraint reduces
             //   to ‹Expression' → T›.
 
-            if (expression instanceof EnclosedExpr) {
-                EnclosedExpr enclosedExpr = (EnclosedExpr)expression;
-                return ReductionResult.oneConstraint(new ExpressionCompatibleWithType(typeSolver, enclosedExpr.getInner(), T));
+            if (expression.isEnclosedExpr()) {
+                EnclosedExpr enclosedExpr = expression.asEnclosedExpr();
+                return ReductionResult.oneConstraint(
+                        new ExpressionCompatibleWithType(typeSolver, enclosedExpr.getInner(), T));
             }
 
             // - If the expression is a class instance creation expression or a method invocation expression, the
@@ -100,20 +101,20 @@ public class ExpressionCompatibleWithType extends ConstraintFormula {
             //   This bound set may contain new inference variables, as well as dependencies between these new
             //   variables and the inference variables in T.
 
-            if (expression instanceof ObjectCreationExpr) {
+            if (expression.isObjectCreationExpr()) {
                 BoundSet B3 = new TypeInference(typeSolver).invocationTypeInferenceBoundsSetB3();
                 return ReductionResult.bounds(B3);
             }
 
-            if (expression instanceof MethodCallExpr) {
+            if (expression.isMethodCallExpr()) {
                 throw new UnsupportedOperationException();
             }
 
             // - If the expression is a conditional expression of the form e1 ? e2 : e3, the constraint reduces to two
             //   constraint formulas, ‹e2 → T› and ‹e3 → T›.
 
-            if (expression instanceof ConditionalExpr) {
-                ConditionalExpr conditionalExpr = (ConditionalExpr)expression;
+            if (expression.isConditionalExpr()) {
+                ConditionalExpr conditionalExpr = expression.asConditionalExpr();
                 return ReductionResult.withConstraints(
                         new ExpressionCompatibleWithType(typeSolver, conditionalExpr.getThenExpr(), T),
                         new ExpressionCompatibleWithType(typeSolver, conditionalExpr.getElseExpr(), T));
@@ -122,10 +123,11 @@ public class ExpressionCompatibleWithType extends ConstraintFormula {
             // - If the expression is a lambda expression or a method reference expression, the result is specified
             //   below.
 
-            // A constraint formula of the form ‹LambdaExpression → T›, where T mentions at least one inference variable, is reduced as follows:
+            // A constraint formula of the form ‹LambdaExpression → T›, where T mentions at least one inference
+            // variable, is reduced as follows:
 
-            if (expression instanceof LambdaExpr) {
-                LambdaExpr lambdaExpr = (LambdaExpr)expression;
+            if (expression.isLambdaExpr()) {
+                LambdaExpr lambdaExpr = expression.asLambdaExpr();
 
                 // - If T is not a functional interface type (§9.8), the constraint reduces to false.
 
@@ -151,13 +153,14 @@ public class ExpressionCompatibleWithType extends ConstraintFormula {
                 //
                 //     Federico: THIS SHOULD NOT HAPPEN, IN CASE WE WILL THROW AN EXCEPTION
                 //
-                //   - Otherwise, the congruence of LambdaExpression with the target function type is asserted as
+                //   - Otherwise,) the congruence of LambdaExpression with the target function type is asserted as
                 //     follows:
                 //
                 //     - If the number of lambda parameters differs from the number of parameter types of the function
                 //       type, the constraint reduces to false.
 
-                if (targetFunctionType.getFormalArgumentTypes().size() != lambdaExpr.getParameters().size()) {
+                if (targetFunctionType.getFormalArgumentTypes().size()
+                        != lambdaExpr.getParameters().size()) {
                     return ReductionResult.falseResult();
                 }
 
@@ -177,7 +180,8 @@ public class ExpressionCompatibleWithType extends ConstraintFormula {
                 //     - If the function type's result is not void and the lambda body is a block that is not
                 //       value-compatible, the constraint reduces to false.
 
-                if (!targetFunctionType.getReturnType().isVoid() && lambdaExpr.getBody() instanceof BlockStmt
+                if (!targetFunctionType.getReturnType().isVoid()
+                        && lambdaExpr.getBody().isBlockStmt()
                         && !isValueCompatibleBlock(lambdaExpr.getBody())) {
                     return ReductionResult.falseResult();
                 }
@@ -188,7 +192,8 @@ public class ExpressionCompatibleWithType extends ConstraintFormula {
                 //       - If the lambda parameters have explicitly declared types F1, ..., Fn and the function type
                 //         has parameter types G1, ..., Gn, then i) for all i (1 ≤ i ≤ n), ‹Fi = Gi›, and ii) ‹T' <: T›.
 
-                boolean hasExplicitlyDeclaredTypes = lambdaExpr.getParameters().stream().anyMatch(p -> !(p.getType() instanceof UnknownType));
+                boolean hasExplicitlyDeclaredTypes = lambdaExpr.getParameters().stream()
+                        .anyMatch(p -> !(p.getType().isUnknownType()));
                 if (hasExplicitlyDeclaredTypes) {
                     throw new UnsupportedOperationException();
                 }
@@ -202,37 +207,49 @@ public class ExpressionCompatibleWithType extends ConstraintFormula {
 
                     if (TypeHelper.isProperType(R)) {
 
-                        //         - If R is a proper type, and if the lambda body or some result expression in the lambda body
+                        //         - If R is a proper type, and if the lambda body or some result expression in the
+                        // lambda body
                         //           is not compatible in an assignment context with R, then false.
 
-                        if (lambdaExpr.getBody() instanceof BlockStmt) {
-                            List<Expression> resultExpressions = ExpressionHelper.getResultExpressions((BlockStmt)lambdaExpr.getBody());
+                        if (lambdaExpr.getBody().isBlockStmt()) {
+                            List<Expression> resultExpressions =
+                                    getResultExpressions(lambdaExpr.getBody().asBlockStmt());
                             for (Expression e : resultExpressions) {
-                                if (!ExpressionHelper.isCompatibleInAssignmentContext(e, R, typeSolver)) {
+                                if (!isCompatibleInAssignmentContext(e, R, typeSolver)) {
                                     return ReductionResult.falseResult();
                                 }
                             }
                         } else {
-                            Expression e = ((ExpressionStmt)lambdaExpr.getBody()).getExpression();
-                            if (!ExpressionHelper.isCompatibleInAssignmentContext(e, R, typeSolver)) {
+                            Expression e =
+                                    lambdaExpr.getBody().asExpressionStmt().getExpression();
+                            if (!isCompatibleInAssignmentContext(e, R, typeSolver)) {
                                 return ReductionResult.falseResult();
                             }
                         }
                     } else {
-                        //         - Otherwise, if R is not a proper type, then where the lambda body has the form Expression,
+                        //         - Otherwise, if R is not a proper type, then where the lambda body has the form
+                        // Expression,
                         //           the constraint ‹Expression → R›; or where the lambda body is a block with result
                         //           expressions e1, ..., em, for all i (1 ≤ i ≤ m), ‹ei → R›.
 
-                        if (lambdaExpr.getBody() instanceof BlockStmt) {
-                            getAllReturnExpressions((BlockStmt)lambdaExpr.getBody()).forEach(e -> constraints.add(new ExpressionCompatibleWithType(typeSolver, e, R)));
+                        if (lambdaExpr.getBody().isBlockStmt()) {
+                            getAllReturnExpressions(lambdaExpr.getBody().asBlockStmt())
+                                    .forEach(e -> constraints.add(new ExpressionCompatibleWithType(typeSolver, e, R)));
                         } else {
                             // FEDERICO: Added - Start
-                            for (int i=0;i<lambdaExpr.getParameters().size();i++) {
-                                ResolvedType paramType = targetFunctionType.getFormalArgumentTypes().get(i);
-                                TypeInferenceCache.record(typeSolver, lambdaExpr, lambdaExpr.getParameter(i).getNameAsString(), paramType);
+                            for (int i = 0; i < lambdaExpr.getParameters().size(); i++) {
+                                ResolvedType paramType = targetFunctionType
+                                        .getFormalArgumentTypes()
+                                        .get(i);
+                                TypeInferenceCache.addRecord(
+                                        typeSolver,
+                                        lambdaExpr,
+                                        lambdaExpr.getParameter(i).getNameAsString(),
+                                        paramType);
                             }
                             // FEDERICO: Added - End
-                            Expression e = ((ExpressionStmt)lambdaExpr.getBody()).getExpression();
+                            Expression e =
+                                    lambdaExpr.getBody().asExpressionStmt().getExpression();
                             constraints.add(new ExpressionCompatibleWithType(typeSolver, e, R));
                         }
                     }
@@ -241,35 +258,58 @@ public class ExpressionCompatibleWithType extends ConstraintFormula {
                 return ReductionResult.withConstraints(constraints);
             }
 
-            // A constraint formula of the form ‹MethodReference → T›, where T mentions at least one inference variable, is reduced as follows:
+            // A constraint formula of the form ‹MethodReference → T›, where T mentions at least one inference variable,
+            // is reduced as follows:
 
-            if (expression instanceof MethodReferenceExpr) {
+            if (expression.isMethodReferenceExpr()) {
 
-                // - If T is not a functional interface type, or if T is a functional interface type that does not have a function type (§9.9), the constraint reduces to false.
+                // - If T is not a functional interface type, or if T is a functional interface type that does not have
+                // a function type (§9.9), the constraint reduces to false.
                 //
-                // - Otherwise, if there does not exist a potentially applicable method for the method reference when targeting T, the constraint reduces to false.
+                // - Otherwise, if there does not exist a potentially applicable method for the method reference when
+                // targeting T, the constraint reduces to false.
                 //
-                // - Otherwise, if the method reference is exact (§15.13.1), then let P1, ..., Pn be the parameter types of the function type of T, and let F1, ..., Fk be the parameter types of the potentially applicable method. The constraint reduces to a new set of constraints, as follows:
+                // - Otherwise, if the method reference is exact (§15.13.1), then let P1, ..., Pn be the parameter types
+                // of the function type of T, and let F1, ..., Fk be the parameter types of the potentially applicable
+                // method. The constraint reduces to a new set of constraints, as follows:
                 //
-                //   - In the special case where n = k+1, the parameter of type P1 is to act as the target reference of the invocation. The method reference expression necessarily has the form ReferenceType :: [TypeArguments] Identifier. The constraint reduces to ‹P1 <: ReferenceType› and, for all i (2 ≤ i ≤ n), ‹Pi → Fi-1›.
+                //   - In the special case where n = k+1, the parameter of type P1 is to act as the target reference of
+                // the invocation. The method reference expression necessarily has the form ReferenceType ::
+                // [TypeArguments] Identifier. The constraint reduces to ‹P1 <: ReferenceType› and, for all i (2 ≤ i ≤
+                // n), ‹Pi → Fi-1›.
                 //
                 //     In all other cases, n = k, and the constraint reduces to, for all i (1 ≤ i ≤ n), ‹Pi → Fi›.
                 //
-                //   - If the function type's result is not void, let R be its return type. Then, if the result of the potentially applicable compile-time declaration is void, the constraint reduces to false. Otherwise, the constraint reduces to ‹R' → R›, where R' is the result of applying capture conversion (§5.1.10) to the return type of the potentially applicable compile-time declaration.
+                //   - If the function type's result is not void, let R be its return type. Then, if the result of the
+                // potentially applicable compile-time declaration is void, the constraint reduces to false. Otherwise,
+                // the constraint reduces to ‹R' → R›, where R' is the result of applying capture conversion (§5.1.10)
+                // to the return type of the potentially applicable compile-time declaration.
                 //
                 // - Otherwise, the method reference is inexact, and:
                 //
-                //   - If one or more of the function type's parameter types is not a proper type, the constraint reduces to false.
+                //   - If one or more of the function type's parameter types is not a proper type, the constraint
+                // reduces to false.
                 //
-                //     This condition never arises in practice, due to the handling of inexact method references in §18.5.1 and the substitution applied to the target type in §18.5.2.
+                //     This condition never arises in practice, due to the handling of inexact method references in
+                // §18.5.1 and the substitution applied to the target type in §18.5.2.
                 //
-                //   - Otherwise, a search for a compile-time declaration is performed, as specified in §15.13.1. If there is no compile-time declaration for the method reference, the constraint reduces to false. Otherwise, there is a compile-time declaration, and:
+                //   - Otherwise, a search for a compile-time declaration is performed, as specified in §15.13.1. If
+                // there is no compile-time declaration for the method reference, the constraint reduces to false.
+                // Otherwise, there is a compile-time declaration, and:
                 //
                 //     - If the result of the function type is void, the constraint reduces to true.
                 //
-                //     - Otherwise, if the method reference expression elides TypeArguments, and the compile-time declaration is a generic method, and the return type of the compile-time declaration mentions at least one of the method's type parameters, then the constraint reduces to the bound set B3 which would be used to determine the method reference's invocation type when targeting the return type of the function type, as defined in §18.5.2. B3 may contain new inference variables, as well as dependencies between these new variables and the inference variables in T.
+                //     - Otherwise, if the method reference expression elides TypeArguments, and the compile-time
+                // declaration is a generic method, and the return type of the compile-time declaration mentions at
+                // least one of the method's type parameters, then the constraint reduces to the bound set B3 which
+                // would be used to determine the method reference's invocation type when targeting the return type of
+                // the function type, as defined in §18.5.2. B3 may contain new inference variables, as well as
+                // dependencies between these new variables and the inference variables in T.
                 //
-                //     - Otherwise, let R be the return type of the function type, and let R' be the result of applying capture conversion (§5.1.10) to the return type of the invocation type (§15.12.2.6) of the compile-time declaration. If R' is void, the constraint reduces to false; otherwise, the constraint reduces to ‹R' → R›.
+                //     - Otherwise, let R be the return type of the function type, and let R' be the result of applying
+                // capture conversion (§5.1.10) to the return type of the invocation type (§15.12.2.6) of the
+                // compile-time declaration. If R' is void, the constraint reduces to false; otherwise, the constraint
+                // reduces to ‹R' → R›.
 
                 throw new UnsupportedOperationException();
             }
@@ -280,6 +320,14 @@ public class ExpressionCompatibleWithType extends ConstraintFormula {
         throw new RuntimeException("This should not happen");
     }
 
+    private List<Expression> getResultExpressions(BlockStmt blockStmt) {
+        throw new UnsupportedOperationException();
+    }
+
+    private boolean isCompatibleInAssignmentContext(Expression expression, ResolvedType type, TypeSolver typeSolver) {
+        return type.isAssignableBy(JavaParserFacade.get(typeSolver).getType(expression, false));
+    }
+
     private List<Expression> getAllReturnExpressions(BlockStmt blockStmt) {
         return blockStmt.findAll(ReturnStmt.class).stream()
                 .filter(r -> r.getExpression().isPresent())
@@ -291,7 +339,7 @@ public class ExpressionCompatibleWithType extends ConstraintFormula {
         // A block lambda body is value-compatible if it cannot complete normally (§14.21) and every return statement
         // in the block has the form return Expression;.
 
-        if (statement instanceof BlockStmt) {
+        if (statement.isBlockStmt()) {
             if (!ControlFlowLogic.getInstance().canCompleteNormally(statement)) {
                 return true;
             }
@@ -323,11 +371,10 @@ public class ExpressionCompatibleWithType extends ConstraintFormula {
 
     @Override
     public String toString() {
-        return "ExpressionCompatibleWithType{" +
-                "typeSolver=" + typeSolver +
-                ", expression=" + expression +
-                ", T=" + T +
-                '}';
+        return "ExpressionCompatibleWithType{" + "typeSolver="
+                + typeSolver + ", expression="
+                + expression + ", T="
+                + T + '}';
     }
 
     private MethodType replaceTypeVariablesWithInferenceVariables(MethodType methodType) {
@@ -337,14 +384,19 @@ public class ExpressionCompatibleWithType extends ConstraintFormula {
         for (ResolvedType formalArg : methodType.getFormalArgumentTypes()) {
             newFormalArgumentTypes.add(replaceTypeVariablesWithInferenceVariables(formalArg, correspondences));
         }
-        ResolvedType newReturnType = replaceTypeVariablesWithInferenceVariables(methodType.getReturnType(), correspondences);
-        return new MethodType(methodType.getTypeParameters(), newFormalArgumentTypes, newReturnType, methodType.getExceptionTypes());
+        ResolvedType newReturnType =
+                replaceTypeVariablesWithInferenceVariables(methodType.getReturnType(), correspondences);
+        return new MethodType(
+                methodType.getTypeParameters(), newFormalArgumentTypes, newReturnType, methodType.getExceptionTypes());
     }
 
-    private ResolvedType replaceTypeVariablesWithInferenceVariables(ResolvedType originalType, Map<ResolvedTypeVariable, InferenceVariable> correspondences) {
+    private ResolvedType replaceTypeVariablesWithInferenceVariables(
+            ResolvedType originalType, Map<ResolvedTypeVariable, InferenceVariable> correspondences) {
         if (originalType.isTypeVariable()) {
             if (!correspondences.containsKey(originalType.asTypeVariable())) {
-                correspondences.put(originalType.asTypeVariable(), InferenceVariable.unnamed(originalType.asTypeVariable().asTypeParameter()));
+                correspondences.put(
+                        originalType.asTypeVariable(),
+                        InferenceVariable.unnamed(originalType.asTypeVariable().asTypeParameter()));
             }
             return correspondences.get(originalType.asTypeVariable());
         }
