@@ -21,6 +21,9 @@
 
 package com.github.javaparser.symbolsolver;
 
+import static com.github.javaparser.StaticJavaParser.parse;
+import static org.junit.jupiter.api.Assertions.assertEquals;
+
 import com.github.javaparser.ast.CompilationUnit;
 import com.github.javaparser.ast.body.MethodDeclaration;
 import com.github.javaparser.ast.expr.MethodCallExpr;
@@ -32,14 +35,10 @@ import com.github.javaparser.symbolsolver.resolution.typesolvers.CombinedTypeSol
 import com.github.javaparser.symbolsolver.resolution.typesolvers.JavaParserTypeSolver;
 import com.github.javaparser.symbolsolver.resolution.typesolvers.ReflectionTypeSolver;
 import com.github.javaparser.symbolsolver.utils.LeanParserConfiguration;
-import org.junit.jupiter.api.BeforeEach;
-import org.junit.jupiter.api.Test;
-
 import java.io.IOException;
 import java.nio.file.Path;
-
-import static com.github.javaparser.StaticJavaParser.parse;
-import static org.junit.jupiter.api.Assertions.assertEquals;
+import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.api.Test;
 
 class Issue113Test extends AbstractSymbolResolutionTest {
 
@@ -47,7 +46,9 @@ class Issue113Test extends AbstractSymbolResolutionTest {
 
     @BeforeEach
     void setup() {
-        typeSolver = new CombinedTypeSolver(new ReflectionTypeSolver(), new JavaParserTypeSolver(adaptPath("src/test/resources/issue113"), new LeanParserConfiguration()));
+        typeSolver = new CombinedTypeSolver(
+                new ReflectionTypeSolver(),
+                new JavaParserTypeSolver(adaptPath("src/test/resources/issue113"), new LeanParserConfiguration()));
     }
 
     @Test
@@ -57,7 +58,9 @@ class Issue113Test extends AbstractSymbolResolutionTest {
 
         JavaParserFacade parserFacade = JavaParserFacade.get(typeSolver);
         MethodDeclaration methodDeclaration = cu.findAll(MethodDeclaration.class).stream()
-                .filter(node -> node.getName().getIdentifier().equals("doSomething")).findAny().orElse(null);
+                .filter(node -> node.getName().getIdentifier().equals("doSomething"))
+                .findAny()
+                .orElse(null);
         methodDeclaration.findAll(MethodCallExpr.class).forEach(parserFacade::solve);
     }
 
@@ -66,9 +69,9 @@ class Issue113Test extends AbstractSymbolResolutionTest {
         Path pathToSourceFile = adaptPath("src/test/resources/issue113/com/foo/Widget.java");
         CompilationUnit cu = parse(pathToSourceFile);
 
-        JavaParserClassDeclaration jssExtendedWidget = new JavaParserClassDeclaration(cu.getClassByName("Widget").get(), typeSolver);
+        JavaParserClassDeclaration jssExtendedWidget =
+                new JavaParserClassDeclaration(cu.getClassByName("Widget").get(), typeSolver);
         ResolvedReferenceType superClass = jssExtendedWidget.getSuperClass().get();
         assertEquals("com.foo.base.Widget", superClass.getQualifiedName());
     }
-
 }
