@@ -20,6 +20,8 @@
 
 package com.github.javaparser.symbolsolver;
 
+import static org.junit.jupiter.api.Assertions.assertEquals;
+
 import com.github.javaparser.ParserConfiguration;
 import com.github.javaparser.StaticJavaParser;
 import com.github.javaparser.ast.CompilationUnit;
@@ -28,33 +30,28 @@ import com.github.javaparser.resolution.TypeSolver;
 import com.github.javaparser.symbolsolver.resolution.typesolvers.ReflectionTypeSolver;
 import org.junit.jupiter.api.Test;
 
-import static org.junit.jupiter.api.Assertions.assertEquals;
-
-
 public class Issue2132Test extends AbstractSymbolResolutionTest {
 
     @Test
     public void test() {
-        
+
         TypeSolver typeSolver = new ReflectionTypeSolver();
         ParserConfiguration config = new ParserConfiguration();
         config.setSymbolResolver(new JavaSymbolSolver(typeSolver));
         StaticJavaParser.setConfiguration(config);
 
-        String s = 
-                "class A {\n" + 
-                "    void method() {\n" + 
-                "        String s = \"\";\n" + 
-                "        {\n" + 
-                "          s.length();\n" + 
-                "        }\n" + 
-                "    }\n" + 
-                "}";
+        String s = "class A {\n" + "    void method() {\n"
+                + "        String s = \"\";\n"
+                + "        {\n"
+                + "          s.length();\n"
+                + "        }\n"
+                + "    }\n"
+                + "}";
         CompilationUnit cu = StaticJavaParser.parse(s);
         MethodCallExpr mce = cu.findFirst(MethodCallExpr.class).get();
         assertEquals("int", mce.calculateResolvedType().describe());
         assertEquals("java.lang.String.length", mce.resolve().getQualifiedName());
-        assertEquals("java.lang.String", mce.getScope().get().calculateResolvedType().describe());
+        assertEquals(
+                "java.lang.String", mce.getScope().get().calculateResolvedType().describe());
     }
-
 }
