@@ -21,6 +21,8 @@
 
 package com.github.javaparser.symbolsolver;
 
+import static org.junit.jupiter.api.Assertions.assertEquals;
+
 import com.github.javaparser.JavaParser;
 import com.github.javaparser.ParseStart;
 import com.github.javaparser.StreamProvider;
@@ -29,14 +31,11 @@ import com.github.javaparser.ast.expr.NameExpr;
 import com.github.javaparser.resolution.declarations.ResolvedValueDeclaration;
 import com.github.javaparser.symbolsolver.resolution.typesolvers.CombinedTypeSolver;
 import com.github.javaparser.symbolsolver.resolution.typesolvers.JavaParserTypeSolver;
-import org.junit.jupiter.api.Test;
-
 import java.io.IOException;
 import java.nio.charset.StandardCharsets;
 import java.nio.file.Files;
 import java.nio.file.Path;
-
-import static org.junit.jupiter.api.Assertions.assertEquals;
+import org.junit.jupiter.api.Test;
 
 class Issue2367Test extends AbstractSymbolResolutionTest {
 
@@ -51,10 +50,16 @@ class Issue2367Test extends AbstractSymbolResolutionTest {
         JavaParser javaParser = new JavaParser();
         javaParser.getParserConfiguration().setSymbolResolver(new JavaSymbolSolver(typeSolver));
 
-        CompilationUnit unit = javaParser.parse(ParseStart.COMPILATION_UNIT,
-                new StreamProvider(Files.newInputStream(file), StandardCharsets.UTF_8.name())).getResult().get();
+        CompilationUnit unit = javaParser
+                .parse(
+                        ParseStart.COMPILATION_UNIT,
+                        new StreamProvider(Files.newInputStream(file), StandardCharsets.UTF_8.name()))
+                .getResult()
+                .get();
 
-        NameExpr nameExpr = unit.findFirst(NameExpr.class, m -> m.getName().getIdentifier().equals("privateField")).get();
+        NameExpr nameExpr = unit.findFirst(
+                        NameExpr.class, m -> m.getName().getIdentifier().equals("privateField"))
+                .get();
         ResolvedValueDeclaration resolvedValueDeclaration = nameExpr.resolve();
         assertEquals("double", resolvedValueDeclaration.getType().describe());
     }
