@@ -21,19 +21,18 @@
 
 package com.github.javaparser.symbolsolver.model.typesystem;
 
+import static org.junit.jupiter.api.Assertions.assertEquals;
+
 import com.github.javaparser.resolution.TypeSolver;
 import com.github.javaparser.resolution.declarations.ResolvedTypeParameterDeclaration;
 import com.github.javaparser.resolution.model.typesystem.ReferenceTypeImpl;
 import com.github.javaparser.resolution.types.ResolvedTypeVariable;
 import com.github.javaparser.symbolsolver.reflectionmodel.ReflectionClassDeclaration;
 import com.github.javaparser.symbolsolver.resolution.typesolvers.ReflectionTypeSolver;
+import java.util.Collections;
 import org.junit.jupiter.api.BeforeEach;
 import org.junit.jupiter.api.Test;
 
-import java.util.Collections;
-
-import static org.junit.jupiter.api.Assertions.assertEquals;
-
 class TypeVariableUsageTest {
 
     private ResolvedTypeVariable tpA;
@@ -42,8 +41,9 @@ class TypeVariableUsageTest {
 
     @BeforeEach
     void setup() {
-        tpA = new ResolvedTypeVariable(ResolvedTypeParameterDeclaration.onType("A", "foo.Bar", Collections.emptyList()));
-        
+        tpA = new ResolvedTypeVariable(
+                ResolvedTypeParameterDeclaration.onType("A", "foo.Bar", Collections.emptyList()));
+
         typeSolver = new ReflectionTypeSolver();
         tpString = new ReferenceTypeImpl(new ReflectionClassDeclaration(String.class, typeSolver));
     }
@@ -52,5 +52,4 @@ class TypeVariableUsageTest {
     void testIsAssignableBySimple() {
         assertEquals(false, tpString.isAssignableBy(tpA));
     }
-
 }
