@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2015-2016 Federico Tomassetti
- * Copyright (C) 2017-2019 The JavaParser Team.
+ * Copyright (C) 2017-2024 The JavaParser Team.
  *
  * This file is part of JavaParser.
  *
@@ -22,7 +22,5 @@
 package com.github.javaparser.symbolsolver.testingclasses;
 
 public class UtilityClass {
-    public static void method(SomeClass.InnerEnum e) {
-
-    }
+    public static void method(SomeClass.InnerEnum e) {}
 }
